/*!
 * Mercury Editor is a CoffeeScript and jQuery based WYSIWYG editor.  Documentation and other useful information can be
 * found at https://github.com/jejacks0n/mercury
 *
 * Supported browsers:
 *   - Firefox 4+
 *   - Chrome 10+
 *   - Safari 5+
 *
 * Copyright (c) 2011 Jeremy Jackson
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit
 * persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 *= require_self
 *= require mercury/mercury
 */
window.MercurySetup = {

  // # Mercury Configuration
  config: {
    // ## Hijacking Links & Forms
    // Mercury will hijack links and forms that don't have a target set, or the target is set to _self and will set it
    // to _top.  This is because the target must be set properly for Mercury to not get in the way of some
    // functionality, like proper page loads on form submissions etc.  Mercury doesn't do this to links or forms that
    // are within editable regions because it doesn't want to impact the html that's saved.  With that being explained,
    // you can add classes to links or forms that you don't want this behavior added to.  Let's say you have links that
    // open a lightbox style window, and you don't want the targets of these to be set to _top.  You can add classes to
    // this array, and they will be ignored when the hijacking is applied.
    nonHijackableClasses: [],


    // ## Pasting (in Chrome/Safari)
    //
    // When copying content using webkit, it embeds all the user defined styles (from the css files) into the html
    // style attributes directly.  When pasting this content into HTML5 contentEditable elements it leaves these
    // intact.  This can be a desired feature, or an annoyance, so you can enable it or disable it here.  Keep in mind
    // this will only change the behavior in webkit, as mozilla doesn't do this.
    cleanStylesOnPaste: true,


    // ## Snippet Options and Preview
    //
    // When a user drags a snippet onto the page they'll be prompted to enter options for the given snippet.  The server
    // is expected to respond with a form.  Once the user submits this form, an Ajax request is sent to the server with
    // the options provided; this preview request is expected to respond with the rendered markup for the snippet.
    //
    // Name will be replaced with the snippet name (eg. example)
    snippets: {
      method: 'POST',
      optionsUrl: '/mercury/snippets/:name/options.html',
      previewUrl: '/mercury/snippets/:name/preview.html'
      },


    // ## Image Uploading
    //
    // If you drag images (while pressing shift) from your desktop into regions that support it, it will be uploaded
    // to the server and inserted into the region.  This configuration allows you to specify if you want to
    // disable/enable this feature, the accepted mime-types, file size restrictions, and other things related to
    // uploading.  You can optionally provide a handler function that takes the response from the server and returns an
    // object: {image: {url: '[your provided url]'}
    //
    // **Note:** Image uploading is only supported in some region types.
    uploading: {
      enabled: true,
      allowedMimeTypes: ['image/jpeg', 'image/gif', 'image/png'],
      maxFileSize: 1235242880,
      inputName: 'image[image]',
      url: '/images',
      handler: false
      },


    // ## Toolbars
    //
    // This is where you can customize the toolbars by adding or removing buttons, or changing them and their
    // behaviors.  Any top level object put here will create a new toolbar.  Buttons are simply nested inside the
    // toolbars, along with button groups.
    //
    // Some toolbars are custom (the snippetable toolbar for instance), and to denote that use _custom: true.  You can
    // then build the toolbar yourself with it's own behavior.
    //
    // Buttons can be grouped, and a button group is simply a way to wrap buttons for styling -- they can also handle
    // enabling or disabling all the buttons within it by using a context.  The table button group is a good example
    // of this.
    //
    // It's important to note that each of the button names (keys), in each toolbar object must be unique, regardless
    // of if it's in a button group, or nested, etc.  This is because styling is applied to them by name, and because
    // their name is used in the event that's fired when you click on them.
    //
    // Button format: `[label, description, {type: action, type: action, etc}]`
    //
    // ### The available button types are:
    //
    // - toggle:  toggles on or off when clicked, otherwise behaves like a button
    // - modal:   opens a modal window, expects the action to be one of:
    //   1. a string url
    //   2. a function that returns a string url
    // - panel:   opens a panel dialog, expects the action to be one of:
    //   1. a string url
    //   2. a function that returns a string url
    // - palette: opens a palette window, expects the action to be one of:
    //   1. a string url
    //   2. a function that returns a string url
    // - select:  opens a pulldown style window, expects the action to be one of:
    //   1. a string url
    //   2. a function that returns a string url
    // - context: calls a callback function, expects the action to be:
    //   1. a function that returns a boolean to highlight the button
    //   note: if a function isn't provided, the key will be passed to the contextHandler, in which case a default
    //         context will be used (for more info read the Contexts section below)
    // - mode:    toggle a given mode in the editor, expects the action to be:
    //   1. a string, denoting the name of the mode
    //   note: it's assumed that when a specific mode is turned on, all other modes will be turned off, which happens
    //         automatically, thus putting the editor into a specific "state"
    // - regions: allows buttons to be enabled/disabled based on what region type has focus, expects the action to be:
    //   1. an array of region types (eg. ['editable', 'markupable'])
    // - preload: allows some dialog views to be loaded when the button is created instead of on first open, expects:
    //   1. a boolean true / false
    //   note: this is only used by panels, selects, and palettes
    //
    // Separators are any "button" that's not an array, and are expected to be a string.  You can use two different
    // separator styles: line ('-'), and spacer (' ').
    toolbars: {
      primary: {
        save:                  ['Save', 'Save this page'],
        preview:               ['Preview', 'Preview this page', { toggle: true, mode: true }],
        sep1:                  ' ',
        undoredo:              {
          undo:                ['Undo', 'Undo your last action'],
          redo:                ['Redo', 'Redo your last action'],
          sep:                 ' '
          },
        insertLink:            ['Link', 'Insert Link', { modal: '/mercury/modals/link.html', regions: ['editable', 'markupable'] }],
        insertMedia:           ['Media', 'Insert Media (images and videos)', { modal: '/mercury/modals/media.html', regions: ['editable', 'markupable'] }],
        insertTable:           ['Table', 'Insert Table', { modal: '/mercury/modals/table.html', regions: ['editable', 'markupable'] }],
        insertCharacter:       ['Character', 'Special Characters', { modal: '/mercury/modals/character.html', regions: ['editable', 'markupable'] }],
        snippetPanel:          ['Snippet', 'Snippet Panel', { panel: '/mercury/panels/snippets.html' }],
        sep2:                  ' ',
        historyPanel:          ['History', 'Page Version History', { panel: '/mercury/panels/history.html' }],
        sep3:                  ' ',
        notesPanel:            ['Notes', 'Page Notes', { panel: '/mercury/panels/notes.html' }]
        },

      editable: {
        _regions:              ['editable', 'markupable'],
        predefined:            {
          style:               ['Style', null, { select: '/mercury/selects/style.html', preload: true }],
          sep1:                ' ',
          formatblock:         ['Block Format', null, { select: '/mercury/selects/formatblock.html', preload: true }],
          sep2:                '-'
          },
        colors:                {
          backColor:           ['Background Color', null, { palette: '/mercury/palettes/backcolor.html', context: true, preload: true, regions: ['editable'] }],
          sep1:                ' ',
          foreColor:           ['Text Color', null, { palette: '/mercury/palettes/forecolor.html', context: true, preload: true, regions: ['editable'] }],
          sep2:                '-'
          },
        decoration:            {
          bold:                ['Bold', null, { context: true }],
          italic:              ['Italicize', null, { context: true }],
          overline:            ['Overline', null, { context: true, regions: ['editable'] }],
          strikethrough:       ['Strikethrough', null, { context: true, regions: ['editable'] }],
          underline:           ['Underline', null, { context: true, regions: ['editable'] }],
          sep:                 '-'
          },
        script:                {
          subscript:           ['Subscript', null, { context: true }],
          superscript:         ['Superscript', null, { context: true }],
          sep: '-'
          },
        justify:               {
          justifyLeft:         ['Align Left', null, { context: true, regions: ['editable'] }],
          justifyCenter:       ['Center', null, { context: true, regions: ['editable'] }],
          justifyRight:        ['Align Right', null, { context: true, regions: ['editable'] }],
          justifyFull:         ['Justify Full', null, { context: true, regions: ['editable'] }],
          sep:                 '-'
          },
        list:                  {
          insertUnorderedList: ['Unordered List', null, { context: true }],
          insertOrderedList:   ['Numbered List', null, { context: true }],
          sep:                 '-'
          },
        indent:                {
          outdent:             ['Decrease Indentation', null],
          indent:              ['Increase Indentation', null],
          sep:                 '-'
          },
        table:                 {
          _context:            true,
          insertRowBefore:     ['Insert Table Row', 'Insert a table row before the cursor', { regions: ['editable'] }],
          insertRowAfter:      ['Insert Table Row', 'Insert a table row after the cursor', { regions: ['editable'] }],
          deleteRow:           ['Delete Table Row', 'Delete this table row', { regions: ['editable'] }],
          insertColumnBefore:  ['Insert Table Column', 'Insert a table column before the cursor', { regions: ['editable'] }],
          insertColumnAfter:   ['Insert Table Column', 'Insert a table column after the cursor', { regions: ['editable'] }],
          deleteColumn:        ['Delete Table Column', 'Delete this table column', { regions: ['editable'] }],
          sep1:                ' ',
          increaseColspan:     ['Increase Cell Columns', 'Increase the cells colspan'],
          decreaseColspan:     ['Decrease Cell Columns', 'Decrease the cells colspan and add a new cell'],
          increaseRowspan:     ['Increase Cell Rows', 'Increase the cells rowspan'],
          decreaseRowspan:     ['Decrease Cell Rows', 'Decrease the cells rowspan and add a new cell'],
          sep2:                '-'
          },
        rules:                 {
          horizontalRule:      ['Horizontal Rule', 'Insert a horizontal rule'],
          sep1:                '-'
          },
        formatting:            {
          removeFormatting:    ['Remove Formatting', 'Remove formatting for the selection', { regions: ['editable'] }],
          sep2:                ' '
          },
        editors:               {
          htmlEditor:          ['Edit HTML', 'Edit the HTML content', { regions: ['editable'] }]
          }
        },

      snippetable: {
        _custom:               true,
        actions:               {
          editSnippet:         ['Edit Snippet Settings', null],
          sep1:                ' ',
          removeSnippet:       ['Remove Snippet', null]
          }
        }
      },


    // ## Behaviors
    //
    // Behaviors are used to change the default behaviors of a given region type when a given button is clicked.  For
    // example, you may prefer to add HR tags using an HR wrapped within a div with a classname (for styling).  You
    // can add your own complex behaviors here.
    //
    // You can see how the behavior matches up directly with the button name.  It's also important to note that the
    // callback functions are executed within the scope of the given region, so you have access to all it's methods.
    behaviors: {
      horizontalRule: function(selection) { selection.replace('<hr/>') },
      htmlEditor: function() { Mercury.modal('/mercury/modals/htmleditor.html', { title: 'HTML Editor', fullHeight: true, handler: 'htmlEditor' }) }
      },


    // ## Contexts
    //
    // Contexts are used callback functions used for highlighting and disabling/enabling buttons and buttongroups.
    // When the cursor enters an element within an html region for instance we want to disable or highlight buttons
    // based on the properties of the given node.  You can see some examples of contexts in:
    //
    // Mercury.Toolbar.Button.contexts
    // and
    // Mercury.Toolbar.ButtonGroup.contexts


    // ## Styles
    //
    // Mercury tries to stay as much out of your code as possible, but because regions appear within your document we
    // need to include a few styles to indicate regions, as well as the different states of them (eg. focused).  These
    // styles are injected into your document, and as simple as they might be, you may want to change them.  You can do
    // so here.
    injectedStyles: '' +
      '.mercury-region, .mercury-textarea { min-height: 10px; outline: 1px dotted #09F }' +
      '.mercury-textarea { box-sizing: border-box; -moz-box-sizing: border-box; -webkit-box-sizing: border-box; resize: vertical; }' +
      '.mercury-region:focus, .mercury-region.focus, .mercury-textarea.focus { outline: none; -webkit-box-shadow: 0 0 10px #09F, 0 0 1px #045; box-shadow: 0 0 10px #09F, 0 0 1px #045 }' +
      '.mercury-region:after { content: "."; display: block; visibility: hidden; clear: both; height: 0; overflow: hidden; }' +
      '.mercury-region table, .mercury-region td, .mercury-region th { border: 1px dotted red; }'
  },

  // ## Silent Mode
  //
  // Turning silent mode on will disable asking about unsaved changes before leaving the page.
  silent: false,

  // ## Debug Mode
  //
  // Turning debug mode on will log events and other various things (using console.debug if available).
  debug: false

};

if (!window.Mercury) window.Mercury = window.MercurySetup;
else if (typeof(jQuery) !== 'undefined') jQuery.extend(window.Mercury, window.MercurySetup);/*!
 * jQuery JavaScript Library v1.6
 * http://jquery.com/
 *
 * Copyright 2011, John Resig
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 * Copyright 2011, The Dojo Foundation
 * Released under the MIT, BSD, and GPL Licenses.
 *
 * Date: Mon May 2 13:50:00 2011 -0400
 */
(function(a,b){function k(a,c,d){if(d===b&&a.nodeType===1){name="data-"+c.replace(j,"$1-$2").toLowerCase(),d=a.getAttribute(name);if(typeof d=="string"){try{d=d==="true"?!0:d==="false"?!1:d==="null"?null:f.isNaN(d)?i.test(d)?f.parseJSON(d):d:parseFloat(d)}catch(e){}f.data(a,c,d)}else d=b}return d}function l(a){for(var b in a)if(b!=="toJSON")return!1;return!0}function m(a,c,d){var e=c+"defer",g=c+"queue",h=c+"mark",i=f.data(a,e,b,!0);i&&(d==="queue"||!f.data(a,g,b,!0))&&(d==="mark"||!f.data(a,h,b,!0))&&setTimeout(function(){!f.data(a,g,b,!0)&&!f.data(a,h,b,!0)&&(f.removeData(a,e,!0),i.resolve())},0)}function D(){return!1}function E(){return!0}function K(a,c,d){var e=f.extend({},d[0]);e.type=a,e.originalEvent={},e.liveFired=b,f.event.handle.call(c,e),e.isDefaultPrevented()&&d[0].preventDefault()}function M(a){var b,c,d,e,g,h,i,j,k,l,m,n,o,p=[],q=[],r=f._data(this,"events");if(a.liveFired===this||!r||!r.live||a.target.disabled||a.button&&a.type==="click")return;a.namespace&&(n=new RegExp("(^|\\.)"+a.namespace.split(".").join("\\.(?:.*\\.)?")+"(\\.|$)")),a.liveFired=this;var s=r.live.slice(0);for(i=0;i<s.length;i++)g=s[i],g.origType.replace(x,"")===a.type?q.push(g.selector):s.splice(i--,1);e=f(a.target).closest(q,a.currentTarget);for(j=0,k=e.length;j<k;j++){m=e[j];for(i=0;i<s.length;i++){g=s[i];if(m.selector===g.selector&&(!n||n.test(g.namespace))&&!m.elem.disabled){h=m.elem,d=null;if(g.preType==="mouseenter"||g.preType==="mouseleave")a.type=g.preType,d=f(a.relatedTarget).closest(g.selector)[0],d&&f.contains(h,d)&&(d=h);(!d||d!==h)&&p.push({elem:h,handleObj:g,level:m.level})}}}for(j=0,k=p.length;j<k;j++){e=p[j];if(c&&e.level>c)break;a.currentTarget=e.elem,a.data=e.handleObj.data,a.handleObj=e.handleObj,o=e.handleObj.origHandler.apply(e.elem,arguments);if(o===!1||a.isPropagationStopped()){c=e.level,o===!1&&(b=!1);if(a.isImmediatePropagationStopped())break}}return b}function N(a,b){return(a&&a!=="*"?a+".":"")+b.replace(z,"`").replace(A,"&")}function V(a){return!a||!a.parentNode||a.parentNode.nodeType===11}function W(a,b,c){b=b||0;if(f.isFunction(b))return f.grep(a,function(a,d){var e=!!b.call(a,d,a);return e===c});if(b.nodeType)return f.grep(a,function(a,d){return a===b===c});if(typeof b=="string"){var d=f.grep(a,function(a){return a.nodeType===1});if(R.test(b))return f.filter(b,d,!c);b=f.filter(b,d)}return f.grep(a,function(a,d){return f.inArray(a,b)>=0===c})}function bf(a,b){return f.nodeName(a,"table")?a.getElementsByTagName("tbody")[0]||a.appendChild(a.ownerDocument.createElement("tbody")):a}function bg(a,b){if(b.nodeType!==1||!f.hasData(a))return;var c=f.expando,d=f.data(a),e=f.data(b,d);if(d=d[c]){var g=d.events;e=e[c]=f.extend({},d);if(g){delete e.handle,e.events={};for(var h in g)for(var i=0,j=g[h].length;i<j;i++)f.event.add(b,h+(g[h][i].namespace?".":"")+g[h][i].namespace,g[h][i],g[h][i].data)}}}function bh(a,b){var c;if(b.nodeType!==1)return;b.clearAttributes&&b.clearAttributes(),b.mergeAttributes&&b.mergeAttributes(a),c=b.nodeName.toLowerCase();if(c==="object")b.outerHTML=a.outerHTML;else if(c!=="input"||a.type!=="checkbox"&&a.type!=="radio"){if(c==="option")b.selected=a.defaultSelected;else if(c==="input"||c==="textarea")b.defaultValue=a.defaultValue}else a.checked&&(b.defaultChecked=b.checked=a.checked),b.value!==a.value&&(b.value=a.value);b.removeAttribute(f.expando)}function bi(a){return"getElementsByTagName"in a?a.getElementsByTagName("*"):"querySelectorAll"in a?a.querySelectorAll("*"):[]}function bj(a){if(a.type==="checkbox"||a.type==="radio")a.defaultChecked=a.checked}function bk(a){f.nodeName(a,"input")?bj(a):a.getElementsByTagName&&f.grep(a.getElementsByTagName("input"),bj)}function bl(a,b){b.src?f.ajax({url:b.src,async:!1,dataType:"script"}):f.globalEval(b.text||b.textContent||b.innerHTML||""),b.parentNode&&b.parentNode.removeChild(b)}function bB(a,b,c){var d=b==="width"?bv:bw,e=b==="width"?a.offsetWidth:a.offsetHeight;return c==="border"?e:(f.each(d,function(){c||(e-=parseFloat(f.css(a,"padding"+this))||0),c==="margin"?e+=parseFloat(f.css(a,"margin"+this))||0:e-=parseFloat(f.css(a,"border"+this+"Width"))||0}),e)}function bX(a){return function(b,c){typeof b!="string"&&(c=b,b="*");if(f.isFunction(c)){var d=b.toLowerCase().split(bO),e=0,g=d.length,h,i,j;for(;e<g;e++)h=d[e],j=/^\+/.test(h),j&&(h=h.substr(1)||"*"),i=a[h]=a[h]||[],i[j?"unshift":"push"](c)}}}function bY(a,c,d,e,f,g){f=f||c.dataTypes[0],g=g||{},g[f]=!0;var h=a[f],i=0,j=h?h.length:0,k=a===bS,l;for(;i<j&&(k||!l);i++)l=h[i](c,d,e),typeof l=="string"&&(!k||g[l]?l=b:(c.dataTypes.unshift(l),l=bY(a,c,d,e,l,g)));return(k||!l)&&!g["*"]&&(l=bY(a,c,d,e,"*",g)),l}function bZ(a,b,c,d){if(f.isArray(b))f.each(b,function(b,e){c||bD.test(a)?d(a,e):bZ(a+"["+(typeof e=="object"||f.isArray(e)?b:"")+"]",e,c,d)});else if(!c&&b!=null&&typeof b=="object")for(var e in b)bZ(a+"["+e+"]",b[e],c,d);else d(a,b)}function b$(a,c,d){var e=a.contents,f=a.dataTypes,g=a.responseFields,h,i,j,k;for(i in g)i in d&&(c[g[i]]=d[i]);while(f[0]==="*")f.shift(),h===b&&(h=a.mimeType||c.getResponseHeader("content-type"));if(h)for(i in e)if(e[i]&&e[i].test(h)){f.unshift(i);break}if(f[0]in d)j=f[0];else{for(i in d){if(!f[0]||a.converters[i+" "+f[0]]){j=i;break}k||(k=i)}j=j||k}if(j)return j!==f[0]&&f.unshift(j),d[j]}function b_(a,c){a.dataFilter&&(c=a.dataFilter(c,a.dataType));var d=a.dataTypes,e={},g,h,i=d.length,j,k=d[0],l,m,n,o,p;for(g=1;g<i;g++){if(g===1)for(h in a.converters)typeof h=="string"&&(e[h.toLowerCase()]=a.converters[h]);l=k,k=d[g];if(k==="*")k=l;else if(l!=="*"&&l!==k){m=l+" "+k,n=e[m]||e["* "+k];if(!n){p=b;for(o in e){j=o.split(" ");if(j[0]===l||j[0]==="*"){p=e[j[1]+" "+k];if(p){o=e[o],o===!0?n=p:p===!0&&(n=o);break}}}}!n&&!p&&f.error("No conversion from "+m.replace(" "," to ")),n!==!0&&(c=n?n(c):p(o(c)))}}return c}function cf(){try{return new a.XMLHttpRequest}catch(b){}}function cg(){try{return new a.ActiveXObject("Microsoft.XMLHTTP")}catch(b){}}function cq(){return setTimeout(cr,0),co=f.now()}function cr(){co=b}function cs(a,b){var c={};return f.each(cn.concat.apply([],cn.slice(0,b)),function(){c[this]=a}),c}function ct(a){if(!ch[a]){var b=f("<"+a+">").appendTo("body"),d=b.css("display");b.remove();if(d==="none"||d===""){ci||(ci=c.createElement("iframe"),ci.frameBorder=ci.width=ci.height=0),c.body.appendChild(ci);if(!cj||!ci.createElement)cj=(ci.contentWindow||ci.contentDocument).document,cj.write("<!doctype><html><body></body></html>");b=cj.createElement(a),cj.body.appendChild(b),d=f.css(b,"display"),c.body.removeChild(ci)}ch[a]=d}return ch[a]}function cw(a){return f.isWindow(a)?a:a.nodeType===9?a.defaultView||a.parentWindow:!1}var c=a.document,d=a.navigator,e=a.location,f=function(){function H(){if(e.isReady)return;try{c.documentElement.doScroll("left")}catch(a){setTimeout(H,1);return}e.ready()}var e=function(a,b){return new e.fn.init(a,b,h)},f=a.jQuery,g=a.$,h,i=/^(?:[^<]*(<[\w\W]+>)[^>]*$|#([\w\-]*)$)/,j=/\S/,k=/^\s+/,l=/\s+$/,m=/\d/,n=/^<(\w+)\s*\/?>(?:<\/\1>)?$/,o=/^[\],:{}\s]*$/,p=/\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g,q=/"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g,r=/(?:^|:|,)(?:\s*\[)+/g,s=/(webkit)[ \/]([\w.]+)/,t=/(opera)(?:.*version)?[ \/]([\w.]+)/,u=/(msie) ([\w.]+)/,v=/(mozilla)(?:.*? rv:([\w.]+))?/,w=d.userAgent,x,y,z,A=Object.prototype.toString,B=Object.prototype.hasOwnProperty,C=Array.prototype.push,D=Array.prototype.slice,E=String.prototype.trim,F=Array.prototype.indexOf,G={};return e.fn=e.prototype={constructor:e,init:function(a,d,f){var g,h,j,k;if(!a)return this;if(a.nodeType)return this.context=this[0]=a,this.length=1,this;if(a==="body"&&!d&&c.body)return this.context=c,this[0]=c.body,this.selector=a,this.length=1,this;if(typeof a=="string"){a.charAt(0)==="<"&&a.charAt(a.length-1)===">"&&a.length>=3?g=[null,a,null]:g=i.exec(a);if(g&&(g[1]||!d)){if(g[1])return d=d instanceof e?d[0]:d,k=d?d.ownerDocument||d:c,j=n.exec(a),j?e.isPlainObject(d)?(a=[c.createElement(j[1])],e.fn.attr.call(a,d,!0)):a=[k.createElement(j[1])]:(j=e.buildFragment([g[1]],[k]),a=(j.cacheable?e.clone(j.fragment):j.fragment).childNodes),e.merge(this,a);h=c.getElementById(g[2]);if(h&&h.parentNode){if(h.id!==g[2])return f.find(a);this.length=1,this[0]=h}return this.context=c,this.selector=a,this}return!d||d.jquery?(d||f).find(a):this.constructor(d).find(a)}return e.isFunction(a)?f.ready(a):(a.selector!==b&&(this.selector=a.selector,this.context=a.context),e.makeArray(a,this))},selector:"",jquery:"1.6",length:0,size:function(){return this.length},toArray:function(){return D.call(this,0)},get:function(a){return a==null?this.toArray():a<0?this[this.length+a]:this[a]},pushStack:function(a,b,c){var d=this.constructor();return e.isArray(a)?C.apply(d,a):e.merge(d,a),d.prevObject=this,d.context=this.context,b==="find"?d.selector=this.selector+(this.selector?" ":"")+c:b&&(d.selector=this.selector+"."+b+"("+c+")"),d},each:function(a,b){return e.each(this,a,b)},ready:function(a){return e.bindReady(),y.done(a),this},eq:function(a){return a===-1?this.slice(a):this.slice(a,+a+1)},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},slice:function(){return this.pushStack(D.apply(this,arguments),"slice",D.call(arguments).join(","))},map:function(a){return this.pushStack(e.map(this,function(b,c){return a.call(b,c,b)}))},end:function(){return this.prevObject||this.constructor(null)},push:C,sort:[].sort,splice:[].splice},e.fn.init.prototype=e.fn,e.extend=e.fn.extend=function(){var a,c,d,f,g,h,i=arguments[0]||{},j=1,k=arguments.length,l=!1;typeof i=="boolean"&&(l=i,i=arguments[1]||{},j=2),typeof i!="object"&&!e.isFunction(i)&&(i={}),k===j&&(i=this,--j);for(;j<k;j++)if((a=arguments[j])!=null)for(c in a){d=i[c],f=a[c];if(i===f)continue;l&&f&&(e.isPlainObject(f)||(g=e.isArray(f)))?(g?(g=!1,h=d&&e.isArray(d)?d:[]):h=d&&e.isPlainObject(d)?d:{},i[c]=e.extend(l,h,f)):f!==b&&(i[c]=f)}return i},e.extend({noConflict:function(b){return a.$===e&&(a.$=g),b&&a.jQuery===e&&(a.jQuery=f),e},isReady:!1,readyWait:1,holdReady:function(a){a?e.readyWait++:e.ready(!0)},ready:function(a){if(a===!0&&!--e.readyWait||a!==!0&&!e.isReady){if(!c.body)return setTimeout(e.ready,1);e.isReady=!0;if(a!==!0&&--e.readyWait>0)return;y.resolveWith(c,[e]),e.fn.trigger&&e(c).trigger("ready").unbind("ready")}},bindReady:function(){if(y)return;y=e._Deferred();if(c.readyState==="complete")return setTimeout(e.ready,1);if(c.addEventListener)c.addEventListener("DOMContentLoaded",z,!1),a.addEventListener("load",e.ready,!1);else if(c.attachEvent){c.attachEvent("onreadystatechange",z),a.attachEvent("onload",e.ready);var b=!1;try{b=a.frameElement==null}catch(d){}c.documentElement.doScroll&&b&&H()}},isFunction:function(a){return e.type(a)==="function"},isArray:Array.isArray||function(a){return e.type(a)==="array"},isWindow:function(a){return a&&typeof a=="object"&&"setInterval"in a},isNaN:function(a){return a==null||!m.test(a)||isNaN(a)},type:function(a){return a==null?String(a):G[A.call(a)]||"object"},isPlainObject:function(a){if(!a||e.type(a)!=="object"||a.nodeType||e.isWindow(a))return!1;if(a.constructor&&!B.call(a,"constructor")&&!B.call(a.constructor.prototype,"isPrototypeOf"))return!1;var c;for(c in a);return c===b||B.call(a,c)},isEmptyObject:function(a){for(var b in a)return!1;return!0},error:function(a){throw a},parseJSON:function(b){if(typeof b!="string"||!b)return null;b=e.trim(b);if(a.JSON&&a.JSON.parse)return a.JSON.parse(b);if(o.test(b.replace(p,"@").replace(q,"]").replace(r,"")))return(new Function("return "+b))();e.error("Invalid JSON: "+b)},parseXML:function(b,c,d){return a.DOMParser?(d=new DOMParser,c=d.parseFromString(b,"text/xml")):(c=new ActiveXObject("Microsoft.XMLDOM"),c.async="false",c.loadXML(b)),d=c.documentElement,(!d||!d.nodeName||d.nodeName==="parsererror")&&e.error("Invalid XML: "+b),c},noop:function(){},globalEval:function(b){b&&j.test(b)&&(a.execScript||function(b){a.eval.call(a,b)})(b)},nodeName:function(a,b){return a.nodeName&&a.nodeName.toUpperCase()===b.toUpperCase()},each:function(a,c,d){var f,g=0,h=a.length,i=h===b||e.isFunction(a);if(d){if(i){for(f in a)if(c.apply(a[f],d)===!1)break}else for(;g<h;)if(c.apply(a[g++],d)===!1)break}else if(i){for(f in a)if(c.call(a[f],f,a[f])===!1)break}else for(;g<h;)if(c.call(a[g],g,a[g++])===!1)break;return a},trim:E?function(a){return a==null?"":E.call(a)}:function(a){return a==null?"":a.toString().replace(k,"").replace(l,"")},makeArray:function(a,b){var c=b||[];if(a!=null){var d=e.type(a);a.length==null||d==="string"||d==="function"||d==="regexp"||e.isWindow(a)?C.call(c,a):e.merge(c,a)}return c},inArray:function(a,b){if(F)return F.call(b,a);for(var c=0,d=b.length;c<d;c++)if(b[c]===a)return c;return-1},merge:function(a,c){var d=a.length,e=0;if(typeof c.length=="number")for(var f=c.length;e<f;e++)a[d++]=c[e];else while(c[e]!==b)a[d++]=c[e++];return a.length=d,a},grep:function(a,b,c){var d=[],e;c=!!c;for(var f=0,g=a.length;f<g;f++)e=!!b(a[f],f),c!==e&&d.push(a[f]);return d},map:function(a,c,d){var f,g,h=[],i=0,j=a.length,k=a instanceof e||j!==b&&typeof j=="number"&&(j>0&&a[0]&&a[j-1]||j===0||e.isArray(a));if(k)for(;i<j;i++)f=c(a[i],i,d),f!=null&&(h[h.length]=f);else for(g in a)f=c(a[g],g,d),f!=null&&(h[h.length]=f);return h.concat.apply([],h)},guid:1,proxy:function(a,c){if(typeof c=="string"){var d=a[c];c=a,a=d}if(!e.isFunction(a))return b;var f=D.call(arguments,2),g=function(){return a.apply(c,f.concat(D.call(arguments)))};return g.guid=a.guid=a.guid||g.guid||e.guid++,g},access:function(a,c,d,f,g,h){var i=a.length;if(typeof c=="object"){for(var j in c)e.access(a,j,c[j],f,g,d);return a}if(d!==b){f=!h&&f&&e.isFunction(d);for(var k=0;k<i;k++)g(a[k],c,f?d.call(a[k],k,g(a[k],c)):d,h);return a}return i?g(a[0],c):b},now:function(){return(new Date).getTime()},uaMatch:function(a){a=a.toLowerCase();var b=s.exec(a)||t.exec(a)||u.exec(a)||a.indexOf("compatible")<0&&v.exec(a)||[];return{browser:b[1]||"",version:b[2]||"0"}},sub:function(){function a(b,c){return new a.fn.init(b,c)}e.extend(!0,a,this),a.superclass=this,a.fn=a.prototype=this(),a.fn.constructor=a,a.sub=this.sub,a.fn.init=function d(c,d){return d&&d instanceof e&&!(d instanceof a)&&(d=a(d)),e.fn.init.call(this,c,d,b)},a.fn.init.prototype=a.fn;var b=a(c);return a},browser:{}}),e.each("Boolean Number String Function Array Date RegExp Object".split(" "),function(a,b){G["[object "+b+"]"]=b.toLowerCase()}),x=e.uaMatch(w),x.browser&&(e.browser[x.browser]=!0,e.browser.version=x.version),e.browser.webkit&&(e.browser.safari=!0),j.test(" ")&&(k=/^[\s\xA0]+/,l=/[\s\xA0]+$/),h=e(c),c.addEventListener?z=function(){c.removeEventListener("DOMContentLoaded",z,!1),e.ready()}:c.attachEvent&&(z=function(){c.readyState==="complete"&&(c.detachEvent("onreadystatechange",z),e.ready())}),e}(),g="done fail isResolved isRejected promise then always pipe".split(" "),h=[].slice;f.extend({_Deferred:function(){var a=[],b,c,d,e={done:function(){if(!d){var c=arguments,g,h,i,j,k;b&&(k=b,b=0);for(g=0,h=c.length;g<h;g++)i=c[g],j=f.type(i),j==="array"?e.done.apply(e,i):j==="function"&&a.push(i);k&&e.resolveWith(k[0],k[1])}return this},resolveWith:function(e,f){if(!d&&!b&&!c){f=f||[],c=1;try{while(a[0])a.shift().apply(e,f)}finally{b=[e,f],c=0}}return this},resolve:function(){return e.resolveWith(this,arguments),this},isResolved:function(){return!!c||!!b},cancel:function(){return d=1,a=[],this}};return e},Deferred:function(a){var b=f._Deferred(),c=f._Deferred(),d;return f.extend(b,{then:function(a,c){return b.done(a).fail(c),this},always:function(){return b.done.apply(b,arguments).fail.apply(this,arguments)},fail:c.done,rejectWith:c.resolveWith,reject:c.resolve,isRejected:c.isResolved,pipe:function(a,c){return f.Deferred(function(d){f.each({done:[a,"resolve"],fail:[c,"reject"]},function(a,c){var e=c[0],g=c[1],h;f.isFunction(e)?b[a](function(){h=e.apply(this,arguments),f.isFunction(h.promise)?h.promise().then(d.resolve,d.reject):d[g](h)}):b[a](d[g])})}).promise()},promise:function(a){if(a==null){if(d)return d;d=a={}}var c=g.length;while(c--)a[g[c]]=b[g[c]];return a}}),b.done(c.cancel).fail(b.cancel),delete b.cancel,a&&a.call(b,b),b},when:function(a){function i(a){return function(c){b[a]=arguments.length>1?h.call(arguments,0):c,--e||g.resolveWith(g,h.call(b,0))}}var b=arguments,c=0,d=b.length,e=d,g=d<=1&&a&&f.isFunction(a.promise)?a:f.Deferred();if(d>1){for(;c<d;c++)b[c]&&f.isFunction(b[c].promise)?b[c].promise().then(i(c),g.reject):--e;e||g.resolveWith(g,b)}else g!==a&&g.resolveWith(g,d?[a]:[]);return g.promise()}}),f.support=function(){var a=c.createElement("div"),b,d,e,f,g,h,i,j,k,l,m,n,o,p,q;a.setAttribute("className","t"),a.innerHTML="   <link/><table></table><a href='/a' style='top:1px;float:left;opacity:.55;'>a</a><input type='checkbox'/>",b=a.getElementsByTagName("*"),d=a.getElementsByTagName("a")[0];if(!b||!b.length||!d)return{};e=c.createElement("select"),f=e.appendChild(c.createElement("option")),g=a.getElementsByTagName("input")[0],i={leadingWhitespace:a.firstChild.nodeType===3,tbody:!a.getElementsByTagName("tbody").length,htmlSerialize:!!a.getElementsByTagName("link").length,style:/top/.test(d.getAttribute("style")),hrefNormalized:d.getAttribute("href")==="/a",opacity:/^0.55$/.test(d.style.opacity),cssFloat:!!d.style.cssFloat,checkOn:g.value==="on",optSelected:f.selected,getSetAttribute:a.className!=="t",submitBubbles:!0,changeBubbles:!0,focusinBubbles:!1,deleteExpando:!0,noCloneEvent:!0,inlineBlockNeedsLayout:!1,shrinkWrapBlocks:!1,reliableMarginRight:!0},g.checked=!0,i.noCloneChecked=g.cloneNode(!0).checked,e.disabled=!0,i.optDisabled=!f.disabled;try{delete a.test}catch(r){i.deleteExpando=!1}!a.addEventListener&&a.attachEvent&&a.fireEvent&&(a.attachEvent("onclick",function s(){i.noCloneEvent=!1,a.detachEvent("onclick",s)}),a.cloneNode(!0).fireEvent("onclick")),g=c.createElement("input"),g.value="t",g.setAttribute("type","radio"),i.radioValue=g.value==="t",g.setAttribute("checked","checked"),a.appendChild(g),j=c.createDocumentFragment(),j.appendChild(a.firstChild),i.checkClone=j.cloneNode(!0).cloneNode(!0).lastChild.checked,a.innerHTML="",a.style.width=a.style.paddingLeft="1px",k=c.createElement("body"),l={visibility:"hidden",width:0,height:0,border:0,margin:0,background:"none"};for(p in l)k.style[p]=l[p];k.appendChild(a),c.documentElement.appendChild(k),i.appendChecked=g.checked,i.boxModel=a.offsetWidth===2,"zoom"in a.style&&(a.style.display="inline",a.style.zoom=1,i.inlineBlockNeedsLayout=a.offsetWidth===2,a.style.display="",a.innerHTML="<div style='width:4px;'></div>",i.shrinkWrapBlocks=a.offsetWidth!==2),a.innerHTML="<table><tr><td style='padding:0;border:0;display:none'></td><td>t</td></tr></table>",m=a.getElementsByTagName("td"),q=m[0].offsetHeight===0,m[0].style.display="",m[1].style.display="none",i.reliableHiddenOffsets=q&&m[0].offsetHeight===0,a.innerHTML="",c.defaultView&&c.defaultView.getComputedStyle&&(h=c.createElement("div"),h.style.width="0",h.style.marginRight="0",a.appendChild(h),i.reliableMarginRight=(parseInt(c.defaultView.getComputedStyle(h,null).marginRight,10)||0)===0),k.innerHTML="",c.documentElement.removeChild(k);if(a.attachEvent)for(p in{submit:1,change:1,focusin:1})o="on"+p,q=o in a,q||(a.setAttribute(o,"return;"),q=typeof a[o]=="function"),i[p+"Bubbles"]=q;return i}(),f.boxModel=f.support.boxModel;var i=/^(?:\{.*\}|\[.*\])$/,j=/([a-z])([A-Z])/g;f.extend({cache:{},uuid:0,expando:"jQuery"+(f.fn.jquery+Math.random()).replace(/\D/g,""),noData:{embed:!0,object:"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000",applet:!0},hasData:function(a){return a=a.nodeType?f.cache[a[f.expando]]:a[f.expando],!!a&&!l(a)},data:function(a,c,d,e){if(!f.acceptData(a))return;var g=f.expando,h=typeof c=="string",i,j=a.nodeType,k=j?f.cache:a,l=j?a[f.expando]:a[f.expando]&&f.expando;if((!l||e&&l&&!k[l][g])&&h&&d===b)return;l||(j?a[f.expando]=l=++f.uuid:l=f.expando),k[l]||(k[l]={},j||(k[l].toJSON=f.noop));if(typeof c=="object"||typeof c=="function")e?k[l][g]=f.extend(k[l][g],c):k[l]=f.extend(k[l],c);return i=k[l],e&&(i[g]||(i[g]={}),i=i[g]),d!==b&&(i[c]=d),c==="events"&&!i[c]?i[g]&&i[g].events:h?i[c]:i},removeData:function(b,c,d){if(!f.acceptData(b))return;var e=f.expando,g=b.nodeType,h=g?f.cache:b,i=g?b[f.expando]:f.expando;if(!h[i])return;if(c){var j=d?h[i][e]:h[i];if(j){delete j[c];if(!l(j))return}}if(d){delete h[i][e];if(!l(h[i]))return}var k=h[i][e];f.support.deleteExpando||h!=a?delete h[i]:h[i]=null,k?(h[i]={},g||(h[i].toJSON=f.noop),h[i][e]=k):g&&(f.support.deleteExpando?delete b[f.expando]:b.removeAttribute?b.removeAttribute(f.expando):b[f.expando]=null)},_data:function(a,b,c){return f.data(a,b,c,!0)},acceptData:function(a){if(a.nodeName){var b=f.noData[a.nodeName.toLowerCase()];if(b)return b!==!0&&a.getAttribute("classid")===b}return!0}}),f.fn.extend({data:function(a,c){var d=null;if(typeof a=="undefined"){if(this.length){d=f.data(this[0]);if(this[0].nodeType===1){var e=this[0].attributes,g;for(var h=0,i=e.length;h<i;h++)g=e[h].name,g.indexOf("data-")===0&&(g=f.camelCase(g.substring(5)),k(this[0],g,d[g]))}}return d}if(typeof a=="object")return this.each(function(){f.data(this,a)});var j=a.split(".");return j[1]=j[1]?"."+j[1]:"",c===b?(d=this.triggerHandler("getData"+j[1]+"!",[j[0]]),d===b&&this.length&&(d=f.data(this[0],a),d=k(this[0],a,d)),d===b&&j[1]?this.data(j[0]):d):this.each(function(){var b=f(this),d=[j[0],c];b.triggerHandler("setData"+j[1]+"!",d),f.data(this,a,c),b.triggerHandler("changeData"+j[1]+"!",d)})},removeData:function(a){return this.each(function(){f.removeData(this,a)})}}),f.extend({_mark:function(a,c){a&&(c=(c||"fx")+"mark",f.data(a,c,(f.data(a,c,b,!0)||0)+1,!0))},_unmark:function(a,c,d){a!==!0&&(d=c,c=a,a=!1);if(c){d=d||"fx";var e=d+"mark",g=a?0:(f.data(c,e,b,!0)||1)-1;g?f.data(c,e,g,!0):(f.removeData(c,e,!0),m(c,d,"mark"))}},queue:function(a,c,d){if(a){c=(c||"fx")+"queue";var e=f.data(a,c,b,!0);return d&&(!e||f.isArray(d)?e=f.data(a,c,f.makeArray(d),!0):e.push(d)),e||[]}},dequeue:function(a,b){b=b||"fx";var c=f.queue(a,b),d=c.shift(),e;d==="inprogress"&&(d=c.shift()),d&&(b==="fx"&&c.unshift("inprogress"),d.call(a,function(){f.dequeue(a,b)})),c.length||(f.removeData(a,b+"queue",!0),m(a,b,"queue"))}}),f.fn.extend({queue:function(a,c){return typeof a!="string"&&(c=a,a="fx"),c===b?f.queue(this[0],a):this.each(function(){var b=f.queue(this,a,c);a==="fx"&&b[0]!=="inprogress"&&f.dequeue(this,a)})},dequeue:function(a){return this.each(function(){f.dequeue(this,a)})},delay:function(a,b){return a=f.fx?f.fx.speeds[a]||a:a,b=b||"fx",this.queue(b,function(){var c=this;setTimeout(function(){f.dequeue(c,b)},a)})},clearQueue:function(a){return this.queue(a||"fx",[])},promise:function(a,c){function l(){--h||d.resolveWith(e,[e])}typeof a!="string"&&(c=a,a=b),a=a||"fx";var d=f.Deferred(),e=this,g=e.length,h=1,i=a+"defer",j=a+"queue",k=a+"mark";while(g--)if(tmp=f.data(e[g],i,b,!0)||(f.data(e[g],j,b,!0)||f.data(e[g],k,b,!0))&&f.data(e[g],i,f._Deferred(),!0))h++,tmp.done(l);return l(),d.promise()}});var n=/[\n\t\r]/g,o=/\s+/,p=/\r/g,q=/^(?:button|input)$/i,r=/^(?:button|input|object|select|textarea)$/i,s=/^a(?:rea)?$/i,t=/^(?:data-|aria-)/,u=/\:/,v;f.fn.extend({attr:function(a,b){return f.access(this,a,b,!0,f.attr)},removeAttr:function(a){return this.each(function(){f.removeAttr(this,a)})},prop:function(a,b){return f.access(this,a,b,!0,f.prop)},removeProp:function(a){return this.each(function(){try{this[a]=b,delete this[a]}catch(c){}})},addClass:function(a){if(f.isFunction(a))return this.each(function(b){var c=f(this);c.addClass(a.call(this,b,c.attr("class")||""))});if(a&&typeof a=="string"){var b=(a||"").split(o);for(var c=0,d=this.length;c<d;c++){var e=this[c];if(e.nodeType===1)if(!e.className)e.className=a;else{var g=" "+e.className+" ",h=e.className;for(var i=0,j=b.length;i<j;i++)g.indexOf(" "+b[i]+" ")<0&&(h+=" "+b[i]);e.className=f.trim(h)}}}return this},removeClass:function(a){if(f.isFunction(a))return this.each(function(b){var c=f(this);c.removeClass(a.call(this,b,c.attr("class")))});if(a&&typeof a=="string"||a===b){var c=(a||"").split(o);for(var d=0,e=this.length;d<e;d++){var g=this[d];if(g.nodeType===1&&g.className)if(a){var h=(" "+g.className+" ").replace(n," ");for(var i=0,j=c.length;i<j;i++)h=h.replace(" "+c[i]+" "," ");g.className=f.trim(h)}else g.className=""}}return this},toggleClass:function(a,b){var c=typeof a,d=typeof b=="boolean";return f.isFunction(a)?this.each(function(c){var d=f(this);d.toggleClass(a.call(this,c,d.attr("class"),b),b)}):this.each(function(){if(c==="string"){var e,g=0,h=f(this),i=b,j=a.split(o);while(e=j[g++])i=d?i:!h.hasClass(e),h[i?"addClass":"removeClass"](e)}else if(c==="undefined"||c==="boolean")this.className&&f._data(this,"__className__",this.className),this.className=this.className||a===!1?"":f._data(this,"__className__")||""})},hasClass:function(a){var b=" "+a+" ";for(var c=0,d=this.length;c<d;c++)if((" "+this[c].className+" ").replace(n," ").indexOf(b)>-1)return!0;return!1},val:function(a){var c,d,e=this[0];if(!arguments.length)return e?(c=f.valHooks[e.nodeName.toLowerCase()]||f.valHooks[e.type],c&&"get"in c&&(d=c.get(e,"value"))!==b?d:(e.value||"").replace(p,"")):b;var g=f.isFunction(a);return this.each(function(d){var e=f(this),h;if(this.nodeType!==1)return;g?h=a.call(this,d,e.val()):h=a,h==null?h="":typeof h=="number"?h+="":f.isArray(h)&&(h=f.map(h,function(a){return a==null?"":a+""})),c=f.valHooks[this.nodeName.toLowerCase()]||f.valHooks[this.type];if(!c||"set"in c&&c.set(this,h,"value")===b)this.value=h})}}),f.extend({valHooks:{option:{get:function(a){var b=a.attributes.value;return!b||b.specified?a.value:a.text}},select:{get:function(a){var b=a.selectedIndex,c=[],d=a.options,e=a.type==="select-one";if(b<0)return null;for(var g=e?b:0,h=e?b+1:d.length;g<h;g++){var i=d[g];if(i.selected&&(f.support.optDisabled?!i.disabled:i.getAttribute("disabled")===null)&&(!i.parentNode.disabled||!f.nodeName(i.parentNode,"optgroup"))){value=f(i).val();if(e)return value;c.push(value)}}return e&&!c.length&&d.length?f(d[b]).val():c},set:function(a,b){var c=f.makeArray(b);return f(a).find("option").each(function(){this.selected=f.inArray(f(this).val(),c)>=0}),c.length||(a.selectedIndex=-1),c}}},attrFn:{val:!0,css:!0,html:!0,text:!0,data:!0,width:!0,height:!0,offset:!0},attrFix:{tabindex:"tabIndex",readonly:"readOnly"},attr:function(a,c,d,e){var g=a.nodeType;if(!a||g===3||g===8||g===2)return b;if(e&&c in f.attrFn)return f(a)[c](d);var h,i,j=g!==1||!f.isXMLDoc(a);return c=j&&f.attrFix[c]||c,i=f.attrHooks[c]||(v&&(f.nodeName(a,"form")||u.test(c))?v:b),d!==b?d===null||d===!1&&!t.test(c)?(f.removeAttr(a,c),b):i&&"set"in i&&j&&(h=i.set(a,d,c))!==b?h:(d===!0&&!t.test(c)&&(d=c),a.setAttribute(c,""+d),d):i&&"get"in i&&j?i.get(a,c):(h=a.getAttribute(c),h===null?b:h)},removeAttr:function(a,b){a.nodeType===1&&(b=f.attrFix[b]||b,f.support.getSetAttribute?a.removeAttribute(b):(f.attr(a,b,""),a.removeAttributeNode(a.getAttributeNode(b))))},attrHooks:{type:{set:function(a,b){if(q.test(a.nodeName)&&a.parentNode)f.error("type property can't be changed");else if(!f.support.radioValue&&b==="radio"&&f.nodeName(a,"input")){var c=a.getAttribute("value");return a.setAttribute("type",b),c&&(a.value=c),b}}},tabIndex:{get:function(a){var c=a.getAttributeNode("tabIndex");return c&&c.specified?parseInt(c.value,10):r.test(a.nodeName)||s.test(a.nodeName)&&a.href?0:b}}},propFix:{},prop:function(a,c,d){var e=a.nodeType;if(!a||e===3||e===8||e===2)return b;var g,h,i=e!==1||!f.isXMLDoc(a);return c=i&&f.propFix[c]||c,h=f.propHooks[c],d!==b?h&&"set"in h&&(g=h.set(a,d,c))!==b?g:a[c]=d:h&&"get"in h&&(g=h.get(a,c))!==b?g:a[c]},propHooks:{}}),f.support.getSetAttribute||(f.attrFix=f.extend(f.attrFix,{"for":"htmlFor","class":"className",maxlength:"maxLength",cellspacing:"cellSpacing",cellpadding:"cellPadding",rowspan:"rowSpan",colspan:"colSpan",usemap:"useMap",frameborder:"frameBorder"}),v=f.attrHooks.name=f.attrHooks.value=f.valHooks.button={get:function(a,c){var d;return c==="value"&&!f.nodeName(a,"button")?a.getAttribute(c):(d=a.getAttributeNode(c),d&&d.specified?d.nodeValue:b)},set:function(a,b,c){var d=a.getAttributeNode(c);if(d)return d.nodeValue=b,b}},f.each(["width","height"],function(a,b){f.attrHooks[b]=f.extend(f.attrHooks[b],{set:function(a,c){if(c==="")return a.setAttribute(b,"auto"),c}})})),f.support.hrefNormalized||f.each(["href","src","width","height"],function(a,c){f.attrHooks[c]=f.extend(f.attrHooks[c],{get:function(a){var d=a.getAttribute(c,2);return d===null?b:d}})}),f.support.style||(f.attrHooks.style={get:function(a){return a.style.cssText.toLowerCase()||b},set:function(a,b){return a.style.cssText=""+b}}),f.support.optSelected||(f.propHooks.selected=f.extend(f.propHooks.selected,{get:function(a){var b=a.parentNode;b&&(b.selectedIndex,b.parentNode&&b.parentNode.selectedIndex)}})),f.support.checkOn||f.each(["radio","checkbox"],function(){f.valHooks[this]={get:function(a){return a.getAttribute("value")===null?"on":a.value}}}),f.each(["radio","checkbox"],function(){f.valHooks[this]=f.extend(f.valHooks[this],{set:function(a,b){if(f.isArray(b))return a.checked=f.inArray(f(a).val(),b)>=0}})});var w=Object.prototype.hasOwnProperty,x=/\.(.*)$/,y=/^(?:textarea|input|select)$/i,z=/\./g,A=/ /g,B=/[^\w\s.|`]/g,C=function(a){return a.replace(B,"\\$&")};f.event={add:function(a,c,d,e){if(a.nodeType===3||a.nodeType===8)return;if(d===!1)d=D;else if(!d)return;var g,h;d.handler&&(g=d,d=g.handler),d.guid||(d.guid=f.guid++);var i=f._data(a);if(!i)return;var j=i.events,k=i.handle;j||(i.events=j={}),k||(i.handle=k=function(a){return typeof f!="undefined"&&(!a||f.event.triggered!==a.type)?f.event.handle.apply(k.elem,arguments):b}),k.elem=a,c=c.split(" ");var l,m=0,n;while(l=c[m++]){h=g?f.extend({},g):{handler:d,data:e},l.indexOf(".")>-1?(n=l.split("."),l=n.shift(),h.namespace=n.slice(0).sort().join(".")):(n=[],h.namespace=""),h.type=l,h.guid||(h.guid=d.guid);var o=j[l],p=f.event.special[l]||{};if(!o){o=j[l]=[];if(!p.setup||p.setup.call(a,e,n,k)===!1)a.addEventListener?a.addEventListener(l,k,!1):a.attachEvent&&a.attachEvent("on"+l,k)}p.add&&(p.add.call(a,h),h.handler.guid||(h.handler.guid=d.guid)),o.push(h),f.event.global[l]=!0}a=null},global:{},remove:function(a,c,d,e){if(a.nodeType===3||a.nodeType===8)return;d===!1&&(d=D);var g,h,i,j,k=0,l,m,n,o,p,q,r,s=f.hasData(a)&&f._data(a),t=s&&s.events;if(!s||!t)return;c&&c.type&&(d=c.handler,c=c.type);if(!c||typeof c=="string"&&c.charAt(0)==="."){c=c||"";for(h in t)f.event.remove(a,h+c);return}c=c.split(" ");while(h=c[k++]){r=h,q=null,l=h.indexOf(".")<0,m=[],l||(m=h.split("."),h=m.shift(),n=new RegExp("(^|\\.)"+f.map(m.slice(0).sort(),C).join("\\.(?:.*\\.)?")+"(\\.|$)")),p=t[h];if(!p)continue;if(!d){for(j=0;j<p.length;j++){q=p[j];if(l||n.test(q.namespace))f.event.remove(a,r,q.handler,j),p.splice(j--,1)}continue}o=f.event.special[h]||{};for(j=e||0;j<p.length;j++){q=p[j];if(d.guid===q.guid){if(l||n.test(q.namespace))e==null&&p.splice(j--,1),o.remove&&o.remove.call(a,q);if(e!=null)break}}if(p.length===0||e!=null&&p.length===1)(!o.teardown||o.teardown.call(a,m)===!1)&&f.removeEvent(a,h,s.handle),g=null,delete t[h]}if(f.isEmptyObject(t)){var u=s.handle;u&&(u.elem=null),delete s.events,delete s.handle,f.isEmptyObject(s)&&f.removeData(a,b,!0)}},customEvent:{getData:!0,setData:!0,changeData:!0},trigger:function(c,d,e,g){var h=c.type||c,i=[],j;h.indexOf("!")>=0&&(h=h.slice(0,-1),j=!0),h.indexOf(".")>=0&&(i=h.split("."),h=i.shift(),i.sort());if((!e||f.event.customEvent[h])&&!f.event.global[h])return;c=typeof c=="object"?c[f.expando]?c:new f.Event(h,c):new f.Event(h),c.type=h,c.exclusive=j,c.namespace=i.join("."),c.namespace_re=new RegExp("(^|\\.)"+i.join("\\.(?:.*\\.)?")+"(\\.|$)");if(g||!e)c.preventDefault(),c.stopPropagation();if(!e){f.each(f.cache,function(){var a=f.expando,b=this[a];b&&b.events&&b.events[h]&&f.event.trigger(c,d,b.handle.elem)});return}if(e.nodeType===3||e.nodeType===8)return;c.result=b,c.target=e,d=d?f.makeArray(d):[],d.unshift(c);var k=e,l=h.indexOf(":")<0?"on"+h:"";do{var m=f._data(k,"handle");c.currentTarget=k,m&&m.apply(k,d),l&&f.acceptData(k)&&k[l]&&k[l].apply(k,d)===!1&&(c.result=!1,c.preventDefault()),k=k.parentNode||k.ownerDocument||k===c.target.ownerDocument&&a}while(k&&!c.isPropagationStopped());if(!c.isDefaultPrevented()){var n,o=f.event.special[h]||{};if((!o._default||o._default.call(e.ownerDocument,c)===!1)&&(h!=="click"||!f.nodeName(e,"a"))&&f.acceptData(e)){try{l&&e[h]&&(n=e[l],n&&(e[l]=null),f.event.triggered=h,e[h]())}catch(p){}n&&(e[l]=n),f.event.triggered=b}}return c.result},handle:function(c){c=f.event.fix(c||a.event);var d=((
f._data(this,"events")||{})[c.type]||[]).slice(0),e=!c.exclusive&&!c.namespace,g=Array.prototype.slice.call(arguments,0);g[0]=c,c.currentTarget=this;for(var h=0,i=d.length;h<i;h++){var j=d[h];if(e||c.namespace_re.test(j.namespace)){c.handler=j.handler,c.data=j.data,c.handleObj=j;var k=j.handler.apply(this,g);k!==b&&(c.result=k,k===!1&&(c.preventDefault(),c.stopPropagation()));if(c.isImmediatePropagationStopped())break}}return c.result},props:"altKey attrChange attrName bubbles button cancelable charCode clientX clientY ctrlKey currentTarget data detail eventPhase fromElement handler keyCode layerX layerY metaKey newValue offsetX offsetY pageX pageY prevValue relatedNode relatedTarget screenX screenY shiftKey srcElement target toElement view wheelDelta which".split(" "),fix:function(a){if(a[f.expando])return a;var d=a;a=f.Event(d);for(var e=this.props.length,g;e;)g=this.props[--e],a[g]=d[g];a.target||(a.target=a.srcElement||c),a.target.nodeType===3&&(a.target=a.target.parentNode),!a.relatedTarget&&a.fromElement&&(a.relatedTarget=a.fromElement===a.target?a.toElement:a.fromElement);if(a.pageX==null&&a.clientX!=null){var h=a.target.ownerDocument||c,i=h.documentElement,j=h.body;a.pageX=a.clientX+(i&&i.scrollLeft||j&&j.scrollLeft||0)-(i&&i.clientLeft||j&&j.clientLeft||0),a.pageY=a.clientY+(i&&i.scrollTop||j&&j.scrollTop||0)-(i&&i.clientTop||j&&j.clientTop||0)}return a.which==null&&(a.charCode!=null||a.keyCode!=null)&&(a.which=a.charCode!=null?a.charCode:a.keyCode),!a.metaKey&&a.ctrlKey&&(a.metaKey=a.ctrlKey),!a.which&&a.button!==b&&(a.which=a.button&1?1:a.button&2?3:a.button&4?2:0),a},guid:1e8,proxy:f.proxy,special:{ready:{setup:f.bindReady,teardown:f.noop},live:{add:function(a){f.event.add(this,N(a.origType,a.selector),f.extend({},a,{handler:M,guid:a.handler.guid}))},remove:function(a){f.event.remove(this,N(a.origType,a.selector),a)}},beforeunload:{setup:function(a,b,c){f.isWindow(this)&&(this.onbeforeunload=c)},teardown:function(a,b){this.onbeforeunload===b&&(this.onbeforeunload=null)}}}},f.removeEvent=c.removeEventListener?function(a,b,c){a.removeEventListener&&a.removeEventListener(b,c,!1)}:function(a,b,c){a.detachEvent&&a.detachEvent("on"+b,c)},f.Event=function(a,b){if(!this.preventDefault)return new f.Event(a,b);a&&a.type?(this.originalEvent=a,this.type=a.type,this.isDefaultPrevented=a.defaultPrevented||a.returnValue===!1||a.getPreventDefault&&a.getPreventDefault()?E:D):this.type=a,b&&f.extend(this,b),this.timeStamp=f.now(),this[f.expando]=!0},f.Event.prototype={preventDefault:function(){this.isDefaultPrevented=E;var a=this.originalEvent;if(!a)return;a.preventDefault?a.preventDefault():a.returnValue=!1},stopPropagation:function(){this.isPropagationStopped=E;var a=this.originalEvent;if(!a)return;a.stopPropagation&&a.stopPropagation(),a.cancelBubble=!0},stopImmediatePropagation:function(){this.isImmediatePropagationStopped=E,this.stopPropagation()},isDefaultPrevented:D,isPropagationStopped:D,isImmediatePropagationStopped:D};var F=function(a){var b=a.relatedTarget;try{if(b&&b!==c&&!b.parentNode)return;while(b&&b!==this)b=b.parentNode;b!==this&&(a.type=a.data,f.event.handle.apply(this,arguments))}catch(d){}},G=function(a){a.type=a.data,f.event.handle.apply(this,arguments)};f.each({mouseenter:"mouseover",mouseleave:"mouseout"},function(a,b){f.event.special[a]={setup:function(c){f.event.add(this,b,c&&c.selector?G:F,a)},teardown:function(a){f.event.remove(this,b,a&&a.selector?G:F)}}}),f.support.submitBubbles||(f.event.special.submit={setup:function(a,b){if(!f.nodeName(this,"form"))f.event.add(this,"click.specialSubmit",function(a){var b=a.target,c=b.type;(c==="submit"||c==="image")&&f(b).closest("form").length&&K("submit",this,arguments)}),f.event.add(this,"keypress.specialSubmit",function(a){var b=a.target,c=b.type;(c==="text"||c==="password")&&f(b).closest("form").length&&a.keyCode===13&&K("submit",this,arguments)});else return!1},teardown:function(a){f.event.remove(this,".specialSubmit")}});if(!f.support.changeBubbles){var H,I=function(a){var b=a.type,c=a.value;return b==="radio"||b==="checkbox"?c=a.checked:b==="select-multiple"?c=a.selectedIndex>-1?f.map(a.options,function(a){return a.selected}).join("-"):"":f.nodeName(a,"select")&&(c=a.selectedIndex),c},J=function(a){var c=a.target,d,e;if(!y.test(c.nodeName)||c.readOnly)return;d=f._data(c,"_change_data"),e=I(c),(a.type!=="focusout"||c.type!=="radio")&&f._data(c,"_change_data",e);if(d===b||e===d)return;if(d!=null||e)a.type="change",a.liveFired=b,f.event.trigger(a,arguments[1],c)};f.event.special.change={filters:{focusout:J,beforedeactivate:J,click:function(a){var b=a.target,c=f.nodeName(b,"input")?b.type:"";(c==="radio"||c==="checkbox"||f.nodeName(b,"select"))&&J.call(this,a)},keydown:function(a){var b=a.target,c=f.nodeName(b,"input")?b.type:"";(a.keyCode===13&&!f.nodeName(b,"textarea")||a.keyCode===32&&(c==="checkbox"||c==="radio")||c==="select-multiple")&&J.call(this,a)},beforeactivate:function(a){var b=a.target;f._data(b,"_change_data",I(b))}},setup:function(a,b){if(this.type==="file")return!1;for(var c in H)f.event.add(this,c+".specialChange",H[c]);return y.test(this.nodeName)},teardown:function(a){return f.event.remove(this,".specialChange"),y.test(this.nodeName)}},H=f.event.special.change.filters,H.focus=H.beforeactivate}f.support.focusinBubbles||f.each({focus:"focusin",blur:"focusout"},function(a,b){function e(a){var c=f.event.fix(a);c.type=b,c.originalEvent={},f.event.trigger(c,null,c.target),c.isDefaultPrevented()&&a.preventDefault()}var d=0;f.event.special[b]={setup:function(){d++===0&&c.addEventListener(a,e,!0)},teardown:function(){--d===0&&c.removeEventListener(a,e,!0)}}}),f.each(["bind","one"],function(a,c){f.fn[c]=function(a,d,e){var g;if(typeof a=="object"){for(var h in a)this[c](h,d,a[h],e);return this}if(arguments.length===2||d===!1)e=d,d=b;c==="one"?(g=function(a){return f(this).unbind(a,g),e.apply(this,arguments)},g.guid=e.guid||f.guid++):g=e;if(a==="unload"&&c!=="one")this.one(a,d,e);else for(var i=0,j=this.length;i<j;i++)f.event.add(this[i],a,g,d);return this}}),f.fn.extend({unbind:function(a,b){if(typeof a=="object"&&!a.preventDefault)for(var c in a)this.unbind(c,a[c]);else for(var d=0,e=this.length;d<e;d++)f.event.remove(this[d],a,b);return this},delegate:function(a,b,c,d){return this.live(b,c,d,a)},undelegate:function(a,b,c){return arguments.length===0?this.unbind("live"):this.die(b,null,c,a)},trigger:function(a,b){return this.each(function(){f.event.trigger(a,b,this)})},triggerHandler:function(a,b){if(this[0])return f.event.trigger(a,b,this[0],!0)},toggle:function(a){var b=arguments,c=a.guid||f.guid++,d=0,e=function(c){var e=(f.data(this,"lastToggle"+a.guid)||0)%d;return f.data(this,"lastToggle"+a.guid,e+1),c.preventDefault(),b[e].apply(this,arguments)||!1};e.guid=c;while(d<b.length)b[d++].guid=c;return this.click(e)},hover:function(a,b){return this.mouseenter(a).mouseleave(b||a)}});var L={focus:"focusin",blur:"focusout",mouseenter:"mouseover",mouseleave:"mouseout"};f.each(["live","die"],function(a,c){f.fn[c]=function(a,d,e,g){var h,i=0,j,k,l,m=g||this.selector,n=g?this:f(this.context);if(typeof a=="object"&&!a.preventDefault){for(var o in a)n[c](o,d,a[o],m);return this}if(c==="die"&&!a&&g&&g.charAt(0)===".")return n.unbind(g),this;if(d===!1||f.isFunction(d))e=d||D,d=b;a=(a||"").split(" ");while((h=a[i++])!=null){j=x.exec(h),k="",j&&(k=j[0],h=h.replace(x,""));if(h==="hover"){a.push("mouseenter"+k,"mouseleave"+k);continue}l=h,L[h]?(a.push(L[h]+k),h=h+k):h=(L[h]||h)+k;if(c==="live")for(var p=0,q=n.length;p<q;p++)f.event.add(n[p],"live."+N(h,m),{data:d,selector:m,handler:e,origType:h,origHandler:e,preType:l});else n.unbind("live."+N(h,m),e)}return this}}),f.each("blur focus focusin focusout load resize scroll unload click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup error".split(" "),function(a,b){f.fn[b]=function(a,c){return c==null&&(c=a,a=null),arguments.length>0?this.bind(b,a,c):this.trigger(b)},f.attrFn&&(f.attrFn[b]=!0)}),function(){function t(a,b,c,d,e,f){for(var g=0,h=d.length;g<h;g++){var i=d[g];if(i){var j=!1;i=i[a];while(i){if(i.sizcache===c){j=d[i.sizset];break}i.nodeType===1&&!f&&(i.sizcache=c,i.sizset=g);if(i.nodeName.toLowerCase()===b){j=i;break}i=i[a]}d[g]=j}}}function u(a,b,c,d,e,f){for(var g=0,h=d.length;g<h;g++){var i=d[g];if(i){var j=!1;i=i[a];while(i){if(i.sizcache===c){j=d[i.sizset];break}if(i.nodeType===1){f||(i.sizcache=c,i.sizset=g);if(typeof b!="string"){if(i===b){j=!0;break}}else if(k.filter(b,[i]).length>0){j=i;break}}i=i[a]}d[g]=j}}}var a=/((?:\((?:\([^()]+\)|[^()]+)+\)|\[(?:\[[^\[\]]*\]|['"][^'"]*['"]|[^\[\]'"]+)+\]|\\.|[^ >+~,(\[\\]+)+|[>+~])(\s*,\s*)?((?:.|\r|\n)*)/g,d=0,e=Object.prototype.toString,g=!1,h=!0,i=/\\/g,j=/\W/;[0,0].sort(function(){return h=!1,0});var k=function(b,d,f,g){f=f||[],d=d||c;var h=d;if(d.nodeType!==1&&d.nodeType!==9)return[];if(!b||typeof b!="string")return f;var i,j,n,o,q,r,s,t,u=!0,w=k.isXML(d),x=[],y=b;do{a.exec(""),i=a.exec(y);if(i){y=i[3],x.push(i[1]);if(i[2]){o=i[3];break}}}while(i);if(x.length>1&&m.exec(b))if(x.length===2&&l.relative[x[0]])j=v(x[0]+x[1],d);else{j=l.relative[x[0]]?[d]:k(x.shift(),d);while(x.length)b=x.shift(),l.relative[b]&&(b+=x.shift()),j=v(b,j)}else{!g&&x.length>1&&d.nodeType===9&&!w&&l.match.ID.test(x[0])&&!l.match.ID.test(x[x.length-1])&&(q=k.find(x.shift(),d,w),d=q.expr?k.filter(q.expr,q.set)[0]:q.set[0]);if(d){q=g?{expr:x.pop(),set:p(g)}:k.find(x.pop(),x.length===1&&(x[0]==="~"||x[0]==="+")&&d.parentNode?d.parentNode:d,w),j=q.expr?k.filter(q.expr,q.set):q.set,x.length>0?n=p(j):u=!1;while(x.length)r=x.pop(),s=r,l.relative[r]?s=x.pop():r="",s==null&&(s=d),l.relative[r](n,s,w)}else n=x=[]}n||(n=j),n||k.error(r||b);if(e.call(n)==="[object Array]")if(!u)f.push.apply(f,n);else if(d&&d.nodeType===1)for(t=0;n[t]!=null;t++)n[t]&&(n[t]===!0||n[t].nodeType===1&&k.contains(d,n[t]))&&f.push(j[t]);else for(t=0;n[t]!=null;t++)n[t]&&n[t].nodeType===1&&f.push(j[t]);else p(n,f);return o&&(k(o,h,f,g),k.uniqueSort(f)),f};k.uniqueSort=function(a){if(r){g=h,a.sort(r);if(g)for(var b=1;b<a.length;b++)a[b]===a[b-1]&&a.splice(b--,1)}return a},k.matches=function(a,b){return k(a,null,null,b)},k.matchesSelector=function(a,b){return k(b,null,null,[a]).length>0},k.find=function(a,b,c){var d;if(!a)return[];for(var e=0,f=l.order.length;e<f;e++){var g,h=l.order[e];if(g=l.leftMatch[h].exec(a)){var j=g[1];g.splice(1,1);if(j.substr(j.length-1)!=="\\"){g[1]=(g[1]||"").replace(i,""),d=l.find[h](g,b,c);if(d!=null){a=a.replace(l.match[h],"");break}}}}return d||(d=typeof b.getElementsByTagName!="undefined"?b.getElementsByTagName("*"):[]),{set:d,expr:a}},k.filter=function(a,c,d,e){var f,g,h=a,i=[],j=c,m=c&&c[0]&&k.isXML(c[0]);while(a&&c.length){for(var n in l.filter)if((f=l.leftMatch[n].exec(a))!=null&&f[2]){var o,p,q=l.filter[n],r=f[1];g=!1,f.splice(1,1);if(r.substr(r.length-1)==="\\")continue;j===i&&(i=[]);if(l.preFilter[n]){f=l.preFilter[n](f,j,d,i,e,m);if(!f)g=o=!0;else if(f===!0)continue}if(f)for(var s=0;(p=j[s])!=null;s++)if(p){o=q(p,f,s,j);var t=e^!!o;d&&o!=null?t?g=!0:j[s]=!1:t&&(i.push(p),g=!0)}if(o!==b){d||(j=i),a=a.replace(l.match[n],"");if(!g)return[];break}}if(a===h)if(g==null)k.error(a);else break;h=a}return j},k.error=function(a){throw"Syntax error, unrecognized expression: "+a};var l=k.selectors={order:["ID","NAME","TAG"],match:{ID:/#((?:[\w\u00c0-\uFFFF\-]|\\.)+)/,CLASS:/\.((?:[\w\u00c0-\uFFFF\-]|\\.)+)/,NAME:/\[name=['"]*((?:[\w\u00c0-\uFFFF\-]|\\.)+)['"]*\]/,ATTR:/\[\s*((?:[\w\u00c0-\uFFFF\-]|\\.)+)\s*(?:(\S?=)\s*(?:(['"])(.*?)\3|(#?(?:[\w\u00c0-\uFFFF\-]|\\.)*)|)|)\s*\]/,TAG:/^((?:[\w\u00c0-\uFFFF\*\-]|\\.)+)/,CHILD:/:(only|nth|last|first)-child(?:\(\s*(even|odd|(?:[+\-]?\d+|(?:[+\-]?\d*)?n\s*(?:[+\-]\s*\d+)?))\s*\))?/,POS:/:(nth|eq|gt|lt|first|last|even|odd)(?:\((\d*)\))?(?=[^\-]|$)/,PSEUDO:/:((?:[\w\u00c0-\uFFFF\-]|\\.)+)(?:\((['"]?)((?:\([^\)]+\)|[^\(\)]*)+)\2\))?/},leftMatch:{},attrMap:{"class":"className","for":"htmlFor"},attrHandle:{href:function(a){return a.getAttribute("href")},type:function(a){return a.getAttribute("type")}},relative:{"+":function(a,b){var c=typeof b=="string",d=c&&!j.test(b),e=c&&!d;d&&(b=b.toLowerCase());for(var f=0,g=a.length,h;f<g;f++)if(h=a[f]){while((h=h.previousSibling)&&h.nodeType!==1);a[f]=e||h&&h.nodeName.toLowerCase()===b?h||!1:h===b}e&&k.filter(b,a,!0)},">":function(a,b){var c,d=typeof b=="string",e=0,f=a.length;if(d&&!j.test(b)){b=b.toLowerCase();for(;e<f;e++){c=a[e];if(c){var g=c.parentNode;a[e]=g.nodeName.toLowerCase()===b?g:!1}}}else{for(;e<f;e++)c=a[e],c&&(a[e]=d?c.parentNode:c.parentNode===b);d&&k.filter(b,a,!0)}},"":function(a,b,c){var e,f=d++,g=u;typeof b=="string"&&!j.test(b)&&(b=b.toLowerCase(),e=b,g=t),g("parentNode",b,f,a,e,c)},"~":function(a,b,c){var e,f=d++,g=u;typeof b=="string"&&!j.test(b)&&(b=b.toLowerCase(),e=b,g=t),g("previousSibling",b,f,a,e,c)}},find:{ID:function(a,b,c){if(typeof b.getElementById!="undefined"&&!c){var d=b.getElementById(a[1]);return d&&d.parentNode?[d]:[]}},NAME:function(a,b){if(typeof b.getElementsByName!="undefined"){var c=[],d=b.getElementsByName(a[1]);for(var e=0,f=d.length;e<f;e++)d[e].getAttribute("name")===a[1]&&c.push(d[e]);return c.length===0?null:c}},TAG:function(a,b){if(typeof b.getElementsByTagName!="undefined")return b.getElementsByTagName(a[1])}},preFilter:{CLASS:function(a,b,c,d,e,f){a=" "+a[1].replace(i,"")+" ";if(f)return a;for(var g=0,h;(h=b[g])!=null;g++)h&&(e^(h.className&&(" "+h.className+" ").replace(/[\t\n\r]/g," ").indexOf(a)>=0)?c||d.push(h):c&&(b[g]=!1));return!1},ID:function(a){return a[1].replace(i,"")},TAG:function(a,b){return a[1].replace(i,"").toLowerCase()},CHILD:function(a){if(a[1]==="nth"){a[2]||k.error(a[0]),a[2]=a[2].replace(/^\+|\s*/g,"");var b=/(-?)(\d*)(?:n([+\-]?\d*))?/.exec(a[2]==="even"&&"2n"||a[2]==="odd"&&"2n+1"||!/\D/.test(a[2])&&"0n+"+a[2]||a[2]);a[2]=b[1]+(b[2]||1)-0,a[3]=b[3]-0}else a[2]&&k.error(a[0]);return a[0]=d++,a},ATTR:function(a,b,c,d,e,f){var g=a[1]=a[1].replace(i,"");return!f&&l.attrMap[g]&&(a[1]=l.attrMap[g]),a[4]=(a[4]||a[5]||"").replace(i,""),a[2]==="~="&&(a[4]=" "+a[4]+" "),a},PSEUDO:function(b,c,d,e,f){if(b[1]==="not")if((a.exec(b[3])||"").length>1||/^\w/.test(b[3]))b[3]=k(b[3],null,null,c);else{var g=k.filter(b[3],c,d,!0^f);return d||e.push.apply(e,g),!1}else if(l.match.POS.test(b[0])||l.match.CHILD.test(b[0]))return!0;return b},POS:function(a){return a.unshift(!0),a}},filters:{enabled:function(a){return a.disabled===!1&&a.type!=="hidden"},disabled:function(a){return a.disabled===!0},checked:function(a){return a.checked===!0},selected:function(a){return a.parentNode&&a.parentNode.selectedIndex,a.selected===!0},parent:function(a){return!!a.firstChild},empty:function(a){return!a.firstChild},has:function(a,b,c){return!!k(c[3],a).length},header:function(a){return/h\d/i.test(a.nodeName)},text:function(a){var b=a.getAttribute("type"),c=a.type;return a.nodeName.toLowerCase()==="input"&&"text"===c&&(b===c||b===null)},radio:function(a){return a.nodeName.toLowerCase()==="input"&&"radio"===a.type},checkbox:function(a){return a.nodeName.toLowerCase()==="input"&&"checkbox"===a.type},file:function(a){return a.nodeName.toLowerCase()==="input"&&"file"===a.type},password:function(a){return a.nodeName.toLowerCase()==="input"&&"password"===a.type},submit:function(a){var b=a.nodeName.toLowerCase();return(b==="input"||b==="button")&&"submit"===a.type},image:function(a){return a.nodeName.toLowerCase()==="input"&&"image"===a.type},reset:function(a){return a.nodeName.toLowerCase()==="input"&&"reset"===a.type},button:function(a){var b=a.nodeName.toLowerCase();return b==="input"&&"button"===a.type||b==="button"},input:function(a){return/input|select|textarea|button/i.test(a.nodeName)},focus:function(a){return a===a.ownerDocument.activeElement}},setFilters:{first:function(a,b){return b===0},last:function(a,b,c,d){return b===d.length-1},even:function(a,b){return b%2===0},odd:function(a,b){return b%2===1},lt:function(a,b,c){return b<c[3]-0},gt:function(a,b,c){return b>c[3]-0},nth:function(a,b,c){return c[3]-0===b},eq:function(a,b,c){return c[3]-0===b}},filter:{PSEUDO:function(a,b,c,d){var e=b[1],f=l.filters[e];if(f)return f(a,c,b,d);if(e==="contains")return(a.textContent||a.innerText||k.getText([a])||"").indexOf(b[3])>=0;if(e==="not"){var g=b[3];for(var h=0,i=g.length;h<i;h++)if(g[h]===a)return!1;return!0}k.error(e)},CHILD:function(a,b){var c=b[1],d=a;switch(c){case"only":case"first":while(d=d.previousSibling)if(d.nodeType===1)return!1;if(c==="first")return!0;d=a;case"last":while(d=d.nextSibling)if(d.nodeType===1)return!1;return!0;case"nth":var e=b[2],f=b[3];if(e===1&&f===0)return!0;var g=b[0],h=a.parentNode;if(h&&(h.sizcache!==g||!a.nodeIndex)){var i=0;for(d=h.firstChild;d;d=d.nextSibling)d.nodeType===1&&(d.nodeIndex=++i);h.sizcache=g}var j=a.nodeIndex-f;return e===0?j===0:j%e===0&&j/e>=0}},ID:function(a,b){return a.nodeType===1&&a.getAttribute("id")===b},TAG:function(a,b){return b==="*"&&a.nodeType===1||a.nodeName.toLowerCase()===b},CLASS:function(a,b){return(" "+(a.className||a.getAttribute("class"))+" ").indexOf(b)>-1},ATTR:function(a,b){var c=b[1],d=l.attrHandle[c]?l.attrHandle[c](a):a[c]!=null?a[c]:a.getAttribute(c),e=d+"",f=b[2],g=b[4];return d==null?f==="!=":f==="="?e===g:f==="*="?e.indexOf(g)>=0:f==="~="?(" "+e+" ").indexOf(g)>=0:g?f==="!="?e!==g:f==="^="?e.indexOf(g)===0:f==="$="?e.substr(e.length-g.length)===g:f==="|="?e===g||e.substr(0,g.length+1)===g+"-":!1:e&&d!==!1},POS:function(a,b,c,d){var e=b[2],f=l.setFilters[e];if(f)return f(a,c,b,d)}}},m=l.match.POS,n=function(a,b){return"\\"+(b-0+1)};for(var o in l.match)l.match[o]=new RegExp(l.match[o].source+/(?![^\[]*\])(?![^\(]*\))/.source),l.leftMatch[o]=new RegExp(/(^(?:.|\r|\n)*?)/.source+l.match[o].source.replace(/\\(\d+)/g,n));var p=function(a,b){return a=Array.prototype.slice.call(a,0),b?(b.push.apply(b,a),b):a};try{Array.prototype.slice.call(c.documentElement.childNodes,0)[0].nodeType}catch(q){p=function(a,b){var c=0,d=b||[];if(e.call(a)==="[object Array]")Array.prototype.push.apply(d,a);else if(typeof a.length=="number")for(var f=a.length;c<f;c++)d.push(a[c]);else for(;a[c];c++)d.push(a[c]);return d}}var r,s;c.documentElement.compareDocumentPosition?r=function(a,b){return a===b?(g=!0,0):!a.compareDocumentPosition||!b.compareDocumentPosition?a.compareDocumentPosition?-1:1:a.compareDocumentPosition(b)&4?-1:1}:(r=function(a,b){var c,d,e=[],f=[],h=a.parentNode,i=b.parentNode,j=h;if(a===b)return g=!0,0;if(h===i)return s(a,b);if(!h)return-1;if(!i)return 1;while(j)e.unshift(j),j=j.parentNode;j=i;while(j)f.unshift(j),j=j.parentNode;c=e.length,d=f.length;for(var k=0;k<c&&k<d;k++)if(e[k]!==f[k])return s(e[k],f[k]);return k===c?s(a,f[k],-1):s(e[k],b,1)},s=function(a,b,c){if(a===b)return c;var d=a.nextSibling;while(d){if(d===b)return-1;d=d.nextSibling}return 1}),k.getText=function(a){var b="",c;for(var d=0;a[d];d++)c=a[d],c.nodeType===3||c.nodeType===4?b+=c.nodeValue:c.nodeType!==8&&(b+=k.getText(c.childNodes));return b},function(){var a=c.createElement("div"),d="script"+(new Date).getTime(),e=c.documentElement;a.innerHTML="<a name='"+d+"'/>",e.insertBefore(a,e.firstChild),c.getElementById(d)&&(l.find.ID=function(a,c,d){if(typeof c.getElementById!="undefined"&&!d){var e=c.getElementById(a[1]);return e?e.id===a[1]||typeof e.getAttributeNode!="undefined"&&e.getAttributeNode("id").nodeValue===a[1]?[e]:b:[]}},l.filter.ID=function(a,b){var c=typeof a.getAttributeNode!="undefined"&&a.getAttributeNode("id");return a.nodeType===1&&c&&c.nodeValue===b}),e.removeChild(a),e=a=null}(),function(){var a=c.createElement("div");a.appendChild(c.createComment("")),a.getElementsByTagName("*").length>0&&(l.find.TAG=function(a,b){var c=b.getElementsByTagName(a[1]);if(a[1]==="*"){var d=[];for(var e=0;c[e];e++)c[e].nodeType===1&&d.push(c[e]);c=d}return c}),a.innerHTML="<a href='#'></a>",a.firstChild&&typeof a.firstChild.getAttribute!="undefined"&&a.firstChild.getAttribute("href")!=="#"&&(l.attrHandle.href=function(a){return a.getAttribute("href",2)}),a=null}(),c.querySelectorAll&&function(){var a=k,b=c.createElement("div"),d="__sizzle__";b.innerHTML="<p class='TEST'></p>";if(b.querySelectorAll&&b.querySelectorAll(".TEST").length===0)return;k=function(b,e,f,g){e=e||c;if(!g&&!k.isXML(e)){var h=/^(\w+$)|^\.([\w\-]+$)|^#([\w\-]+$)/.exec(b);if(h&&(e.nodeType===1||e.nodeType===9)){if(h[1])return p(e.getElementsByTagName(b),f);if(h[2]&&l.find.CLASS&&e.getElementsByClassName)return p(e.getElementsByClassName(h[2]),f)}if(e.nodeType===9){if(b==="body"&&e.body)return p([e.body],f);if(h&&h[3]){var i=e.getElementById(h[3]);if(!i||!i.parentNode)return p([],f);if(i.id===h[3])return p([i],f)}try{return p(e.querySelectorAll(b),f)}catch(j){}}else if(e.nodeType===1&&e.nodeName.toLowerCase()!=="object"){var m=e,n=e.getAttribute("id"),o=n||d,q=e.parentNode,r=/^\s*[+~]/.test(b);n?o=o.replace(/'/g,"\\$&"):e.setAttribute("id",o),r&&q&&(e=e.parentNode);try{if(!r||q)return p(e.querySelectorAll("[id='"+o+"'] "+b),f)}catch(s){}finally{n||m.removeAttribute("id")}}}return a(b,e,f,g)};for(var e in a)k[e]=a[e];b=null}(),function(){var a=c.documentElement,b=a.matchesSelector||a.mozMatchesSelector||a.webkitMatchesSelector||a.msMatchesSelector;if(b){var d=!b.call(c.createElement("div"),"div"),e=!1;try{b.call(c.documentElement,"[test!='']:sizzle")}catch(f){e=!0}k.matchesSelector=function(a,c){c=c.replace(/\=\s*([^'"\]]*)\s*\]/g,"='$1']");if(!k.isXML(a))try{if(e||!l.match.PSEUDO.test(c)&&!/!=/.test(c)){var f=b.call(a,c);if(f||!d||a.document&&a.document.nodeType!==11)return f}}catch(g){}return k(c,null,null,[a]).length>0}}}(),function(){var a=c.createElement("div");a.innerHTML="<div class='test e'></div><div class='test'></div>";if(!a.getElementsByClassName||a.getElementsByClassName("e").length===0)return;a.lastChild.className="e";if(a.getElementsByClassName("e").length===1)return;l.order.splice(1,0,"CLASS"),l.find.CLASS=function(a,b,c){if(typeof b.getElementsByClassName!="undefined"&&!c)return b.getElementsByClassName(a[1])},a=null}(),c.documentElement.contains?k.contains=function(a,b){return a!==b&&(a.contains?a.contains(b):!0)}:c.documentElement.compareDocumentPosition?k.contains=function(a,b){return!!(a.compareDocumentPosition(b)&16)}:k.contains=function(){return!1},k.isXML=function(a){var b=(a?a.ownerDocument||a:0).documentElement;return b?b.nodeName!=="HTML":!1};var v=function(a,b){var c,d=[],e="",f=b.nodeType?[b]:b;while(c=l.match.PSEUDO.exec(a))e+=c[0],a=a.replace(l.match.PSEUDO,"");a=l.relative[a]?a+"*":a;for(var g=0,h=f.length;g<h;g++)k(a,f[g],d);return k.filter(e,d)};f.find=k,f.expr=k.selectors,f.expr[":"]=f.expr.filters,f.unique=k.uniqueSort,f.text=k.getText,f.isXMLDoc=k.isXML,f.contains=k.contains}();var O=/Until$/,P=/^(?:parents|prevUntil|prevAll)/,Q=/,/,R=/^.[^:#\[\.,]*$/,S=Array.prototype.slice,T=f.expr.match.POS,U={children:!0,contents:!0,next:!0,prev:!0};f.fn.extend({find:function(a){var b=this,c,d;if(typeof a!="string")return f(a).filter(function(){for(c=0,d=b.length;c<d;c++)if(f.contains(b[c],this))return!0});var e=this.pushStack("","find",a),g,h,i;for(c=0,d=this.length;c<d;c++){g=e.length,f.find(a,this[c],e);if(c>0)for(h=g;h<e.length;h++)for(i=0;i<g;i++)if(e[i]===e[h]){e.splice(h--,1);break}}return e},has:function(a){var b=f(a);return this.filter(function(){for(var a=0,c=b.length;a<c;a++)if(f.contains(this,b[a]))return!0})},not:function(a){return this.pushStack(W(this,a,!1),"not",a)},filter:function(a){return this.pushStack(W(this,a,!0),"filter",a)},is:function(a){return!!a&&(typeof a=="string"?f.filter(a,this).length>0:this.filter(a).length>0)},closest:function(a,b){var c=[],d,e,g=this[0];if(f.isArray(a)){var h,i,j={},k=1;if(g&&a.length){for(d=0,e=a.length;d<e;d++)i=a[d],j[i]||(j[i]=T.test(i)?f(i,b||this.context):i);while(g&&g.ownerDocument&&g!==b){for(i in j)h=j[i],(h.jquery?h.index(g)>-1:f(g).is(h))&&c.push({selector:i,elem:g,level:k});g=g.parentNode,k++}}return c}var l=T.test(a)||typeof a!="string"?f(a,b||this.context):0;for(d=0,e=this.length;d<e;d++){g=this[d];while(g){if(l?l.index(g)>-1:f.find.matchesSelector(g,a)){c.push(g);break}g=g.parentNode;if(!g||!g.ownerDocument||g===b||g.nodeType===11)break}}return c=c.length>1?f.unique(c):c,this.pushStack(c,"closest",a)},index:function(a){return!a||typeof a=="string"?f.inArray(this[0],a?f(a):this.parent().children()):f.inArray(a.jquery?a[0]:a,this)},add:function(a,b){var c=typeof a=="string"?f(a,b):f.makeArray(a&&a.nodeType?[a]:a),d=f.merge(this.get(),c);return this.pushStack(V(c[0])||V(d[0])?d:f.unique(d))},andSelf:function(){return this.add(this.prevObject)}}),f.each({parent:function(a){var b=a.parentNode;return b&&b.nodeType!==11?b:null},parents:function(a){return f.dir(a,"parentNode")},parentsUntil:function(a,b,c){return f.dir(a,"parentNode",c)},next:function(a){return f.nth(a,2,"nextSibling")},prev:function(a){return f.nth(a,2,"previousSibling")},nextAll:function(a){return f.dir(a,"nextSibling")},prevAll:function(a){return f.dir(a,"previousSibling")},nextUntil:function(a,b,c){return f.dir(a,"nextSibling",c)},prevUntil:function(a,b,c){return f.dir(a,"previousSibling",c)},siblings:function(a){return f.sibling(a.parentNode.firstChild,a)},children:function(a){return f.sibling(a.firstChild)},contents:function(a){return f.nodeName(a,"iframe")?a.contentDocument||a.contentWindow.document:f.makeArray(a.childNodes)}},function(a,b){f.fn[a]=function(c,d){var e=f.map(this,b,c),g=S.call(arguments);return O.test(a)||(d=c),d&&typeof d=="string"&&(e=f.filter(d,e)),e=this.length>1&&!U[a]?f.unique(e):e,(this.length>1||Q.test(d))&&P.test(a)&&(e=e.reverse()),this.pushStack(e,a,g.join(","))}}),f.extend({filter:function(a,b,c){return c&&(a=":not("+a+")"),b.length===1?f.find.matchesSelector(b[0],a)?[b[0]]:[]:f.find.matches(a,b)},dir:function(a,c,d){var e=[],g=a[c];while(g&&g.nodeType!==9&&(d===b||g.nodeType!==1||!f(g).is(d)))g.nodeType===1&&e.push(g),g=g[c];return e},nth:function(a,b,c,d){b=b||1;var e=0;for(;a;a=a[c])if(a.nodeType===1&&++e===b)break;return a},sibling:function(a,b){var c=[];for(;a;a=a.nextSibling)a.nodeType===1&&a!==b&&c.push(a);return c}});var X=/ jQuery\d+="(?:\d+|null)"/g,Y=/^\s+/,Z=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/ig,$=/<([\w:]+)/,_=/<tbody/i,ba=/<|&#?\w+;/,bb=/<(?:script|object|embed|option|style)/i,bc=/checked\s*(?:[^=]|=\s*.checked.)/i,bd=/\/(java|ecma)script/i,be={option:[1,"<select multiple='multiple'>","</select>"],legend:[1,"<fieldset>","</fieldset>"],thead:[1,"<table>","</table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],col:[2,"<table><tbody></tbody><colgroup>","</colgroup></table>"],area:[1,"<map>","</map>"],_default:[0,"",""]};be.optgroup=be.option,be.tbody=be.tfoot=be.colgroup=be.caption=be.thead,be.th=be.td,f.support.htmlSerialize||(be._default=[1,"div<div>","</div>"]),f.fn.extend({text:function(a){return f.isFunction(a)?this.each(function(b){var c=f(this);c.text(a.call(this,b,c.text()))}):typeof a!="object"&&a!==b?this.empty().append((this[0]&&this[0].ownerDocument||c).createTextNode(a)):f.text(this)},wrapAll:function(a){if(f.isFunction(a))return this.each(function(b){f(this).wrapAll(a.call(this,b))});if(this[0]){var b=f(a,this[0].ownerDocument).eq(0).clone(!0);this[0].parentNode&&b.insertBefore(this[0]),b.map(function(){var a=this;while(a.firstChild&&a.firstChild.nodeType===1)a=a.firstChild;return a}).append(this)}return this},wrapInner:function(a){return f.isFunction(a)?this.each(function(b){f(this).wrapInner(a.call(this,b))}):this.each(function(){var b=f(this),c=b.contents();c.length?c.wrapAll(a):b.append(a)})},wrap:function(a){return this.each(function(){f(this).wrapAll(a)})},unwrap:function(){return this.parent().each(function(){f.nodeName(this,"body")||f(this).replaceWith(this.childNodes)}).end()},append:function(){return this.domManip(arguments,!0,function(a){this.nodeType===1&&this.appendChild(a)})},prepend:function(){return this.domManip(arguments,!0,function(a){this.nodeType===1&&this.insertBefore(a,this.firstChild)})},before:function(){if(this[0]&&this[0].parentNode)return this.domManip(arguments,!1,function(a){this.parentNode.insertBefore(a,this)});if(arguments.length){var a=f(arguments[0]);return a.push.apply(a,this.toArray()),this.pushStack(a,"before",arguments)}},after:function(){if(this[0]&&this[0].parentNode)return this.domManip(arguments,!1,function(a){this.parentNode.insertBefore(a,this.nextSibling)});if(arguments.length){var a=this.pushStack(this,"after",arguments);return a.push.apply(a,f(arguments[0]).toArray()),a}},remove:function(a,b){for(var c=0,d;(d=this[c])!=null;c++)if(!a||f.filter(a,[d]).length)!b&&d.nodeType===1&&(f.cleanData(d.getElementsByTagName("*")),f.cleanData([d])),d.parentNode&&d.parentNode.removeChild(d);return this},empty:function(){for(var a=0,b;(b=this[a])!=null;a++){b.nodeType===1&&f.cleanData(b.getElementsByTagName("*"));while(b.firstChild)b.removeChild(b.firstChild)}return this},clone:function(a,b){return a=a==null?!1:a,b=b==null?a:b,this.map(function(){return f.clone(this,a,b)})},html:function(a){if(a===b)return this[0]&&this[0].nodeType===1?this[0].innerHTML.replace(X,""):null;if(typeof a=="string"&&!bb.test(a)&&(f.support.leadingWhitespace||!Y.test(a))&&!be[($.exec(a)||["",""])[1].toLowerCase()]){a=a.replace(Z,"<$1></$2>");try{for(var c=0,d=this.length;c<d;c++)this[c].nodeType===1&&(f.cleanData(this[c].getElementsByTagName("*")),this[c].innerHTML=a)}catch(e){this.empty().append(a)}}else f.isFunction(a)?this.each(function(b){var c=f(this);c.html(a.call(this,b,c.html()))}):this.empty().append(a);return this},replaceWith:function(a){return this[0]&&this[0].parentNode?f.isFunction(a)?this.each(function(b){var c=f(this),d=c.html();c.replaceWith(a.call(this,b,d))}):(typeof a!="string"&&(a=f(a).detach()),this.each(function(){var b=this.nextSibling,c=this.parentNode;f(this).remove(),b?f(b).before(a):f(c).append(a)})):this.length?this.pushStack(f(f.isFunction(a)?a():a),"replaceWith",a):this},detach:function(a){return this.remove(a,!0)},domManip:function(a,c,d){var e,g,h,i,j=a[0],k=[];if(!f.support.checkClone&&arguments.length===3&&typeof j=="string"&&bc.test(j))return this.each(function(){f(this).domManip(a,c,d,!0)});if(f.isFunction(j))return this.each(function(e){var g=f(this);a[0]=j.call(this,e,c?g.html():b),g.domManip(a,c,d)});if(this[0]){i=j&&j.parentNode,f.support.parentNode&&i&&i.nodeType===11&&i.childNodes.length===this.length?e={fragment:i}:e=f.buildFragment(a,this,k),h=e.fragment,h.childNodes.length===1?g=h=h.firstChild:g=h.firstChild;if(g){c=c&&f.nodeName(g,"tr");for(var l=0,m=this.length,n=m-1;l<m;l++)d.call(c?bf(this[l],g):this[l],e.cacheable||m>1&&l<n?f.clone(h,!0,!0):h)}k.length&&f.each(k,bl)}return this}}),f.buildFragment=function(a,b,d){var e,g,h,i=b&&b[0]?b[0].ownerDocument||b[0]:c;return a.length===1&&typeof a[0]=="string"&&a[0].length<512&&i===c&&a[0].charAt(0)==="<"&&!bb.test(a[0])&&(f.support.checkClone||!bc.test(a[0]))&&(g=!0,h=f.fragments[a[0]],h&&h!==1&&(e=h)),e||(e=i.createDocumentFragment(),f.clean(a,i,e,d)),g&&(f.fragments[a[0]]=h?e:1),{fragment:e,cacheable:g}},f.fragments={},f.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},function(a,b){f.fn[a]=function(c){var d=[],e=f(c),g=this.length===1&&this[0].parentNode;if(g&&g.nodeType===11&&g.childNodes.length===1&&e.length===1)return e[b](this[0]),this;for(var h=0,i=e.length;h<i;h++){var j=(h>0?this.clone(!0):this).get();f(e[h])[b](j),d=d.concat(j)}return this.pushStack(d,a,e.selector)}}),f.extend({clone:function(a,b,c){var d=a.cloneNode(!0),e,g,h;if((!f.support.noCloneEvent||!f.support.noCloneChecked)&&(a.nodeType===1||a.nodeType===11)&&!f.isXMLDoc(a)){bh(a,d),e=bi(a),g=bi(d);for(h=0;e[h];++h)bh(e[h],g[h])}if(b){bg(a,d);if(c){e=bi(a),g=bi(d);for(h=0;e[h];++h)bg(e[h],g[h])}}return d},clean:function(a,b,d,e){var g;b=b||c,typeof b.createElement=="undefined"&&(b=b.ownerDocument||b[0]&&b[0].ownerDocument||c);var h=[];for(var i=0,j;(j=a[i])!=null;i++){typeof j=="number"&&(j+="");if(!j)continue;if(typeof j=="string")if(!ba.test(j))j=b.createTextNode(j);else{j=j.replace(Z,"<$1></$2>");var k=($.exec(j)||["",""])[1].toLowerCase(),l=be[k]||be._default,m=l[0],n=b.createElement("div");n.innerHTML=l[1]+j+l[2];while(m--)n=n.lastChild;if(!f.support.tbody){var o=_.test(j),p=k==="table"&&!o?n.firstChild&&n.firstChild.childNodes:l[1]==="<table>"&&!o?n.childNodes:[];for(var q=p.length-1;q>=0;--q)f.nodeName(p[q],"tbody")&&!p[q].childNodes.length&&p[q].parentNode.removeChild(p[q])}!f.support.leadingWhitespace&&Y.test(j)&&n.insertBefore(b.createTextNode(Y.exec(j)[0]),n.firstChild),j=n.childNodes}var r;if(!f.support.appendChecked)if(j[0]&&typeof (r=j.length)=="number")for(i=0;i<r;i++)bk(j[i]);else bk(j);j.nodeType?h.push(j):h=f.merge(h,j)}if(d){g=function(a){return!a.type||bd.test(a.type)};for(i=0;h[i
];i++)if(e&&f.nodeName(h[i],"script")&&(!h[i].type||h[i].type.toLowerCase()==="text/javascript"))e.push(h[i].parentNode?h[i].parentNode.removeChild(h[i]):h[i]);else{if(h[i].nodeType===1){var s=f.grep(h[i].getElementsByTagName("script"),g);h.splice.apply(h,[i+1,0].concat(s))}d.appendChild(h[i])}}return h},cleanData:function(a){var b,c,d=f.cache,e=f.expando,g=f.event.special,h=f.support.deleteExpando;for(var i=0,j;(j=a[i])!=null;i++){if(j.nodeName&&f.noData[j.nodeName.toLowerCase()])continue;c=j[f.expando];if(c){b=d[c]&&d[c][e];if(b&&b.events){for(var k in b.events)g[k]?f.event.remove(j,k):f.removeEvent(j,k,b.handle);b.handle&&(b.handle.elem=null)}h?delete j[f.expando]:j.removeAttribute&&j.removeAttribute(f.expando),delete d[c]}}}});var bm=/alpha\([^)]*\)/i,bn=/opacity=([^)]*)/,bo=/-([a-z])/ig,bp=/([A-Z]|^ms)/g,bq=/^-?\d+(?:px)?$/i,br=/^-?\d/,bs=/^[+\-]=/,bt=/[^+\-\.\de]+/g,bu={position:"absolute",visibility:"hidden",display:"block"},bv=["Left","Right"],bw=["Top","Bottom"],bx,by,bz,bA=function(a,b){return b.toUpperCase()};f.fn.css=function(a,c){return arguments.length===2&&c===b?this:f.access(this,a,c,!0,function(a,c,d){return d!==b?f.style(a,c,d):f.css(a,c)})},f.extend({cssHooks:{opacity:{get:function(a,b){if(b){var c=bx(a,"opacity","opacity");return c===""?"1":c}return a.style.opacity}}},cssNumber:{zIndex:!0,fontWeight:!0,opacity:!0,zoom:!0,lineHeight:!0,widows:!0,orphans:!0},cssProps:{"float":f.support.cssFloat?"cssFloat":"styleFloat"},style:function(a,c,d,e){if(!a||a.nodeType===3||a.nodeType===8||!a.style)return;var g,h,i=f.camelCase(c),j=a.style,k=f.cssHooks[i];c=f.cssProps[i]||i;if(d===b)return k&&"get"in k&&(g=k.get(a,!1,e))!==b?g:j[c];h=typeof d;if(h==="number"&&isNaN(d)||d==null)return;h==="string"&&bs.test(d)&&(d=+d.replace(bt,"")+parseFloat(f.css(a,c))),h==="number"&&!f.cssNumber[i]&&(d+="px");if(!k||!("set"in k)||(d=k.set(a,d))!==b)try{j[c]=d}catch(l){}},css:function(a,c,d){var e,g;c=f.camelCase(c),g=f.cssHooks[c],c=f.cssProps[c]||c,c==="cssFloat"&&(c="float");if(g&&"get"in g&&(e=g.get(a,!0,d))!==b)return e;if(bx)return bx(a,c)},swap:function(a,b,c){var d={};for(var e in b)d[e]=a.style[e],a.style[e]=b[e];c.call(a);for(e in b)a.style[e]=d[e]},camelCase:function(a){return a.replace(bo,bA)}}),f.curCSS=f.css,f.each(["height","width"],function(a,b){f.cssHooks[b]={get:function(a,c,d){var e;if(c){a.offsetWidth!==0?e=bB(a,b,d):f.swap(a,bu,function(){e=bB(a,b,d)});if(e<=0){e=bx(a,b,b),e==="0px"&&bz&&(e=bz(a,b,b));if(e!=null)return e===""||e==="auto"?"0px":e}return e<0||e==null?(e=a.style[b],e===""||e==="auto"?"0px":e):typeof e=="string"?e:e+"px"}},set:function(a,b){if(!bq.test(b))return b;b=parseFloat(b);if(b>=0)return b+"px"}}}),f.support.opacity||(f.cssHooks.opacity={get:function(a,b){return bn.test((b&&a.currentStyle?a.currentStyle.filter:a.style.filter)||"")?parseFloat(RegExp.$1)/100+"":b?"1":""},set:function(a,b){var c=a.style,d=a.currentStyle;c.zoom=1;var e=f.isNaN(b)?"":"alpha(opacity="+b*100+")",g=d&&d.filter||c.filter||"";c.filter=bm.test(g)?g.replace(bm,e):g+" "+e}}),f(function(){f.support.reliableMarginRight||(f.cssHooks.marginRight={get:function(a,b){var c;return f.swap(a,{display:"inline-block"},function(){b?c=bx(a,"margin-right","marginRight"):c=a.style.marginRight}),c}})}),c.defaultView&&c.defaultView.getComputedStyle&&(by=function(a,c){var d,e,g;c=c.replace(bp,"-$1").toLowerCase();if(!(e=a.ownerDocument.defaultView))return b;if(g=e.getComputedStyle(a,null))d=g.getPropertyValue(c),d===""&&!f.contains(a.ownerDocument.documentElement,a)&&(d=f.style(a,c));return d}),c.documentElement.currentStyle&&(bz=function(a,b){var c,d=a.currentStyle&&a.currentStyle[b],e=a.runtimeStyle&&a.runtimeStyle[b],f=a.style;return!bq.test(d)&&br.test(d)&&(c=f.left,e&&(a.runtimeStyle.left=a.currentStyle.left),f.left=b==="fontSize"?"1em":d||0,d=f.pixelLeft+"px",f.left=c,e&&(a.runtimeStyle.left=e)),d===""?"auto":d}),bx=by||bz,f.expr&&f.expr.filters&&(f.expr.filters.hidden=function(a){var b=a.offsetWidth,c=a.offsetHeight;return b===0&&c===0||!f.support.reliableHiddenOffsets&&(a.style.display||f.css(a,"display"))==="none"},f.expr.filters.visible=function(a){return!f.expr.filters.hidden(a)});var bC=/%20/g,bD=/\[\]$/,bE=/\r?\n/g,bF=/#.*$/,bG=/^(.*?):[ \t]*([^\r\n]*)\r?$/mg,bH=/^(?:color|date|datetime|email|hidden|month|number|password|range|search|tel|text|time|url|week)$/i,bI=/^(?:about|app|app\-storage|.+\-extension|file|widget):$/,bJ=/^(?:GET|HEAD)$/,bK=/^\/\//,bL=/\?/,bM=/<script\b[^<]*(?:(?!<\/script>)<[^<]*)*<\/script>/gi,bN=/^(?:select|textarea)/i,bO=/\s+/,bP=/([?&])_=[^&]*/,bQ=/^([\w\+\.\-]+:)(?:\/\/([^\/?#:]*)(?::(\d+))?)?/,bR=f.fn.load,bS={},bT={},bU,bV;try{bU=e.href}catch(bW){bU=c.createElement("a"),bU.href="",bU=bU.href}bV=bQ.exec(bU.toLowerCase())||[],f.fn.extend({load:function(a,c,d){if(typeof a!="string"&&bR)return bR.apply(this,arguments);if(!this.length)return this;var e=a.indexOf(" ");if(e>=0){var g=a.slice(e,a.length);a=a.slice(0,e)}var h="GET";c&&(f.isFunction(c)?(d=c,c=b):typeof c=="object"&&(c=f.param(c,f.ajaxSettings.traditional),h="POST"));var i=this;return f.ajax({url:a,type:h,dataType:"html",data:c,complete:function(a,b,c){c=a.responseText,a.isResolved()&&(a.done(function(a){c=a}),i.html(g?f("<div>").append(c.replace(bM,"")).find(g):c)),d&&i.each(d,[c,b,a])}}),this},serialize:function(){return f.param(this.serializeArray())},serializeArray:function(){return this.map(function(){return this.elements?f.makeArray(this.elements):this}).filter(function(){return this.name&&!this.disabled&&(this.checked||bN.test(this.nodeName)||bH.test(this.type))}).map(function(a,b){var c=f(this).val();return c==null?null:f.isArray(c)?f.map(c,function(a,c){return{name:b.name,value:a.replace(bE,"\r\n")}}):{name:b.name,value:c.replace(bE,"\r\n")}}).get()}}),f.each("ajaxStart ajaxStop ajaxComplete ajaxError ajaxSuccess ajaxSend".split(" "),function(a,b){f.fn[b]=function(a){return this.bind(b,a)}}),f.each(["get","post"],function(a,c){f[c]=function(a,d,e,g){return f.isFunction(d)&&(g=g||e,e=d,d=b),f.ajax({type:c,url:a,data:d,success:e,dataType:g})}}),f.extend({getScript:function(a,c){return f.get(a,b,c,"script")},getJSON:function(a,b,c){return f.get(a,b,c,"json")},ajaxSetup:function(a,b){b?f.extend(!0,a,f.ajaxSettings,b):(b=a,a=f.extend(!0,f.ajaxSettings,b));for(var c in{context:1,url:1})c in b?a[c]=b[c]:c in f.ajaxSettings&&(a[c]=f.ajaxSettings[c]);return a},ajaxSettings:{url:bU,isLocal:bI.test(bV[1]),global:!0,type:"GET",contentType:"application/x-www-form-urlencoded",processData:!0,async:!0,accepts:{xml:"application/xml, text/xml",html:"text/html",text:"text/plain",json:"application/json, text/javascript","*":"*/*"},contents:{xml:/xml/,html:/html/,json:/json/},responseFields:{xml:"responseXML",text:"responseText"},converters:{"* text":a.String,"text html":!0,"text json":f.parseJSON,"text xml":f.parseXML}},ajaxPrefilter:bX(bS),ajaxTransport:bX(bT),ajax:function(a,c){function w(a,c,l,m){if(s===2)return;s=2,q&&clearTimeout(q),p=b,n=m||"",v.readyState=a?4:0;var o,r,u,w=l?b$(d,v,l):b,x,y;if(a>=200&&a<300||a===304){if(d.ifModified){if(x=v.getResponseHeader("Last-Modified"))f.lastModified[k]=x;if(y=v.getResponseHeader("Etag"))f.etag[k]=y}if(a===304)c="notmodified",o=!0;else try{r=b_(d,w),c="success",o=!0}catch(z){c="parsererror",u=z}}else{u=c;if(!c||a)c="error",a<0&&(a=0)}v.status=a,v.statusText=c,o?h.resolveWith(e,[r,c,v]):h.rejectWith(e,[v,c,u]),v.statusCode(j),j=b,t&&g.trigger("ajax"+(o?"Success":"Error"),[v,d,o?r:u]),i.resolveWith(e,[v,c]),t&&(g.trigger("ajaxComplete",[v,d]),--f.active||f.event.trigger("ajaxStop"))}typeof a=="object"&&(c=a,a=b),c=c||{};var d=f.ajaxSetup({},c),e=d.context||d,g=e!==d&&(e.nodeType||e instanceof f)?f(e):f.event,h=f.Deferred(),i=f._Deferred(),j=d.statusCode||{},k,l={},m={},n,o,p,q,r,s=0,t,u,v={readyState:0,setRequestHeader:function(a,b){if(!s){var c=a.toLowerCase();a=m[c]=m[c]||a,l[a]=b}return this},getAllResponseHeaders:function(){return s===2?n:null},getResponseHeader:function(a){var c;if(s===2){if(!o){o={};while(c=bG.exec(n))o[c[1].toLowerCase()]=c[2]}c=o[a.toLowerCase()]}return c===b?null:c},overrideMimeType:function(a){return s||(d.mimeType=a),this},abort:function(a){return a=a||"abort",p&&p.abort(a),w(0,a),this}};h.promise(v),v.success=v.done,v.error=v.fail,v.complete=i.done,v.statusCode=function(a){if(a){var b;if(s<2)for(b in a)j[b]=[j[b],a[b]];else b=a[v.status],v.then(b,b)}return this},d.url=((a||d.url)+"").replace(bF,"").replace(bK,bV[1]+"//"),d.dataTypes=f.trim(d.dataType||"*").toLowerCase().split(bO),d.crossDomain==null&&(r=bQ.exec(d.url.toLowerCase()),d.crossDomain=!(!r||r[1]==bV[1]&&r[2]==bV[2]&&(r[3]||(r[1]==="http:"?80:443))==(bV[3]||(bV[1]==="http:"?80:443)))),d.data&&d.processData&&typeof d.data!="string"&&(d.data=f.param(d.data,d.traditional)),bY(bS,d,c,v);if(s===2)return!1;t=d.global,d.type=d.type.toUpperCase(),d.hasContent=!bJ.test(d.type),t&&f.active++===0&&f.event.trigger("ajaxStart");if(!d.hasContent){d.data&&(d.url+=(bL.test(d.url)?"&":"?")+d.data),k=d.url;if(d.cache===!1){var x=f.now(),y=d.url.replace(bP,"$1_="+x);d.url=y+(y===d.url?(bL.test(d.url)?"&":"?")+"_="+x:"")}}(d.data&&d.hasContent&&d.contentType!==!1||c.contentType)&&v.setRequestHeader("Content-Type",d.contentType),d.ifModified&&(k=k||d.url,f.lastModified[k]&&v.setRequestHeader("If-Modified-Since",f.lastModified[k]),f.etag[k]&&v.setRequestHeader("If-None-Match",f.etag[k])),v.setRequestHeader("Accept",d.dataTypes[0]&&d.accepts[d.dataTypes[0]]?d.accepts[d.dataTypes[0]]+(d.dataTypes[0]!=="*"?", */*; q=0.01":""):d.accepts["*"]);for(u in d.headers)v.setRequestHeader(u,d.headers[u]);if(!d.beforeSend||d.beforeSend.call(e,v,d)!==!1&&s!==2){for(u in{success:1,error:1,complete:1})v[u](d[u]);p=bY(bT,d,c,v);if(!p)w(-1,"No Transport");else{v.readyState=1,t&&g.trigger("ajaxSend",[v,d]),d.async&&d.timeout>0&&(q=setTimeout(function(){v.abort("timeout")},d.timeout));try{s=1,p.send(l,w)}catch(z){status<2?w(-1,z):f.error(z)}}return v}return v.abort(),!1},param:function(a,c){var d=[],e=function(a,b){b=f.isFunction(b)?b():b,d[d.length]=encodeURIComponent(a)+"="+encodeURIComponent(b)};c===b&&(c=f.ajaxSettings.traditional);if(f.isArray(a)||a.jquery&&!f.isPlainObject(a))f.each(a,function(){e(this.name,this.value)});else for(var g in a)bZ(g,a[g],c,e);return d.join("&").replace(bC,"+")}}),f.extend({active:0,lastModified:{},etag:{}});var ca=f.now(),cb=/(\=)\?(&|$)|\?\?/i;f.ajaxSetup({jsonp:"callback",jsonpCallback:function(){return f.expando+"_"+ca++}}),f.ajaxPrefilter("json jsonp",function(b,c,d){var e=b.contentType==="application/x-www-form-urlencoded"&&typeof b.data=="string";if(b.dataTypes[0]==="jsonp"||b.jsonp!==!1&&(cb.test(b.url)||e&&cb.test(b.data))){var g,h=b.jsonpCallback=f.isFunction(b.jsonpCallback)?b.jsonpCallback():b.jsonpCallback,i=a[h],j=b.url,k=b.data,l="$1"+h+"$2";return b.jsonp!==!1&&(j=j.replace(cb,l),b.url===j&&(e&&(k=k.replace(cb,l)),b.data===k&&(j+=(/\?/.test(j)?"&":"?")+b.jsonp+"="+h))),b.url=j,b.data=k,a[h]=function(a){g=[a]},d.always(function(){a[h]=i,g&&f.isFunction(i)&&a[h](g[0])}),b.converters["script json"]=function(){return g||f.error(h+" was not called"),g[0]},b.dataTypes[0]="json","script"}}),f.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/javascript|ecmascript/},converters:{"text script":function(a){return f.globalEval(a),a}}}),f.ajaxPrefilter("script",function(a){a.cache===b&&(a.cache=!1),a.crossDomain&&(a.type="GET",a.global=!1)}),f.ajaxTransport("script",function(a){if(a.crossDomain){var d,e=c.head||c.getElementsByTagName("head")[0]||c.documentElement;return{send:function(f,g){d=c.createElement("script"),d.async="async",a.scriptCharset&&(d.charset=a.scriptCharset),d.src=a.url,d.onload=d.onreadystatechange=function(a,c){if(c||!d.readyState||/loaded|complete/.test(d.readyState))d.onload=d.onreadystatechange=null,e&&d.parentNode&&e.removeChild(d),d=b,c||g(200,"success")},e.insertBefore(d,e.firstChild)},abort:function(){d&&d.onload(0,1)}}}});var cc=a.ActiveXObject?function(){for(var a in ce)ce[a](0,1)}:!1,cd=0,ce;f.ajaxSettings.xhr=a.ActiveXObject?function(){return!this.isLocal&&cf()||cg()}:cf,function(a){f.extend(f.support,{ajax:!!a,cors:!!a&&"withCredentials"in a})}(f.ajaxSettings.xhr()),f.support.ajax&&f.ajaxTransport(function(c){if(!c.crossDomain||f.support.cors){var d;return{send:function(e,g){var h=c.xhr(),i,j;c.username?h.open(c.type,c.url,c.async,c.username,c.password):h.open(c.type,c.url,c.async);if(c.xhrFields)for(j in c.xhrFields)h[j]=c.xhrFields[j];c.mimeType&&h.overrideMimeType&&h.overrideMimeType(c.mimeType),!c.crossDomain&&!e["X-Requested-With"]&&(e["X-Requested-With"]="XMLHttpRequest");try{for(j in e)h.setRequestHeader(j,e[j])}catch(k){}h.send(c.hasContent&&c.data||null),d=function(a,e){var j,k,l,m,n;try{if(d&&(e||h.readyState===4)){d=b,i&&(h.onreadystatechange=f.noop,cc&&delete ce[i]);if(e)h.readyState!==4&&h.abort();else{j=h.status,l=h.getAllResponseHeaders(),m={},n=h.responseXML,n&&n.documentElement&&(m.xml=n),m.text=h.responseText;try{k=h.statusText}catch(o){k=""}!j&&c.isLocal&&!c.crossDomain?j=m.text?200:404:j===1223&&(j=204)}}}catch(p){e||g(-1,p)}m&&g(j,k,m,l)},!c.async||h.readyState===4?d():(i=++cd,cc&&(ce||(ce={},f(a).unload(cc)),ce[i]=d),h.onreadystatechange=d)},abort:function(){d&&d(0,1)}}}});var ch={},ci,cj,ck=/^(?:toggle|show|hide)$/,cl=/^([+\-]=)?([\d+.\-]+)([a-z%]*)$/i,cm,cn=[["height","marginTop","marginBottom","paddingTop","paddingBottom"],["width","marginLeft","marginRight","paddingLeft","paddingRight"],["opacity"]],co,cp=a.webkitRequestAnimationFrame||a.mozRequestAnimationFrame||a.oRequestAnimationFrame;f.fn.extend({show:function(a,b,c){var d,e;if(a||a===0)return this.animate(cs("show",3),a,b,c);for(var g=0,h=this.length;g<h;g++)d=this[g],d.style&&(e=d.style.display,!f._data(d,"olddisplay")&&e==="none"&&(e=d.style.display=""),e===""&&f.css(d,"display")==="none"&&f._data(d,"olddisplay",ct(d.nodeName)));for(g=0;g<h;g++){d=this[g];if(d.style){e=d.style.display;if(e===""||e==="none")d.style.display=f._data(d,"olddisplay")||""}}return this},hide:function(a,b,c){if(a||a===0)return this.animate(cs("hide",3),a,b,c);for(var d=0,e=this.length;d<e;d++)if(this[d].style){var g=f.css(this[d],"display");g!=="none"&&!f._data(this[d],"olddisplay")&&f._data(this[d],"olddisplay",g)}for(d=0;d<e;d++)this[d].style&&(this[d].style.display="none");return this},_toggle:f.fn.toggle,toggle:function(a,b,c){var d=typeof a=="boolean";return f.isFunction(a)&&f.isFunction(b)?this._toggle.apply(this,arguments):a==null||d?this.each(function(){var b=d?a:f(this).is(":hidden");f(this)[b?"show":"hide"]()}):this.animate(cs("toggle",3),a,b,c),this},fadeTo:function(a,b,c,d){return this.filter(":hidden").css("opacity",0).show().end().animate({opacity:b},a,c,d)},animate:function(a,b,c,d){var e=f.speed(b,c,d);return f.isEmptyObject(a)?this.each(e.complete,[!1]):this[e.queue===!1?"each":"queue"](function(){e.queue===!1&&f._mark(this);var b=f.extend({},e),c=this.nodeType===1,d=c&&f(this).is(":hidden"),g,h,i,j,k,l,m,n,o;b.animatedProperties={};for(i in a){g=f.camelCase(i),i!==g&&(a[g]=a[i],delete a[i]),h=a[g];if(h==="hide"&&d||h==="show"&&!d)return b.complete.call(this);c&&(g==="height"||g==="width")&&(b.overflow=[this.style.overflow,this.style.overflowX,this.style.overflowY],f.css(this,"display")==="inline"&&f.css(this,"float")==="none"&&(f.support.inlineBlockNeedsLayout?(j=ct(this.nodeName),j==="inline"?this.style.display="inline-block":(this.style.display="inline",this.style.zoom=1)):this.style.display="inline-block")),b.animatedProperties[g]=f.isArray(h)?h[1]:b.specialEasing&&b.specialEasing[g]||b.easing||"swing"}b.overflow!=null&&(this.style.overflow="hidden");for(i in a)k=new f.fx(this,b,i),h=a[i],ck.test(h)?k[h==="toggle"?d?"show":"hide":h]():(l=cl.exec(h),m=k.cur(),l?(n=parseFloat(l[2]),o=l[3]||(f.cssNumber[g]?"":"px"),o!=="px"&&(f.style(this,i,(n||1)+o),m=(n||1)/k.cur()*m,f.style(this,i,m+o)),l[1]&&(n=(l[1]==="-="?-1:1)*n+m),k.custom(m,n,o)):k.custom(m,h,""));return!0})},stop:function(a,b){return a&&this.queue([]),this.each(function(){var a=f.timers,c=a.length;b||f._unmark(!0,this);while(c--)a[c].elem===this&&(b&&a[c](!0),a.splice(c,1))}),b||this.dequeue(),this}}),f.each({slideDown:cs("show",1),slideUp:cs("hide",1),slideToggle:cs("toggle",1),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},function(a,b){f.fn[a]=function(a,c,d){return this.animate(b,a,c,d)}}),f.extend({speed:function(a,b,c){var d=a&&typeof a=="object"?f.extend({},a):{complete:c||!c&&b||f.isFunction(a)&&a,duration:a,easing:c&&b||b&&!f.isFunction(b)&&b};return d.duration=f.fx.off?0:typeof d.duration=="number"?d.duration:d.duration in f.fx.speeds?f.fx.speeds[d.duration]:f.fx.speeds._default,d.old=d.complete,d.complete=function(a){d.queue!==!1?f.dequeue(this):a!==!1&&f._unmark(this),f.isFunction(d.old)&&d.old.call(this)},d},easing:{linear:function(a,b,c,d){return c+d*a},swing:function(a,b,c,d){return(-Math.cos(a*Math.PI)/2+.5)*d+c}},timers:[],fx:function(a,b,c){this.options=b,this.elem=a,this.prop=c,b.orig=b.orig||{}}}),f.fx.prototype={update:function(){this.options.step&&this.options.step.call(this.elem,this.now,this),(f.fx.step[this.prop]||f.fx.step._default)(this)},cur:function(){if(this.elem[this.prop]==null||!!this.elem.style&&this.elem.style[this.prop]!=null){var a,b=f.css(this.elem,this.prop);return isNaN(a=parseFloat(b))?!b||b==="auto"?0:b:a}return this.elem[this.prop]},custom:function(a,b,c){function h(a){return d.step(a)}var d=this,e=f.fx,g;this.startTime=co||cq(),this.start=a,this.end=b,this.unit=c||this.unit||(f.cssNumber[this.prop]?"":"px"),this.now=this.start,this.pos=this.state=0,h.elem=this.elem,h()&&f.timers.push(h)&&!cm&&(cp?(cm=1,g=function(){cm&&(cp(g),e.tick())},cp(g)):cm=setInterval(e.tick,e.interval))},show:function(){this.options.orig[this.prop]=f.style(this.elem,this.prop),this.options.show=!0,this.custom(this.prop==="width"||this.prop==="height"?1:0,this.cur()),f(this.elem).show()},hide:function(){this.options.orig[this.prop]=f.style(this.elem,this.prop),this.options.hide=!0,this.custom(this.cur(),0)},step:function(a){var b=co||cq(),c=!0,d=this.elem,e=this.options,g,h;if(a||b>=e.duration+this.startTime){this.now=this.end,this.pos=this.state=1,this.update(),e.animatedProperties[this.prop]=!0;for(g in e.animatedProperties)e.animatedProperties[g]!==!0&&(c=!1);if(c){e.overflow!=null&&!f.support.shrinkWrapBlocks&&f.each(["","X","Y"],function(a,b){d.style["overflow"+b]=e.overflow[a]}),e.hide&&f(d).hide();if(e.hide||e.show)for(var i in e.animatedProperties)f.style(d,i,e.orig[i]);e.complete.call(d)}return!1}return e.duration==Infinity?this.now=b:(h=b-this.startTime,this.state=h/e.duration,this.pos=f.easing[e.animatedProperties[this.prop]](this.state,h,0,1,e.duration),this.now=this.start+(this.end-this.start)*this.pos),this.update(),!0}},f.extend(f.fx,{tick:function(){var a=f.timers,b=a.length;while(b--)a[b]()||a.splice(b,1);a.length||f.fx.stop()},interval:13,stop:function(){clearInterval(cm),cm=null},speeds:{slow:600,fast:200,_default:400},step:{opacity:function(a){f.style(a.elem,"opacity",a.now)},_default:function(a){a.elem.style&&a.elem.style[a.prop]!=null?a.elem.style[a.prop]=(a.prop==="width"||a.prop==="height"?Math.max(0,a.now):a.now)+a.unit:a.elem[a.prop]=a.now}}}),f.expr&&f.expr.filters&&(f.expr.filters.animated=function(a){return f.grep(f.timers,function(b){return a===b.elem}).length});var cu=/^t(?:able|d|h)$/i,cv=/^(?:body|html)$/i;"getBoundingClientRect"in c.documentElement?f.fn.offset=function(a){var b=this[0],c;if(a)return this.each(function(b){f.offset.setOffset(this,a,b)});if(!b||!b.ownerDocument)return null;if(b===b.ownerDocument.body)return f.offset.bodyOffset(b);try{c=b.getBoundingClientRect()}catch(d){}var e=b.ownerDocument,g=e.documentElement;if(!c||!f.contains(g,b))return c?{top:c.top,left:c.left}:{top:0,left:0};var h=e.body,i=cw(e),j=g.clientTop||h.clientTop||0,k=g.clientLeft||h.clientLeft||0,l=i.pageYOffset||f.support.boxModel&&g.scrollTop||h.scrollTop,m=i.pageXOffset||f.support.boxModel&&g.scrollLeft||h.scrollLeft,n=c.top+l-j,o=c.left+m-k;return{top:n,left:o}}:f.fn.offset=function(a){var b=this[0];if(a)return this.each(function(b){f.offset.setOffset(this,a,b)});if(!b||!b.ownerDocument)return null;if(b===b.ownerDocument.body)return f.offset.bodyOffset(b);f.offset.initialize();var c,d=b.offsetParent,e=b,g=b.ownerDocument,h=g.documentElement,i=g.body,j=g.defaultView,k=j?j.getComputedStyle(b,null):b.currentStyle,l=b.offsetTop,m=b.offsetLeft;while((b=b.parentNode)&&b!==i&&b!==h){if(f.offset.supportsFixedPosition&&k.position==="fixed")break;c=j?j.getComputedStyle(b,null):b.currentStyle,l-=b.scrollTop,m-=b.scrollLeft,b===d&&(l+=b.offsetTop,m+=b.offsetLeft,f.offset.doesNotAddBorder&&(!f.offset.doesAddBorderForTableAndCells||!cu.test(b.nodeName))&&(l+=parseFloat(c.borderTopWidth)||0,m+=parseFloat(c.borderLeftWidth)||0),e=d,d=b.offsetParent),f.offset.subtractsBorderForOverflowNotVisible&&c.overflow!=="visible"&&(l+=parseFloat(c.borderTopWidth)||0,m+=parseFloat(c.borderLeftWidth)||0),k=c}if(k.position==="relative"||k.position==="static")l+=i.offsetTop,m+=i.offsetLeft;return f.offset.supportsFixedPosition&&k.position==="fixed"&&(l+=Math.max(h.scrollTop,i.scrollTop),m+=Math.max(h.scrollLeft,i.scrollLeft)),{top:l,left:m}},f.offset={initialize:function(){var a=c.body,b=c.createElement("div"),d,e,g,h,i=parseFloat(f.css(a,"marginTop"))||0,j="<div style='position:absolute;top:0;left:0;margin:0;border:5px solid #000;padding:0;width:1px;height:1px;'><div></div></div><table style='position:absolute;top:0;left:0;margin:0;border:5px solid #000;padding:0;width:1px;height:1px;' cellpadding='0' cellspacing='0'><tr><td></td></tr></table>";f.extend(b.style,{position:"absolute",top:0,left:0,margin:0,border:0,width:"1px",height:"1px",visibility:"hidden"}),b.innerHTML=j,a.insertBefore(b,a.firstChild),d=b.firstChild,e=d.firstChild,h=d.nextSibling.firstChild.firstChild,this.doesNotAddBorder=e.offsetTop!==5,this.doesAddBorderForTableAndCells=h.offsetTop===5,e.style.position="fixed",e.style.top="20px",this.supportsFixedPosition=e.offsetTop===20||e.offsetTop===15,e.style.position=e.style.top="",d.style.overflow="hidden",d.style.position="relative",this.subtractsBorderForOverflowNotVisible=e.offsetTop===-5,this.doesNotIncludeMarginInBodyOffset=a.offsetTop!==i,a.removeChild(b),f.offset.initialize=f.noop},bodyOffset:function(a){var b=a.offsetTop,c=a.offsetLeft;return f.offset.initialize(),f.offset.doesNotIncludeMarginInBodyOffset&&(b+=parseFloat(f.css(a,"marginTop"))||0,c+=parseFloat(f.css(a,"marginLeft"))||0),{top:b,left:c}},setOffset:function(a,b,c){var d=f.css(a,"position");d==="static"&&(a.style.position="relative");var e=f(a),g=e.offset(),h=f.css(a,"top"),i=f.css(a,"left"),j=(d==="absolute"||d==="fixed")&&f.inArray("auto",[h,i])>-1,k={},l={},m,n;j?(l=e.position(),m=l.top,n=l.left):(m=parseFloat(h)||0,n=parseFloat(i)||0),f.isFunction(b)&&(b=b.call(a,c,g)),b.top!=null&&(k.top=b.top-g.top+m),b.left!=null&&(k.left=b.left-g.left+n),"using"in b?b.using.call(a,k):e.css(k)}},f.fn.extend({position:function(){if(!this[0])return null;var a=this[0],b=this.offsetParent(),c=this.offset(),d=cv.test(b[0].nodeName)?{top:0,left:0}:b.offset();return c.top-=parseFloat(f.css(a,"marginTop"))||0,c.left-=parseFloat(f.css(a,"marginLeft"))||0,d.top+=parseFloat(f.css(b[0],"borderTopWidth"))||0,d.left+=parseFloat(f.css(b[0],"borderLeftWidth"))||0,{top:c.top-d.top,left:c.left-d.left}},offsetParent:function(){return this.map(function(){var a=this.offsetParent||c.body;while(a&&!cv.test(a.nodeName)&&f.css(a,"position")==="static")a=a.offsetParent;return a})}}),f.each(["Left","Top"],function(a,c){var d="scroll"+c;f.fn[d]=function(c){var e,g;return c===b?(e=this[0],e?(g=cw(e),g?"pageXOffset"in g?g[a?"pageYOffset":"pageXOffset"]:f.support.boxModel&&g.document.documentElement[d]||g.document.body[d]:e[d]):null):this.each(function(){g=cw(this),g?g.scrollTo(a?f(g).scrollLeft():c,a?c:f(g).scrollTop()):this[d]=c})}}),f.each(["Height","Width"],function(a,c){var d=c.toLowerCase();f.fn["inner"+c]=function(){return this[0]?parseFloat(f.css(this[0],d,"padding")):null},f.fn["outer"+c]=function(a){return this[0]?parseFloat(f.css(this[0],d,a?"margin":"border")):null},f.fn[d]=function(a){var e=this[0];if(!e)return a==null?null:this;if(f.isFunction(a))return this.each(function(b){var c=f(this);c[d](a.call(this,b,c[d]()))});if(f.isWindow(e)){var g=e.document.documentElement["client"+c];return e.document.compatMode==="CSS1Compat"&&g||e.document.body["client"+c]||g}if(e.nodeType===9)return Math.max(e.documentElement["client"+c],e.body["scroll"+c],e.documentElement["scroll"+c],e.body["offset"+c],e.documentElement["offset"+c]);if(a===b){var h=f.css(e,d),i=parseFloat(h);return f.isNaN(i)?h:i}return this.css(d,typeof a=="string"?a:a+"px")}}),a.jQuery=a.$=f})(window),function(a,b){function c(b,c){var e=b.nodeName.toLowerCase();return"area"===e?(c=b.parentNode,e=c.name,!b.href||!e||c.nodeName.toLowerCase()!=="map"?!1:(b=a("img[usemap=#"+e+"]")[0],!!b&&d(b))):(/input|select|textarea|button|object/.test(e)?!b.disabled:"a"==e?b.href||c:c)&&d(b)}function d(b){return!a(b).parents().andSelf().filter(function(){return a.curCSS(this,"visibility")==="hidden"||a.expr.filters.hidden(this)}).length}a.ui=a.ui||{},a.ui.version||(a.extend(a.ui,{version:"1.8.13",keyCode:{ALT:18,BACKSPACE:8,CAPS_LOCK:20,COMMA:188,COMMAND:91,COMMAND_LEFT:91,COMMAND_RIGHT:93,CONTROL:17,DELETE:46,DOWN:40,END:35,ENTER:13,ESCAPE:27,HOME:36,INSERT:45,LEFT:37,MENU:93,NUMPAD_ADD:107,NUMPAD_DECIMAL:110,NUMPAD_DIVIDE:111,NUMPAD_ENTER:108,NUMPAD_MULTIPLY:106,NUMPAD_SUBTRACT:109,PAGE_DOWN:34,PAGE_UP:33,PERIOD:190,RIGHT:39,SHIFT:16,SPACE:32,TAB:9,UP:38,WINDOWS:91}}),a.fn.extend({_focus:a.fn.focus,focus:function(b,c){return typeof b=="number"?this.each(function(){var d=this;setTimeout(function(){a(d).focus(),c&&c.call(d)},b)}):this._focus.apply(this,arguments)},scrollParent:function(){var b;return b=a.browser.msie&&/(static|relative)/.test(this.css("position"))||/absolute/.test(this.css("position"))?this.parents().filter(function(){return/(relative|absolute|fixed)/.test(a.curCSS(this,"position",1))&&/(auto|scroll)/.test(a.curCSS(this,"overflow",1)+a.curCSS(this,"overflow-y",1)+a.curCSS(this,"overflow-x",1))}).eq(0):this.parents().filter(function(){return/(auto|scroll)/.test(a.curCSS(this,"overflow",1)+a.curCSS(this,"overflow-y",1)+a.curCSS(this,"overflow-x",1))}).eq(0),/fixed/.test(this.css("position"))||!b.length?a(document):b},zIndex:function(c){if(c!==b)return this.css("zIndex",c);if(this.length){c=a(this[0]);for(var d;c.length&&c[0]!==document;){d=c.css("position");if(d==="absolute"||d==="relative"||d==="fixed"){d=parseInt(c.css("zIndex"),10);if(!isNaN(d)&&d!==0)return d}c=c.parent()}}return 0},disableSelection:function(){return this.bind((a.support.selectstart?"selectstart":"mousedown")+".ui-disableSelection",function(a){a.preventDefault()})},enableSelection:function(){return this.unbind(".ui-disableSelection")}}),a.each(["Width","Height"],function(c,d){function e(b,c,d,e){return a.each(f,function(){c-=parseFloat(a.curCSS(b,"padding"+this,!0))||0,d&&(c-=parseFloat(a.curCSS(b,"border"+this+"Width",!0))||0),e&&(c-=parseFloat(a.curCSS(b,"margin"+this,!0))||0)}),c}var f=d==="Width"?["Left","Right"]:["Top","Bottom"],g=d.toLowerCase(),h={innerWidth:a.fn.innerWidth,innerHeight:a.fn.innerHeight,outerWidth:a.fn.outerWidth,outerHeight:a.fn.outerHeight};a.fn["inner"+d]=function(c){return c===b?h["inner"+d].call(this):this.each(function(){a(this).css(g,e(this,c)+"px")})},a.fn["outer"+d]=function(b,c){return typeof b!="number"?h["outer"+d].call(this,b):this.each(function(){a(this).css(g,e(this,b,!0,c)+"px")})}}),a.extend(a.expr[":"],{data:function(b,c,d){return!!a.data(b,d[3])},focusable:function(b){return c(b,!isNaN(a.attr(b,"tabindex")))},tabbable:function(b){var d=a.attr(b,"tabindex"),e=isNaN(d);return(e||d>=0)&&c(b,!e)}}),a(function(){var b=document.body,c=b.appendChild(c=document.createElement("div"));a.extend(c.style,{minHeight:"100px",height:"auto",padding:0,borderWidth:0}),a.support.minHeight=c.offsetHeight===100,a.support.selectstart="onselectstart"in c,b.removeChild(c).style.display="none"}),a.extend(a.ui,{plugin:{add:function(b,c,d){b=a.ui[b].prototype;for(var e in d)b.plugins[e]=b.plugins[e]||[],b.plugins[e].push([c,d[e]])},call:function(a,b,c){if((b=a.plugins[b])&&a.element[0].parentNode)for(var d=0;d<b.length;d++)a.options[b[d][0]]&&b[d][1].apply(a.element,c)}},contains:function(a,b){return document.compareDocumentPosition?a.compareDocumentPosition(b)&16:a!==b&&a.contains(b)},hasScroll:function(b,c){if(a(b).css("overflow")==="hidden")return!1;c=c&&c==="left"?"scrollLeft":"scrollTop";var d=!1;return b[c]>0?!0:(b[c]=1,d=b[c]>0,b[c]=0,d)},isOverAxis:function(a,b,c){return a>b&&a<b+c},isOver:function(b,c,d,e,f,g){return a.ui.isOverAxis(b,d,f)&&a.ui.isOverAxis(c,e,g)}}))}(jQuery),function(a,b){if(a.cleanData){var c=a.cleanData;a.cleanData=function(b){for(var d=0,e;(e=b[d])!=null;d++)a(e).triggerHandler("remove");c(b)}}else{var d=a.fn.remove;a.fn.remove=function(b,c){return this.each(function(){return c||(!b||a.filter(b,[this]).length)&&a("*",this).add([this]).each(function(){a(this).triggerHandler("remove")}),d.call(a(this),b,c)})}}a.widget=function(b,c,d){var e=b.split(".")[0],f;b=b.split(".")[1],f=e+"-"+b,d||(d=c,c=a.Widget),a.expr[":"][f]=function(c){return!!a.data(c,b)},a[e]=a[e]||{},a[e][b]=function(a,b){arguments.length&&this._createWidget(a,b)},c=new c,c.options=a.extend(!0,{},c.options),a[e][b].prototype=a.extend(!0,c,{namespace:e,widgetName:b,widgetEventPrefix:a[e][b].prototype.widgetEventPrefix||b,widgetBaseClass:f},d),a.widget.bridge(b,a[e][b])},a.widget.bridge=function(c,d){a.fn[c]=function(e){var f=typeof e=="string",g=Array.prototype.slice.call(arguments,1),h=this;return e=!f&&g.length?a.extend.apply(null,[!0,e].concat(g)):e,f&&e.charAt(0)==="_"?h:(f?this.each(function(){var d=a.data(this,c),f=d&&a.isFunction(d[e])?d[e].apply(d,g):d;if(f!==d&&f!==b)return h=f,!1}):this.each(function(){var b=a.data(this,c);b?b.option(e||{})._init():a.data(this,c,new d(e,this))}),h)}},a.Widget=function(a,b){arguments.length&&this._createWidget(a,b)},a.Widget.prototype={widgetName:"widget",widgetEventPrefix:"",options:{disabled:!1},_createWidget:function(b,c){a.data(c,this.widgetName,this),this.element=a(c),this.options=a.extend(!0,{},this.options,this._getCreateOptions(),b);var d=this;this.element.bind("remove."+this.widgetName,function(){d.destroy()}),this._create(),this._trigger("create"),this._init()},_getCreateOptions:function(){return a.metadata&&a.metadata.get(this.element[0])[this.widgetName]},_create:function(){},_init:function(){},destroy:function(){this.element.unbind("."+this.widgetName).removeData(this.widgetName),this.widget().unbind("."+this.widgetName).removeAttr("aria-disabled").removeClass(this.widgetBaseClass+"-disabled ui-state-disabled")},widget:function(){return this.element},option:function(c,d){var e=c;if(arguments.length===0)return a.extend({},this.options);if(typeof c=="string"){if(d===b)return this.options[c];e={},e[c]=d}return this._setOptions(e),this},_setOptions:function(b){var c=this;return a.each(b,function(a,b){c._setOption(a,b)}),this},_setOption:function(a,b){return this.options[a]=b,a==="disabled"&&this.widget()[b?"addClass":"removeClass"](this.widgetBaseClass+"-disabled ui-state-disabled").attr("aria-disabled",b),this},enable:function(){return this._setOption("disabled",!1)},disable:function(){return this._setOption("disabled",!0)},_trigger:function(b,c,d){var e=this.options[b];c=a.Event(c),c.type=(b===this.widgetEventPrefix?b:this.widgetEventPrefix+b).toLowerCase(),d=d||{};if(c.originalEvent){b=a.event.props.length;for(var f;b;)f=a.event.props[--b],c[f]=c.originalEvent[f]}return this.element.trigger(c,d),!(a.isFunction(e)&&e.call(this.element[0],c,d)===!1||c.isDefaultPrevented())}}}(jQuery),function(a,b){var c=!1;a(document).mousedown(function(a){c=!1}),a.widget("ui.mouse",{options:{cancel:":input,option",distance:1,delay:0},_mouseInit:function(){var b=this;this.element.bind("mousedown."+this.widgetName,function(a){return b._mouseDown(a)}).bind("click."+this.widgetName,function(c){if(!0===a.data(c.target,b.widgetName+".preventClickEvent"))return a.removeData(c.target,b.widgetName+".preventClickEvent"),c.stopImmediatePropagation(),!1}),this.started=!1},_mouseDestroy:function(){this.element.unbind("."+this.widgetName)},_mouseDown:function(b){a(this.document||document).mousedown(function(a){c=!1});if(c)return;this._mouseStarted&&this._mouseUp(b),this._mouseDownEvent=b;var d=this,e=b.which==1,f=typeof this.options.cancel=="string"?a(b.target).parents().add(b.target).filter(this.options.cancel).length:!1;if(!e||f||!this._mouseCapture(b))return!0;this.mouseDelayMet=!this.options.delay,this.mouseDelayMet||(this._mouseDelayTimer=
setTimeout(function(){d.mouseDelayMet=!0},this.options.delay));if(this._mouseDistanceMet(b)&&this._mouseDelayMet(b)){this._mouseStarted=this._mouseStart(b)!==!1;if(!this._mouseStarted)return b.preventDefault(),!0}return!0===a.data(b.target,this.widgetName+".preventClickEvent")&&a.removeData(b.target,this.widgetName+".preventClickEvent"),this._mouseMoveDelegate=function(a){return d._mouseMove(a)},this._mouseUpDelegate=function(a){return d._mouseUp(a)},a(this.document||document).bind("mousemove."+this.widgetName,this._mouseMoveDelegate).bind("mouseup."+this.widgetName,this._mouseUpDelegate),b.preventDefault(),c=!0,!0},_mouseMove:function(b){return!a.browser.msie||(this.document||document).documentMode>=9||!!b.button?this._mouseStarted?(this._mouseDrag(b),b.preventDefault()):(this._mouseDistanceMet(b)&&this._mouseDelayMet(b)&&(this._mouseStarted=this._mouseStart(this._mouseDownEvent,b)!==!1,this._mouseStarted?this._mouseDrag(b):this._mouseUp(b)),!this._mouseStarted):this._mouseUp(b)},_mouseUp:function(b){return a(this.document||document).unbind("mousemove."+this.widgetName,this._mouseMoveDelegate).unbind("mouseup."+this.widgetName,this._mouseUpDelegate),this._mouseStarted&&(this._mouseStarted=!1,b.target==this._mouseDownEvent.target&&a.data(b.target,this.widgetName+".preventClickEvent",!0),this._mouseStop(b)),!1},_mouseDistanceMet:function(a){return Math.max(Math.abs(this._mouseDownEvent.pageX-a.pageX),Math.abs(this._mouseDownEvent.pageY-a.pageY))>=this.options.distance},_mouseDelayMet:function(a){return this.mouseDelayMet},_mouseStart:function(a){},_mouseDrag:function(a){},_mouseStop:function(a){},_mouseCapture:function(a){return!0}})}(jQuery),function(a){a.widget("ui.draggable",a.ui.mouse,{widgetEventPrefix:"drag",options:{addClasses:!0,appendTo:"parent",axis:!1,connectToSortable:!1,containment:!1,cursor:"auto",cursorAt:!1,grid:!1,handle:!1,helper:"original",iframeFix:!1,opacity:!1,refreshPositions:!1,revert:!1,revertDuration:500,scope:"default",scroll:!0,scrollSensitivity:20,scrollSpeed:20,snap:!1,snapMode:"both",snapTolerance:20,stack:!1,zIndex:!1},_create:function(){this.options.helper=="original"&&!/^(?:r|a|f)/.test(this.element.css("position"))&&(this.element[0].style.position="relative"),this.options.addClasses&&this.element.addClass("ui-draggable"),this.options.disabled&&this.element.addClass("ui-draggable-disabled"),this._mouseInit()},destroy:function(){if(this.element.data("draggable"))return this.element.removeData("draggable").unbind(".draggable").removeClass("ui-draggable ui-draggable-dragging ui-draggable-disabled"),this._mouseDestroy(),this},_mouseCapture:function(b){var c=this.options;return this.helper||c.disabled||a(b.target).is(".ui-resizable-handle")?!1:(this.handle=this._getHandle(b),this.handle?(a(c.iframeFix===!0?"iframe":c.iframeFix).each(function(){a('<div class="ui-draggable-iframeFix" style="background: #fff;"></div>').css({width:this.offsetWidth+"px",height:this.offsetHeight+"px",position:"absolute",opacity:"0.001",zIndex:1e3}).css(a(this).offset()).appendTo("body")}),!0):!1)},_mouseStart:function(b){var c=this.options;return this.helper=this._createHelper(b),this._cacheHelperProportions(),a.ui.ddmanager&&(a.ui.ddmanager.current=this),this._cacheMargins(),this.cssPosition=this.helper.css("position"),this.scrollParent=this.helper.scrollParent(),this.offset=this.positionAbs=this.element.offset(),this.offset={top:this.offset.top-this.margins.top,left:this.offset.left-this.margins.left},a.extend(this.offset,{click:{left:b.pageX-this.offset.left,top:b.pageY-this.offset.top},parent:this._getParentOffset(),relative:this._getRelativeOffset()}),this.originalPosition=this.position=this._generatePosition(b),this.originalPageX=b.pageX,this.originalPageY=b.pageY,c.cursorAt&&this._adjustOffsetFromHelper(c.cursorAt),c.containment&&this._setContainment(),this._trigger("start",b)===!1?(this._clear(),!1):(this._cacheHelperProportions(),a.ui.ddmanager&&!c.dropBehaviour&&a.ui.ddmanager.prepareOffsets(this,b),this.helper.addClass("ui-draggable-dragging"),this._mouseDrag(b,!0),!0)},_mouseDrag:function(b,c){this.position=this._generatePosition(b),this.positionAbs=this._convertPositionTo("absolute");if(!c){c=this._uiHash();if(this._trigger("drag",b,c)===!1)return this._mouseUp({}),!1;this.position=c.position}if(!this.options.axis||this.options.axis!="y")this.helper[0].style.left=this.position.left+"px";if(!this.options.axis||this.options.axis!="x")this.helper[0].style.top=this.position.top+"px";return a.ui.ddmanager&&a.ui.ddmanager.drag(this,b),!1},_mouseStop:function(b){var c=!1;a.ui.ddmanager&&!this.options.dropBehaviour&&(c=a.ui.ddmanager.drop(this,b)),this.dropped&&(c=this.dropped,this.dropped=!1);if((!this.element[0]||!this.element[0].parentNode)&&this.options.helper=="original")return!1;if(this.options.revert=="invalid"&&!c||this.options.revert=="valid"&&c||this.options.revert===!0||a.isFunction(this.options.revert)&&this.options.revert.call(this.element,c)){var e=this;a(this.helper).animate(this.originalPosition,parseInt(this.options.revertDuration,10),function(){e._trigger("stop",b)!==!1&&e._clear()})}else this._trigger("stop",b)!==!1&&this._clear();return!1},_mouseUp:function(b){return this.options.iframeFix===!0&&a("div.ui-draggable-iframeFix").each(function(){this.parentNode.removeChild(this)}),a.ui.mouse.prototype._mouseUp.call(this,b)},cancel:function(){return this.helper.is(".ui-draggable-dragging")?this._mouseUp({}):this._clear(),this},_getHandle:function(b){var c=!this.options.handle||!a(this.options.handle,this.element).length?!0:!1;return a(this.options.handle,this.element).find("*").andSelf().each(function(){this==b.target&&(c=!0)}),c},_createHelper:function(b){var c=this.options;return b=a.isFunction(c.helper)?a(c.helper.apply(this.element[0],[b])):c.helper=="clone"?this.element.clone().removeAttr("id"):this.element,b.parents("body").length||b.appendTo(c.appendTo=="parent"?this.element[0].parentNode:c.appendTo),b[0]!=this.element[0]&&!/(fixed|absolute)/.test(b.css("position"))&&b.css("position","absolute"),b},_adjustOffsetFromHelper:function(b){typeof b=="string"&&(b=b.split(" ")),a.isArray(b)&&(b={left:+b[0],top:+b[1]||0}),"left"in b&&(this.offset.click.left=b.left+this.margins.left),"right"in b&&(this.offset.click.left=this.helperProportions.width-b.right+this.margins.left),"top"in b&&(this.offset.click.top=b.top+this.margins.top),"bottom"in b&&(this.offset.click.top=this.helperProportions.height-b.bottom+this.margins.top)},_getParentOffset:function(){this.offsetParent=this.helper.offsetParent();var b=this.offsetParent.offset();this.cssPosition=="absolute"&&this.scrollParent[0]!=document&&a.ui.contains(this.scrollParent[0],this.offsetParent[0])&&(b.left+=this.scrollParent.scrollLeft(),b.top+=this.scrollParent.scrollTop());if(this.offsetParent[0]==document.body||this.offsetParent[0].tagName&&this.offsetParent[0].tagName.toLowerCase()=="html"&&a.browser.msie)b={top:0,left:0};return{top:b.top+(parseInt(this.offsetParent.css("borderTopWidth"),10)||0),left:b.left+(parseInt(this.offsetParent.css("borderLeftWidth"),10)||0)}},_getRelativeOffset:function(){if(this.cssPosition=="relative"){var a=this.element.position();return{top:a.top-(parseInt(this.helper.css("top"),10)||0)+this.scrollParent.scrollTop(),left:a.left-(parseInt(this.helper.css("left"),10)||0)+this.scrollParent.scrollLeft()}}return{top:0,left:0}},_cacheMargins:function(){this.margins={left:parseInt(this.element.css("marginLeft"),10)||0,top:parseInt(this.element.css("marginTop"),10)||0,right:parseInt(this.element.css("marginRight"),10)||0,bottom:parseInt(this.element.css("marginBottom"),10)||0}},_cacheHelperProportions:function(){this.helperProportions={width:this.helper.outerWidth(),height:this.helper.outerHeight()}},_setContainment:function(){var b=this.options;b.containment=="parent"&&(b.containment=this.helper[0].parentNode);if(b.containment=="document"||b.containment=="window")this.containment=[(b.containment=="document"?0:a(window).scrollLeft())-this.offset.relative.left-this.offset.parent.left,(b.containment=="document"?0:a(window).scrollTop())-this.offset.relative.top-this.offset.parent.top,(b.containment=="document"?0:a(window).scrollLeft())+a(b.containment=="document"?document:window).width()-this.helperProportions.width-this.margins.left,(b.containment=="document"?0:a(window).scrollTop())+(a(b.containment=="document"?document:window).height()||document.body.parentNode.scrollHeight)-this.helperProportions.height-this.margins.top];if(!/^(document|window|parent)$/.test(b.containment)&&b.containment.constructor!=Array){b=a(b.containment);var c=b[0];if(c){b.offset();var e=a(c).css("overflow")!="hidden";this.containment=[(parseInt(a(c).css("borderLeftWidth"),10)||0)+(parseInt(a(c).css("paddingLeft"),10)||0),(parseInt(a(c).css("borderTopWidth"),10)||0)+(parseInt(a(c).css("paddingTop"),10)||0),(e?Math.max(c.scrollWidth,c.offsetWidth):c.offsetWidth)-(parseInt(a(c).css("borderLeftWidth"),10)||0)-(parseInt(a(c).css("paddingRight"),10)||0)-this.helperProportions.width-this.margins.left-this.margins.right,(e?Math.max(c.scrollHeight,c.offsetHeight):c.offsetHeight)-(parseInt(a(c).css("borderTopWidth"),10)||0)-(parseInt(a(c).css("paddingBottom"),10)||0)-this.helperProportions.height-this.margins.top-this.margins.bottom],this.relative_container=b}}else b.containment.constructor==Array&&(this.containment=b.containment)},_convertPositionTo:function(b,c){c||(c=this.position),b=b=="absolute"?1:-1;var e=this.cssPosition=="absolute"&&(this.scrollParent[0]==document||!a.ui.contains(this.scrollParent[0],this.offsetParent[0]))?this.offsetParent:this.scrollParent,f=/(html|body)/i.test(e[0].tagName);return{top:c.top+this.offset.relative.top*b+this.offset.parent.top*b-(a.browser.safari&&a.browser.version<526&&this.cssPosition=="fixed"?0:(this.cssPosition=="fixed"?-this.scrollParent.scrollTop():f?0:e.scrollTop())*b),left:c.left+this.offset.relative.left*b+this.offset.parent.left*b-(a.browser.safari&&a.browser.version<526&&this.cssPosition=="fixed"?0:(this.cssPosition=="fixed"?-this.scrollParent.scrollLeft():f?0:e.scrollLeft())*b)}},_generatePosition:function(b){var c=this.options,e=this.cssPosition=="absolute"&&(this.scrollParent[0]==document||!a.ui.contains(this.scrollParent[0],this.offsetParent[0]))?this.offsetParent:this.scrollParent,f=/(html|body)/i.test(e[0].tagName),g=b.pageX,h=b.pageY;if(this.originalPosition){var i;this.containment&&(this.relative_container?(i=this.relative_container.offset(),i=[this.containment[0]+i.left,this.containment[1]+i.top,this.containment[2]+i.left,this.containment[3]+i.top]):i=this.containment,b.pageX-this.offset.click.left<i[0]&&(g=i[0]+this.offset.click.left),b.pageY-this.offset.click.top<i[1]&&(h=i[1]+this.offset.click.top),b.pageX-this.offset.click.left>i[2]&&(g=i[2]+this.offset.click.left),b.pageY-this.offset.click.top>i[3]&&(h=i[3]+this.offset.click.top)),c.grid&&(h=this.originalPageY+Math.round((h-this.originalPageY)/c.grid[1])*c.grid[1],h=i?h-this.offset.click.top<i[1]||h-this.offset.click.top>i[3]?h-this.offset.click.top<i[1]?h+c.grid[1]:h-c.grid[1]:h:h,g=this.originalPageX+Math.round((g-this.originalPageX)/c.grid[0])*c.grid[0],g=i?g-this.offset.click.left<i[0]||g-this.offset.click.left>i[2]?g-this.offset.click.left<i[0]?g+c.grid[0]:g-c.grid[0]:g:g)}return{top:h-this.offset.click.top-this.offset.relative.top-this.offset.parent.top+(a.browser.safari&&a.browser.version<526&&this.cssPosition=="fixed"?0:this.cssPosition=="fixed"?-this.scrollParent.scrollTop():f?0:e.scrollTop()),left:g-this.offset.click.left-this.offset.relative.left-this.offset.parent.left+(a.browser.safari&&a.browser.version<526&&this.cssPosition=="fixed"?0:this.cssPosition=="fixed"?-this.scrollParent.scrollLeft():f?0:e.scrollLeft())}},_clear:function(){this.helper.removeClass("ui-draggable-dragging"),this.helper[0]!=this.element[0]&&!this.cancelHelperRemoval&&this.helper.remove(),this.helper=null,this.cancelHelperRemoval=!1},_trigger:function(b,c,e){return e=e||this._uiHash(),a.ui.plugin.call(this,b,[c,e]),b=="drag"&&(this.positionAbs=this._convertPositionTo("absolute")),a.Widget.prototype._trigger.call(this,b,c,e)},plugins:{},_uiHash:function(){return{helper:this.helper,position:this.position,originalPosition:this.originalPosition,offset:this.positionAbs}}}),a.extend(a.ui.draggable,{version:"1.8.13"}),a.ui.plugin.add("draggable","connectToSortable",{start:function(b,c){var e=a(this).data("draggable"),f=e.options,g=a.extend({},c,{item:e.element});e.sortables=[],a(f.connectToSortable).each(function(){var c=a.data(this,"sortable");c&&!c.options.disabled&&(e.sortables.push({instance:c,shouldRevert:c.options.revert}),c.refreshPositions(),c._trigger("activate",b,g))})},stop:function(b,c){var e=a(this).data("draggable"),f=a.extend({},c,{item:e.element});a.each(e.sortables,function(){this.instance.isOver?(this.instance.isOver=0,e.cancelHelperRemoval=!0,this.instance.cancelHelperRemoval=!1,this.shouldRevert&&(this.instance.options.revert=!0),this.instance._mouseStop(b),this.instance.options.helper=this.instance.options._helper,e.options.helper=="original"&&this.instance.currentItem.css({top:"auto",left:"auto"})):(this.instance.cancelHelperRemoval=!1,this.instance._trigger("deactivate",b,f))})},drag:function(b,c){var e=a(this).data("draggable"),f=this;a.each(e.sortables,function(){this.instance.positionAbs=e.positionAbs,this.instance.helperProportions=e.helperProportions,this.instance.offset.click=e.offset.click,this.instance._intersectsWith(this.instance.containerCache)?(this.instance.isOver||(this.instance.isOver=1,this.instance.currentItem=a(f).clone().removeAttr("id").appendTo(this.instance.element).data("sortable-item",!0),this.instance.options._helper=this.instance.options.helper,this.instance.options.helper=function(){return c.helper[0]},b.target=this.instance.currentItem[0],this.instance._mouseCapture(b,!0),this.instance._mouseStart(b,!0,!0),this.instance.offset.click.top=e.offset.click.top,this.instance.offset.click.left=e.offset.click.left,this.instance.offset.parent.left-=e.offset.parent.left-this.instance.offset.parent.left,this.instance.offset.parent.top-=e.offset.parent.top-this.instance.offset.parent.top,e._trigger("toSortable",b),e.dropped=this.instance.element,e.currentItem=e.element,this.instance.fromOutside=e),this.instance.currentItem&&this.instance._mouseDrag(b)):this.instance.isOver&&(this.instance.isOver=0,this.instance.cancelHelperRemoval=!0,this.instance.options.revert=!1,this.instance._trigger("out",b,this.instance._uiHash(this.instance)),this.instance._mouseStop(b,!0),this.instance.options.helper=this.instance.options._helper,this.instance.currentItem.remove(),this.instance.placeholder&&this.instance.placeholder.remove(),e._trigger("fromSortable",b),e.dropped=!1)})}}),a.ui.plugin.add("draggable","cursor",{start:function(){var b=a("body"),c=a(this).data("draggable").options;b.css("cursor")&&(c._cursor=b.css("cursor")),b.css("cursor",c.cursor)},stop:function(){var b=a(this).data("draggable").options;b._cursor&&a("body").css("cursor",b._cursor)}}),a.ui.plugin.add("draggable","opacity",{start:function(b,c){b=a(c.helper),c=a(this).data("draggable").options,b.css("opacity")&&(c._opacity=b.css("opacity")),b.css("opacity",c.opacity)},stop:function(b,c){b=a(this).data("draggable").options,b._opacity&&a(c.helper).css("opacity",b._opacity)}}),a.ui.plugin.add("draggable","scroll",{start:function(){var b=a(this).data("draggable");b.scrollParent[0]!=document&&b.scrollParent[0].tagName!="HTML"&&(b.overflowOffset=b.scrollParent.offset())},drag:function(b){var c=a(this).data("draggable"),e=c.options,f=!1;if(c.scrollParent[0]!=document&&c.scrollParent[0].tagName!="HTML"){if(!e.axis||e.axis!="x")c.overflowOffset.top+c.scrollParent[0].offsetHeight-b.pageY<e.scrollSensitivity?c.scrollParent[0].scrollTop=f=c.scrollParent[0].scrollTop+e.scrollSpeed:b.pageY-c.overflowOffset.top<e.scrollSensitivity&&(c.scrollParent[0].scrollTop=f=c.scrollParent[0].scrollTop-e.scrollSpeed);if(!e.axis||e.axis!="y")c.overflowOffset.left+c.scrollParent[0].offsetWidth-b.pageX<e.scrollSensitivity?c.scrollParent[0].scrollLeft=f=c.scrollParent[0].scrollLeft+e.scrollSpeed:b.pageX-c.overflowOffset.left<e.scrollSensitivity&&(c.scrollParent[0].scrollLeft=f=c.scrollParent[0].scrollLeft-e.scrollSpeed)}else{if(!e.axis||e.axis!="x")b.pageY-a(document).scrollTop()<e.scrollSensitivity?f=a(document).scrollTop(a(document).scrollTop()-e.scrollSpeed):a(window).height()-(b.pageY-a(document).scrollTop())<e.scrollSensitivity&&(f=a(document).scrollTop(a(document).scrollTop()+e.scrollSpeed));if(!e.axis||e.axis!="y")b.pageX-a(document).scrollLeft()<e.scrollSensitivity?f=a(document).scrollLeft(a(document).scrollLeft()-e.scrollSpeed):a(window).width()-(b.pageX-a(document).scrollLeft())<e.scrollSensitivity&&(f=a(document).scrollLeft(a(document).scrollLeft()+e.scrollSpeed))}f!==!1&&a.ui.ddmanager&&!e.dropBehaviour&&a.ui.ddmanager.prepareOffsets(c,b)}}),a.ui.plugin.add("draggable","snap",{start:function(){var b=a(this).data("draggable"),c=b.options;b.snapElements=[],a(c.snap.constructor!=String?c.snap.items||":data(draggable)":c.snap).each(function(){var c=a(this),e=c.offset();this!=b.element[0]&&b.snapElements.push({item:this,width:c.outerWidth(),height:c.outerHeight(),top:e.top,left:e.left})})},drag:function(b,c){for(var e=a(this).data("draggable"),f=e.options,g=f.snapTolerance,h=c.offset.left,i=h+e.helperProportions.width,j=c.offset.top,k=j+e.helperProportions.height,l=e.snapElements.length-1;l>=0;l--){var m=e.snapElements[l].left,n=m+e.snapElements[l].width,o=e.snapElements[l].top,p=o+e.snapElements[l].height;if(m-g<h&&h<n+g&&o-g<j&&j<p+g||m-g<h&&h<n+g&&o-g<k&&k<p+g||m-g<i&&i<n+g&&o-g<j&&j<p+g||m-g<i&&i<n+g&&o-g<k&&k<p+g){if(f.snapMode!="inner"){var q=Math.abs(o-k)<=g,r=Math.abs(p-j)<=g,s=Math.abs(m-i)<=g,t=Math.abs(n-h)<=g;q&&(c.position.top=e._convertPositionTo("relative",{top:o-e.helperProportions.height,left:0}).top-e.margins.top),r&&(c.position.top=e._convertPositionTo("relative",{top:p,left:0}).top-e.margins.top),s&&(c.position.left=e._convertPositionTo("relative",{top:0,left:m-e.helperProportions.width}).left-e.margins.left),t&&(c.position.left=e._convertPositionTo("relative",{top:0,left:n}).left-e.margins.left)}var u=q||r||s||t;f.snapMode!="outer"&&(q=Math.abs(o-j)<=g,r=Math.abs(p-k)<=g,s=Math.abs(m-h)<=g,t=Math.abs(n-i)<=g,q&&(c.position.top=e._convertPositionTo("relative",{top:o,left:0}).top-e.margins.top),r&&(c.position.top=e._convertPositionTo("relative",{top:p-e.helperProportions.height,left:0}).top-e.margins.top),s&&(c.position.left=e._convertPositionTo("relative",{top:0,left:m}).left-e.margins.left),t&&(c.position.left=e._convertPositionTo("relative",{top:0,left:n-e.helperProportions.width}).left-e.margins.left)),!e.snapElements[l].snapping&&(q||r||s||t||u)&&e.options.snap.snap&&e.options.snap.snap.call(e.element,b,a.extend(e._uiHash(),{snapItem:e.snapElements[l].item})),e.snapElements[l].snapping=q||r||s||t||u}else e.snapElements[l].snapping&&e.options.snap.release&&e.options.snap.release.call(e.element,b,a.extend(e._uiHash(),{snapItem:e.snapElements[l].item})),e.snapElements[l].snapping=!1}}}),a.ui.plugin.add("draggable","stack",{start:function(){var b=a(this).data("draggable").options;b=a.makeArray(a(b.stack)).sort(function(b,c){return(parseInt(a(b).css("zIndex"),10)||0)-(parseInt(a(c).css("zIndex"),10)||0)});if(b.length){var c=parseInt(b[0].style.zIndex)||0;a(b).each(function(a){this.style.zIndex=c+a}),this[0].style.zIndex=c+b.length}}}),a.ui.plugin.add("draggable","zIndex",{start:function(b,c){b=a(c.helper),c=a(this).data("draggable").options,b.css("zIndex")&&(c._zIndex=b.css("zIndex")),b.css("zIndex",c.zIndex)},stop:function(b,c){b=a(this).data("draggable").options,b._zIndex&&a(c.helper).css("zIndex",b._zIndex)}})}(jQuery),function(a,b){a.widget("ui.sortable",a.ui.mouse,{widgetEventPrefix:"sort",options:{appendTo:"parent",axis:!1,connectWith:!1,containment:!1,cursor:"auto",cursorAt:!1,dropOnEmpty:!0,forcePlaceholderSize:!1,forceHelperSize:!1,grid:!1,handle:!1,helper:"original",items:"> *",opacity:!1,placeholder:!1,revert:!1,scroll:!0,scrollSensitivity:20,scrollSpeed:20,scope:"default",tolerance:"intersect",zIndex:1e3},_create:function(){var a=this.options;this.document=a.document,this.containerCache={},this.element.addClass("ui-sortable"),this.refresh(),this.floating=this.items.length?a.axis==="x"||/left|right/.test(this.items[0].item.css("float"))||/inline|table-cell/.test(this.items[0].item.css("display")):!1,this.offset=this.element.offset(),this._mouseInit()},destroy:function(){this.element.removeClass("ui-sortable ui-sortable-disabled").removeData("sortable").unbind(".sortable"),this._mouseDestroy();for(var a=this.items.length-1;a>=0;a--)this.items[a].item.removeData("sortable-item");return this},_setOption:function(b,c){b==="disabled"?(this.options[b]=c,this.widget()[c?"addClass":"removeClass"]("ui-sortable-disabled")):a.Widget.prototype._setOption.apply(this,arguments)},_mouseCapture:function(b,c){if(this.reverting)return!1;if(this.options.disabled||this.options.type=="static")return!1;this._refreshItems(b);var d=null,e=this,f=a(b.target).parents().each(function(){if(a.data(this,"sortable-item")==e)return d=a(this),!1});a.data(b.target,"sortable-item")==e&&(d=a(b.target));if(!d)return!1;if(this.options.handle&&!c){var g=!1;a(this.options.handle,d).find("*").andSelf().each(function(){this==b.target&&(g=!0)});if(!g)return!1}return this.currentItem=d,this._removeCurrentsFromItems(),!0},_mouseStart:function(b,c,d){var e=this.options,f=this;this.currentContainer=this,this.refreshPositions(),this.helper=this._createHelper(b),this._cacheHelperProportions(),this._cacheMargins(),this.scrollParent=this.helper.scrollParent(),this.offset=this.currentItem.offset(),this.offset={top:this.offset.top-this.margins.top,left:this.offset.left-this.margins.left},this.helper.css("position","absolute"),this.cssPosition=this.helper.css("position"),a.extend(this.offset,{click:{left:b.pageX-this.offset.left,top:b.pageY-this.offset.top},parent:this._getParentOffset(),relative:this._getRelativeOffset()}),this.originalPosition=this._generatePosition(b),this.originalPageX=b.pageX,this.originalPageY=b.pageY,e.cursorAt&&this._adjustOffsetFromHelper(e.cursorAt),this.domPosition={prev:this.currentItem.prev()[0],parent:this.currentItem.parent()[0]},this.helper[0]!=this.currentItem[0]&&this.currentItem.hide(),this._createPlaceholder(),e.containment&&this._setContainment(),e.cursor&&(a("body").css("cursor")&&(this._storedCursor=a("body").css("cursor")),a("body").css("cursor",e.cursor)),e.opacity&&(this.helper.css("opacity")&&(this._storedOpacity=this.helper.css("opacity")),this.helper.css("opacity",e.opacity)),e.zIndex&&(this.helper.css("zIndex")&&(this._storedZIndex=this.helper.css("zIndex")),this.helper.css("zIndex",e.zIndex)),this.scrollParent[0]!=(this.document||document)&&this.scrollParent[0].tagName!="HTML"&&(this.overflowOffset=this.scrollParent.offset()),this._trigger("start",b,this._uiHash()),this._preserveHelperProportions||this._cacheHelperProportions();if(!d)for(var g=this.containers.length-1;g>=0;g--)this.containers[g]._trigger("activate",b,f._uiHash(this));return a.ui.ddmanager&&(a.ui.ddmanager.current=this),a.ui.ddmanager&&!e.dropBehaviour&&a.ui.ddmanager.prepareOffsets(this,b),this.dragging=!0,this.helper.addClass("ui-sortable-helper"),this._mouseDrag(b),!0},_mouseDrag:function(b){this.position=this._generatePosition(b),this.positionAbs=this._convertPositionTo("absolute"),this.lastPositionAbs||(this.lastPositionAbs=this.positionAbs);if(this.options.scroll){var c=this.options,d=!1;this.scrollParent[0]!=(this.document||document)&&this.scrollParent[0].tagName!="HTML"?(this.overflowOffset.top+this.scrollParent[0].offsetHeight-b.pageY<c.scrollSensitivity?this.scrollParent[0].scrollTop=d=this.scrollParent[0].scrollTop+c.scrollSpeed:b.pageY-this.overflowOffset.top<c.scrollSensitivity&&(this.scrollParent[0].scrollTop=d=this.scrollParent[0].scrollTop-c.scrollSpeed),this.overflowOffset.left+this.scrollParent[0].offsetWidth-b.pageX<c.scrollSensitivity?this.scrollParent[0].scrollLeft=d=this.scrollParent[0].scrollLeft+c.scrollSpeed:b.pageX-this.overflowOffset.left<c.scrollSensitivity&&(this.scrollParent[0].scrollLeft=d=this.scrollParent[0].scrollLeft-c.scrollSpeed)):(b.pageY-a(this.document||document).scrollTop()<c.scrollSensitivity?d=a(this.document||document).scrollTop(a(this.document||document).scrollTop()-c.scrollSpeed):a(window).height()-(b.pageY-a(this.document||document).scrollTop())<c.scrollSensitivity&&(d=a(this.document||document).scrollTop(a(this.document||document).scrollTop()+c.scrollSpeed)),b.pageX-a(this.document||document).scrollLeft()<c.scrollSensitivity?d=a(this.document||document).scrollLeft(a(this.document||document).scrollLeft()-c.scrollSpeed):a(window).width()-(b.pageX-a(this.document||document).scrollLeft())<c.scrollSensitivity&&(d=a(this.document||document).scrollLeft(a(this.document||document).scrollLeft()+c.scrollSpeed))),d!==!1&&a.ui.ddmanager&&!c.dropBehaviour&&a.ui.ddmanager.prepareOffsets(this,b)}this.positionAbs=this._convertPositionTo("absolute");if(!this.options.axis||this.options.axis!="y")this.helper[0].style.left=this.position.left+"px";if(!this.options.axis||this.options.axis!="x")this.helper[0].style.top=this.position.top+"px";for(var e=this.items.length-1;e>=0;e--){var f=this.items[e],g=f.item[0],h=this._intersectsWithPointer(f);if(!h)continue;if(g!=this.currentItem[0]&&this.placeholder[h==1?"next":"prev"]()[0]!=g&&!a.ui.contains(this.placeholder[0],g)&&(this.options.type=="semi-dynamic"?!a.ui.contains(this.element[0],g):!0)){this.direction=h==1?"down":"up";if(this.options.tolerance=="pointer"||this._intersectsWithSides(f))this._rearrange(b,f);else break;this._trigger("change",b,this._uiHash());break}}return this._contactContainers(b),a.ui.ddmanager&&a.ui.ddmanager.drag(this,b),this._trigger("sort",b,this._uiHash()),this.lastPositionAbs=this.positionAbs,!1},_mouseStop:function(b,c){if(!b)return;a.ui.ddmanager&&!this.options.dropBehaviour&&a.ui.ddmanager.drop(this,b);if(this.options.revert){var d=this,e=d.placeholder.offset();d.reverting=!0,a(this.helper).animate({left:e.left-this.offset.parent.left-d.margins.left+(this.offsetParent[0]==(this.document||document).body?0:this.offsetParent[0].scrollLeft),top:e.top-this.offset.parent.top-d.margins.top+(this.offsetParent[0]==(this.document||document).body?0:this.offsetParent[0].scrollTop)},parseInt(this.options.revert,10)||500,function(){d._clear(b)})}else this._clear(b,c);return!1},cancel:function(){var b=this;if(this.dragging){this._mouseUp({target:null}),this.options.helper=="original"?this.currentItem.css(this._storedCSS).removeClass("ui-sortable-helper"):this.currentItem.show();for(var c=this.containers.length-1;c>=0;c--)this.containers[c]._trigger("deactivate",null,b._uiHash(this)),this.containers[c].containerCache.over&&(this.containers[c]._trigger("out",null,b._uiHash(this)),this.containers[c].containerCache.over=0)}return this.placeholder&&(this.placeholder[0].parentNode&&this.placeholder[0].parentNode.removeChild(this.placeholder[0]),this.options.helper!="original"&&this.helper&&this.helper[0].parentNode&&this.helper.remove(),a.extend(this,{helper:null,dragging:!1,reverting:!1,_noFinalSort:null}),this.domPosition.prev?a(this.domPosition.prev).after(this.currentItem):a(this.domPosition.parent).prepend(this.currentItem)),this},serialize:function(b){var c=this._getItemsAsjQuery(b&&b.connected),d=[];return b=b||{},a(c).each(function(){var c=(a(b.item||this).attr(b.attribute||"id")||"").match(b.expression||/(.+)[-=_](.+)/);c&&d.push((b.key||c[1]+"[]")+"="+(b.key&&b.expression?c[1]:c[2]))}),!d.length&&b.key&&d.push(b.key+"="),d.join("&")},toArray:function(b){var c=this._getItemsAsjQuery(b&&b.connected),d=[];return b=b||{},c.each(function(){d.push(a(b.item||this).attr(b.attribute||"id")||"")}),d},_intersectsWith:function(a){var b=this.positionAbs.left,c=b+this.helperProportions.width,d=this.positionAbs.top,e=d+this.helperProportions.height,f=a.left,g=f+a.width,h=a.top,i=h+a.height,j=this.offset.click.top,k=this.offset.click.left,l=d+j>h&&d+j<i&&b+k>f&&b+k<g;return this.options.tolerance=="pointer"||this.options.forcePointerForContainers||this.options.tolerance!="pointer"&&this.helperProportions[this.floating?"width":"height"]>a[this.floating?"width":"height"]?l:f<b+this.helperProportions.width/2&&c-this.helperProportions.width/2<g&&h<d+this.helperProportions.height/2&&e-this.helperProportions.height/2<i},_intersectsWithPointer:function(b){var c=a.ui.isOverAxis(this.positionAbs.top+this.offset.click.top,b.top,b.height),d=a.ui.isOverAxis(this.positionAbs.left+this.offset.click.left,b.left,b.width),e=c&&d,f=this._getDragVerticalDirection(),g=this._getDragHorizontalDirection();return e?this.floating?g&&g=="right"||f=="down"?2:1:f&&(f=="down"?2:1):!1},_intersectsWithSides:function(b){var c=a.ui.isOverAxis(this.positionAbs.top+this.offset.click.top,b.top+b.height/2,b.height),d=a.ui.isOverAxis(this.positionAbs.left+this.offset.click.left,b.left+b.width/2,b.width),e=this._getDragVerticalDirection(),f=this._getDragHorizontalDirection();return this.floating&&f?f=="right"&&d||f=="left"&&!d:e&&(e=="down"&&c||e=="up"&&!c)},_getDragVerticalDirection:function(){var a=this.positionAbs.top-this.lastPositionAbs.top;return a!=0&&(a>0?"down":"up")},_getDragHorizontalDirection:function(){var a=this.positionAbs.left-this.lastPositionAbs.left;return a!=0&&(a>0?"right":"left")},refresh:function(a){return this._refreshItems(a),this.refreshPositions(),this},_connectWith:function(){var a=this.options;return a.connectWith.constructor==String?[a.connectWith]:a.connectWith},_getItemsAsjQuery:function(b){var c=this,d=[],e=[],f=this._connectWith();if(f&&b)for(var g=f.length-1;g>=0;g--){var h=a(f[g]);for(var i=h.length-1;i>=0;i--){var j=a.data(h[i],"sortable");j&&j!=this&&!j.options.disabled&&e.push([a.isFunction(j.options.items)?j.options.items.call(j.element):a(j.options.items,j.element).not(".ui-sortable-helper").not(".ui-sortable-placeholder"),j])}}e.push([a.isFunction(this.options.items)?this.options.items.call(this.element,null,{options:this.options,item:this.currentItem}):a(this.options.items,this.element).not(".ui-sortable-helper").not(".ui-sortable-placeholder"),this]);for(var g=e.length-1;g>=0;g--)e[g][0].each(function(){d.push(this)});return a(d)},_removeCurrentsFromItems:function(){var a=this.currentItem.find(":data(sortable-item)");for(var b=0;b<this.items.length;b++)for(var c=0;c<a.length;c++)a[c]==this.items[b].item[0]&&this.items.splice(b,1)},_refreshItems:function(b){this.items=[],this.containers=[this];var c=this.items,d=this,e=[[a.isFunction(this.options.items)?this.options.items.call(this.element[0],b,{item:this.currentItem}):a(this.options.items,this.element),this]],f=this._connectWith();if(f)for(var g=f.length-1;g>=0;g--){var h=a(f[g]);for(var i=h.length-1;i>=0;i--){var j=a.data(h[i],"sortable");j&&j!=this&&!j.options.disabled&&(e.push([a.isFunction(j.options.items)?j.options.items.call(j.element[0],b,{item:this.currentItem}):a(j.options.items,j.element),j]),this.containers.push(j))}}for(var g=e.length-1;g>=0;g--){var k=e[g][1],l=e[g][0];for(var i=0,m=l.length;i<m;i++){var n=a(l[i]);n.data("sortable-item",k),c.push({item:n,instance:k,width:0,height:0,left:0,top:0})}}},refreshPositions:function(b){this.offsetParent&&this.helper&&(this.offset.parent=this._getParentOffset());for(var c=this.items.length-1;c>=0;c--){var d=this.items[c];if(d.instance!=this.currentContainer&&this.currentContainer&&d.item[0]!=this.currentItem[0])continue;var e=this.options.toleranceElement?a(this.options.toleranceElement,d.item):d.item;b||(d.width=e.outerWidth(),d.height=e.outerHeight());var f=e.offset();d.left=f.left,d.top=f.top}if(this.options.custom&&this.options.custom.refreshContainers)this.options.custom.refreshContainers.call(this);else for(var c=this.containers.length-1;c>=0;c--){var f=this.containers[c].element.offset();this.containers[c].containerCache.left=f.left,this.containers[c].containerCache.top=f.top,this.containers[c].containerCache.width=this.containers[c].element.outerWidth(),this.containers[c].containerCache.height=this.containers[c].element.outerHeight()}return this},_createPlaceholder:function(b){var c=b||this,d=c.options;if(!d.placeholder||d.placeholder.constructor==String){var e=d.placeholder;d.placeholder={element:function(){var b=a((this.document||document).createElement(c.currentItem[0].nodeName)).addClass(e||c.currentItem[0].className+" ui-sortable-placeholder").removeClass("ui-sortable-helper")[0];return e||(b.style.visibility="hidden"),b},update:function(a,b){if(e&&!d.forcePlaceholderSize)return;b.height()||b.height(c.currentItem.innerHeight()-parseInt(c.currentItem.css("paddingTop")||0,10)-parseInt(c.currentItem.css("paddingBottom")||0,10)),b
.width()||b.width(c.currentItem.innerWidth()-parseInt(c.currentItem.css("paddingLeft")||0,10)-parseInt(c.currentItem.css("paddingRight")||0,10))}}}c.placeholder=a(d.placeholder.element.call(c.element,c.currentItem)),c.currentItem.after(c.placeholder),d.placeholder.update(c,c.placeholder)},_contactContainers:function(b){var c=null,d=null;for(var e=this.containers.length-1;e>=0;e--){if(a.ui.contains(this.currentItem[0],this.containers[e].element[0]))continue;if(this._intersectsWith(this.containers[e].containerCache)){if(c&&a.ui.contains(this.containers[e].element[0],c.element[0]))continue;c=this.containers[e],d=e}else this.containers[e].containerCache.over&&(this.containers[e]._trigger("out",b,this._uiHash(this)),this.containers[e].containerCache.over=0)}if(!c)return;if(this.containers.length===1)this.containers[d]._trigger("over",b,this._uiHash(this)),this.containers[d].containerCache.over=1;else if(this.currentContainer!=this.containers[d]){var f=1e4,g=null,h=this.positionAbs[this.containers[d].floating?"left":"top"];for(var i=this.items.length-1;i>=0;i--){if(!a.ui.contains(this.containers[d].element[0],this.items[i].item[0]))continue;var j=this.items[i][this.containers[d].floating?"left":"top"];Math.abs(j-h)<f&&(f=Math.abs(j-h),g=this.items[i])}if(!g&&!this.options.dropOnEmpty)return;this.currentContainer=this.containers[d],g?this._rearrange(b,g,null,!0):this._rearrange(b,null,this.containers[d].element,!0),this._trigger("change",b,this._uiHash()),this.containers[d]._trigger("change",b,this._uiHash(this)),this.options.placeholder.update(this.currentContainer,this.placeholder),this.containers[d]._trigger("over",b,this._uiHash(this)),this.containers[d].containerCache.over=1}},_createHelper:function(b){var c=this.options,d=a.isFunction(c.helper)?a(c.helper.apply(this.element[0],[b,this.currentItem])):c.helper=="clone"?this.currentItem.clone():this.currentItem;return d.parents("body").length||a(c.appendTo!="parent"?c.appendTo:this.currentItem[0].parentNode)[0].appendChild(d[0]),d[0]==this.currentItem[0]&&(this._storedCSS={width:this.currentItem[0].style.width,height:this.currentItem[0].style.height,position:this.currentItem.css("position"),top:this.currentItem.css("top"),left:this.currentItem.css("left")}),(d[0].style.width==""||c.forceHelperSize)&&d.width(this.currentItem.width()),(d[0].style.height==""||c.forceHelperSize)&&d.height(this.currentItem.height()),d},_adjustOffsetFromHelper:function(b){typeof b=="string"&&(b=b.split(" ")),a.isArray(b)&&(b={left:+b[0],top:+b[1]||0}),"left"in b&&(this.offset.click.left=b.left+this.margins.left),"right"in b&&(this.offset.click.left=this.helperProportions.width-b.right+this.margins.left),"top"in b&&(this.offset.click.top=b.top+this.margins.top),"bottom"in b&&(this.offset.click.top=this.helperProportions.height-b.bottom+this.margins.top)},_getParentOffset:function(){this.offsetParent=this.helper.offsetParent();var b=this.offsetParent.offset();this.cssPosition=="absolute"&&this.scrollParent[0]!=(this.document||document)&&a.ui.contains(this.scrollParent[0],this.offsetParent[0])&&(b.left+=this.scrollParent.scrollLeft(),b.top+=this.scrollParent.scrollTop());if(this.offsetParent[0]==(this.document||document).body||this.offsetParent[0].tagName&&this.offsetParent[0].tagName.toLowerCase()=="html"&&a.browser.msie)b={top:0,left:0};return{top:b.top+(parseInt(this.offsetParent.css("borderTopWidth"),10)||0),left:b.left+(parseInt(this.offsetParent.css("borderLeftWidth"),10)||0)}},_getRelativeOffset:function(){if(this.cssPosition=="relative"){var a=this.currentItem.position();return{top:a.top-(parseInt(this.helper.css("top"),10)||0)+this.scrollParent.scrollTop(),left:a.left-(parseInt(this.helper.css("left"),10)||0)+this.scrollParent.scrollLeft()}}return{top:0,left:0}},_cacheMargins:function(){this.margins={left:parseInt(this.currentItem.css("marginLeft"),10)||0,top:parseInt(this.currentItem.css("marginTop"),10)||0}},_cacheHelperProportions:function(){this.helperProportions={width:this.helper.outerWidth(),height:this.helper.outerHeight()}},_setContainment:function(){var b=this.options;b.containment=="parent"&&(b.containment=this.helper[0].parentNode);if(b.containment=="document"||b.containment=="window")this.containment=[0-this.offset.relative.left-this.offset.parent.left,0-this.offset.relative.top-this.offset.parent.top,a(b.containment=="document"?this.document||document:window).width()-this.helperProportions.width-this.margins.left,(a(b.containment=="document"?this.document||document:window).height()||(this.document||document).body.parentNode.scrollHeight)-this.helperProportions.height-this.margins.top];if(!/^(document|window|parent)$/.test(b.containment)){var c=a(b.containment)[0],d=a(b.containment).offset(),e=a(c).css("overflow")!="hidden";this.containment=[d.left+(parseInt(a(c).css("borderLeftWidth"),10)||0)+(parseInt(a(c).css("paddingLeft"),10)||0)-this.margins.left,d.top+(parseInt(a(c).css("borderTopWidth"),10)||0)+(parseInt(a(c).css("paddingTop"),10)||0)-this.margins.top,d.left+(e?Math.max(c.scrollWidth,c.offsetWidth):c.offsetWidth)-(parseInt(a(c).css("borderLeftWidth"),10)||0)-(parseInt(a(c).css("paddingRight"),10)||0)-this.helperProportions.width-this.margins.left,d.top+(e?Math.max(c.scrollHeight,c.offsetHeight):c.offsetHeight)-(parseInt(a(c).css("borderTopWidth"),10)||0)-(parseInt(a(c).css("paddingBottom"),10)||0)-this.helperProportions.height-this.margins.top]}},_convertPositionTo:function(b,c){c||(c=this.position);var d=b=="absolute"?1:-1,e=this.options,f=this.cssPosition=="absolute"&&(this.scrollParent[0]==(this.document||document)||!a.ui.contains(this.scrollParent[0],this.offsetParent[0]))?this.offsetParent:this.scrollParent,g=/(html|body)/i.test(f[0].tagName);return{top:c.top+this.offset.relative.top*d+this.offset.parent.top*d-(a.browser.safari&&this.cssPosition=="fixed"?0:(this.cssPosition=="fixed"?-this.scrollParent.scrollTop():g?0:f.scrollTop())*d),left:c.left+this.offset.relative.left*d+this.offset.parent.left*d-(a.browser.safari&&this.cssPosition=="fixed"?0:(this.cssPosition=="fixed"?-this.scrollParent.scrollLeft():g?0:f.scrollLeft())*d)}},_generatePosition:function(b){var c=this.options,d=this.cssPosition=="absolute"&&(this.scrollParent[0]==(this.document||document)||!a.ui.contains(this.scrollParent[0],this.offsetParent[0]))?this.offsetParent:this.scrollParent,e=/(html|body)/i.test(d[0].tagName);this.cssPosition=="relative"&&(this.scrollParent[0]==(this.document||document)||this.scrollParent[0]==this.offsetParent[0])&&(this.offset.relative=this._getRelativeOffset());var f=b.pageX,g=b.pageY;if(this.originalPosition){this.containment&&(b.pageX-this.offset.click.left<this.containment[0]&&(f=this.containment[0]+this.offset.click.left),b.pageY-this.offset.click.top<this.containment[1]&&(g=this.containment[1]+this.offset.click.top),b.pageX-this.offset.click.left>this.containment[2]&&(f=this.containment[2]+this.offset.click.left),b.pageY-this.offset.click.top>this.containment[3]&&(g=this.containment[3]+this.offset.click.top));if(c.grid){var h=this.originalPageY+Math.round((g-this.originalPageY)/c.grid[1])*c.grid[1];g=this.containment?h-this.offset.click.top<this.containment[1]||h-this.offset.click.top>this.containment[3]?h-this.offset.click.top<this.containment[1]?h+c.grid[1]:h-c.grid[1]:h:h;var i=this.originalPageX+Math.round((f-this.originalPageX)/c.grid[0])*c.grid[0];f=this.containment?i-this.offset.click.left<this.containment[0]||i-this.offset.click.left>this.containment[2]?i-this.offset.click.left<this.containment[0]?i+c.grid[0]:i-c.grid[0]:i:i}}return{top:g-this.offset.click.top-this.offset.relative.top-this.offset.parent.top+(a.browser.safari&&this.cssPosition=="fixed"?0:this.cssPosition=="fixed"?-this.scrollParent.scrollTop():e?0:d.scrollTop()),left:f-this.offset.click.left-this.offset.relative.left-this.offset.parent.left+(a.browser.safari&&this.cssPosition=="fixed"?0:this.cssPosition=="fixed"?-this.scrollParent.scrollLeft():e?0:d.scrollLeft())}},_rearrange:function(a,b,c,d){c?c[0].appendChild(this.placeholder[0]):b.item[0].parentNode.insertBefore(this.placeholder[0],this.direction=="down"?b.item[0]:b.item[0].nextSibling),this.counter=this.counter?++this.counter:1;var e=this,f=this.counter;window.setTimeout(function(){f==e.counter&&e.refreshPositions(!d)},0)},_clear:function(b,c){this.reverting=!1;var d=[],e=this;!this._noFinalSort&&this.currentItem[0].parentNode&&this.placeholder.before(this.currentItem),this._noFinalSort=null;if(this.helper[0]==this.currentItem[0]){for(var f in this._storedCSS)if(this._storedCSS[f]=="auto"||this._storedCSS[f]=="static")this._storedCSS[f]="";this.currentItem.css(this._storedCSS).removeClass("ui-sortable-helper")}else this.currentItem.show();this.fromOutside&&!c&&d.push(function(a){this._trigger("receive",a,this._uiHash(this.fromOutside))}),(this.fromOutside||this.domPosition.prev!=this.currentItem.prev().not(".ui-sortable-helper")[0]||this.domPosition.parent!=this.currentItem.parent()[0])&&!c&&d.push(function(a){this._trigger("update",a,this._uiHash())});if(!a.ui.contains(this.element[0],this.currentItem[0])){c||d.push(function(a){this._trigger("remove",a,this._uiHash())});for(var f=this.containers.length-1;f>=0;f--)a.ui.contains(this.containers[f].element[0],this.currentItem[0])&&!c&&(d.push(function(a){return function(b){a._trigger("receive",b,this._uiHash(this))}}.call(this,this.containers[f])),d.push(function(a){return function(b){a._trigger("update",b,this._uiHash(this))}}.call(this,this.containers[f])))}for(var f=this.containers.length-1;f>=0;f--)c||d.push(function(a){return function(b){a._trigger("deactivate",b,this._uiHash(this))}}.call(this,this.containers[f])),this.containers[f].containerCache.over&&(d.push(function(a){return function(b){a._trigger("out",b,this._uiHash(this))}}.call(this,this.containers[f])),this.containers[f].containerCache.over=0);this._storedCursor&&a("body").css("cursor",this._storedCursor),this._storedOpacity&&this.helper.css("opacity",this._storedOpacity),this._storedZIndex&&this.helper.css("zIndex",this._storedZIndex=="auto"?"":this._storedZIndex),this.dragging=!1;if(this.cancelHelperRemoval){if(!c){this._trigger("beforeStop",b,this._uiHash());for(var f=0;f<d.length;f++)d[f].call(this,b);this._trigger("stop",b,this._uiHash())}return!1}c||this._trigger("beforeStop",b,this._uiHash()),this.placeholder[0].parentNode.removeChild(this.placeholder[0]),this.helper[0]!=this.currentItem[0]&&this.helper.remove(),this.helper=null;if(!c){for(var f=0;f<d.length;f++)d[f].call(this,b);this._trigger("stop",b,this._uiHash())}return this.fromOutside=!1,!0},_trigger:function(){a.Widget.prototype._trigger.apply(this,arguments)===!1&&this.cancel()},_uiHash:function(b){var c=b||this;return{helper:c.helper,placeholder:c.placeholder||a([]),position:c.position,originalPosition:c.originalPosition,offset:c.positionAbs,item:c.currentItem,sender:b?b.element:null}}}),a.extend(a.ui.sortable,{version:"1.8.13"})}(jQuery),function(a){a.fn.serializeObject=function(){var a={},b=this.serializeArray();return jQuery.each(b,function(){a[this.name]!==undefined?(a[this.name].push||(a[this.name]=[a[this.name]]),a[this.name].push(this.value||"")):a[this.name]=this.value||""}),a}}(jQuery),jQuery.extend(jQuery.easing,{easeInSine:function(a,b,c,d,e){return-d*Math.cos(b/e*(Math.PI/2))+d+c},easeOutSine:function(a,b,c,d,e){return d*Math.sin(b/e*(Math.PI/2))+c},easeInOutSine:function(a,b,c,d,e){return-d/2*(Math.cos(Math.PI*b/e)-1)+c}}),function(a){a.toJSON=function(b){if(typeof JSON=="object"&&JSON.stringify)return JSON.stringify(b);var c=typeof b;if(b===null)return"null";if(c=="undefined")return undefined;if(c=="number"||c=="boolean")return b+"";if(c=="string")return a.quoteString(b);if(c=="object"){if(typeof b.toJSON=="function")return a.toJSON(b.toJSON());if(b.constructor===Date){var d=b.getUTCFullYear(),e=b.getUTCMonth()+1;e<10&&(e="0"+e);var f=b.getUTCDate();f<10&&(f="0"+f);var g=b.getUTCHours();g<10&&(g="0"+g);var h=b.getUTCMinutes();h<10&&(h="0"+h);var i=b.getUTCSeconds();i<10&&(i="0"+i);var j=b.getUTCMilliseconds();return j<100&&(j="0"+j),j<10&&(j="0"+j),'"'+d+"-"+e+"-"+f+"T"+g+":"+h+":"+i+"."+j+'Z"'}if(b.constructor===Array){var k=[];for(var l=0;l<b.length;l++)k.push(a.toJSON(b[l])||"null");return"["+k.join(",")+"]"}var m=[];for(var n in b){var o;c=typeof n;if(c=="number")o='"'+n+'"';else if(c=="string")o=a.quoteString(n);else continue;if(typeof b[n]=="function")continue;var p=a.toJSON(b[n]);m.push(o+":"+p)}return"{"+m.join(", ")+"}"}},a.quoteString=function(a){return a.match(b)?'"'+a.replace(b,function(a){var b=c[a];return typeof b=="string"?b:(b=a.charCodeAt(),"\\u00"+Math.floor(b/16).toString(16)+(b%16).toString(16))})+'"':'"'+a+'"'};var b=/["\\\x00-\x1f\x7f-\x9f]/g,c={"\b":"\\b","\t":"\\t","\n":"\\n","\f":"\\f","\r":"\\r",'"':'\\"',"\\":"\\\\"}}(jQuery);var LiquidMetal=function(){function f(a,b){var c=a.charAt(b);return"A"<=c&&c<="Z"}function g(a,b){var c=a.charAt(b-1);return c==" "||c=="\t"}function h(a,b,c,d){c=Math.max(c||0,0),d=Math.min(d||a.length,a.length);for(var e=c;e<d;e++)a[e]=b;return a}var a=0,b=1,c=.8,d=.9,e=.85;return{score:function(b,d){if(d.length==0)return c;if(d.length>b.length)return a;var e=this.buildScoreArray(b,d),f=0;for(var g=0;g<e.length;g++)f+=e[g];return f/e.length},buildScoreArray:function(i,j){var k=Array(i.length),l=i.toLowerCase(),m=j.toLowerCase().split(""),n=-1,o=!1;for(var p=0;p<m.length;p++){var q=m[p],r=l.indexOf(q,n+1);if(r<0)return h(k,a);r==0&&(o=!0),g(i,r)?(k[r-1]=1,h(k,e,n+1,r-1)):f(i,r)?h(k,e,n+1,r):h(k,a,n+1,r),k[r]=b,n=r}var s=o?d:c;return h(k,s,n+1),k}}}(),Showdown={};Showdown.converter=function(){var a,b,c,d=0;this.makeHtml=function(d){return a=[],b=[],c=[],d=d.replace(/~/g,"~T"),d=d.replace(/\$/g,"~D"),d=d.replace(/\r\n/g,"\n"),d=d.replace(/\r/g,"\n"),d="\n\n"+d+"\n\n",d=F(d),d=d.replace(/^[ \t]+$/mg,""),d=g(d),d=f(d),d=i(d),d=D(d),d=d.replace(/~D/g,"$$"),d=d.replace(/~T/g,"~"),d=d.replace(/https?\:\/\/[^"\s\<\>]*[^.,;'">\:\s\<\>\)\]\!]/g,function(a,b){var c=d.slice(0,b),e=d.slice(b);if(c.match(/<[^>]+$/)&&e.match(/^[^>]*>/))return a;var f=a.replace(/^http:\/\/github.com\//,"https://github.com/");return"<a href='"+f+"'>"+a+"</a>"}),d=d.replace(/[a-z0-9_\-+=.]+@[a-z0-9\-]+(\.[a-z0-9-]+)+/ig,function(a){return"<a href='mailto:"+a+"'>"+a+"</a>"}),d=d.replace(/[a-f0-9]{40}/ig,function(a,b){if(typeof GitHub=="undefined"||typeof GitHub.nameWithOwner=="undefined")return a;var c=d.slice(0,b),e=d.slice(b);return c.match(/@$/)||c.match(/<[^>]+$/)&&e.match(/^[^>]*>/)?a:"<a href='http://github.com/"+GitHub.nameWithOwner+"/commit/"+a+"'>"+a.substring(0,7)+"</a>"}),d=d.replace(/([a-z0-9_\-+=.]+)@([a-f0-9]{40})/ig,function(a,b,c,f){if(typeof GitHub=="undefined"||typeof GitHub.nameWithOwner=="undefined")return a;GitHub.repoName=GitHub.repoName||e();var g=d.slice(0,f),h=d.slice(f);return g.match(/\/$/)||g.match(/<[^>]+$/)&&h.match(/^[^>]*>/)?a:"<a href='http://github.com/"+b+"/"+GitHub.repoName+"/commit/"+c+"'>"+b+"@"+c.substring(0,7)+"</a>"}),d=d.replace(/([a-z0-9_\-+=.]+\/[a-z0-9_\-+=.]+)@([a-f0-9]{40})/ig,function(a,b,c){return"<a href='http://github.com/"+b+"/commit/"+c+"'>"+b+"@"+c.substring(0,7)+"</a>"}),d=d.replace(/#([0-9]+)/ig,function(a,b,c){if(typeof GitHub=="undefined"||typeof GitHub.nameWithOwner=="undefined")return a;var e=d.slice(0,c),f=d.slice(c);return e==""||e.match(/[a-z0-9_\-+=.]$/)||e.match(/<[^>]+$/)&&f.match(/^[^>]*>/)?a:"<a href='http://github.com/"+GitHub.nameWithOwner+"/issues/#issue/"+b+"'>"+a+"</a>"}),d=d.replace(/([a-z0-9_\-+=.]+)#([0-9]+)/ig,function(a,b,c,f){if(typeof GitHub=="undefined"||typeof GitHub.nameWithOwner=="undefined")return a;GitHub.repoName=GitHub.repoName||e();var g=d.slice(0,f),h=d.slice(f);return g.match(/\/$/)||g.match(/<[^>]+$/)&&h.match(/^[^>]*>/)?a:"<a href='http://github.com/"+b+"/"+GitHub.repoName+"/issues/#issue/"+c+"'>"+a+"</a>"}),d=d.replace(/([a-z0-9_\-+=.]+\/[a-z0-9_\-+=.]+)#([0-9]+)/ig,function(a,b,c){return"<a href='http://github.com/"+b+"/issues/#issue/"+c+"'>"+a+"</a>"}),d};var e=function(){return GitHub.nameWithOwner.match(/^.+\/(.+)$/)[1]},f=function(c){var c=c.replace(/^[ ]{0,3}\[(.+)\]:[ \t]*\n?[ \t]*<?(\S+?)>?[ \t]*\n?[ \t]*(?:(\n*)["(](.+?)[")][ \t]*)?(?:\n+|\Z)/gm,function(c,d,e,f,g){return d=d.toLowerCase(),a[d]=z(e),f?f+g:(g&&(b[d]=g.replace(/"/g,"&quot;")),"")});return c},g=function(a){a=a.replace(/\n/g,"\n\n");var b="p|div|h[1-6]|blockquote|pre|table|dl|ol|ul|script|noscript|form|fieldset|iframe|math|ins|del",c="p|div|h[1-6]|blockquote|pre|table|dl|ol|ul|script|noscript|form|fieldset|iframe|math";return a=a.replace(/^(<(p|div|h[1-6]|blockquote|pre|table|dl|ol|ul|script|noscript|form|fieldset|iframe|math|ins|del)\b[^\r]*?\n<\/\2>[ \t]*(?=\n+))/gm,h),a=a.replace(/^(<(p|div|h[1-6]|blockquote|pre|table|dl|ol|ul|script|noscript|form|fieldset|iframe|math)\b[^\r]*?.*<\/\2>[ \t]*(?=\n+)\n)/gm,h),a=a.replace(/(\n[ ]{0,3}(<(hr)\b([^<>])*?\/?>)[ \t]*(?=\n{2,}))/g,h),a=a.replace(/(\n\n[ ]{0,3}<!(--[^\r]*?--\s*)+>[ \t]*(?=\n{2,}))/g,h),a=a.replace(/(?:\n\n)([ ]{0,3}(?:<([?%])[^\r]*?\2>)[ \t]*(?=\n{2,}))/g,h),a=a.replace(/\n\n/g,"\n"),a},h=function(a,b){var d=b;return d=d.replace(/\n\n/g,"\n"),d=d.replace(/^\n/,""),d=d.replace(/\n+$/g,""),d="\n\n~K"+(c.push(d)-1)+"K\n\n",d},i=function(a){a=p(a);var b=t("<hr />");return a=a.replace(/^[ ]{0,2}([ ]?\*[ ]?){3,}[ \t]*$/gm,b),a=a.replace(/^[ ]{0,2}([ ]?\-[ ]?){3,}[ \t]*$/gm,b),a=a.replace(/^[ ]{0,2}([ ]?\_[ ]?){3,}[ \t]*$/gm,b),a=r(a),a=s(a),a=x(a),a=g(a),a=y(a),a},j=function(a){return a=u(a),a=k(a),a=A(a),a=n(a),a=l(a),a=B(a),a=z(a),a=w(a),a=a.replace(/  +\n/g," <br />\n"),a},k=function(a){var b=/(<[a-z\/!$]("[^"]*"|'[^']*'|[^'">])*>|<!(--.*?--\s*)+>)/gi;return a=a.replace(b,function(a){var b=a.replace(/(.)<\/?code>(?=.)/g,"$1`");return b=G(b,"\\`*_"),b}),a},l=function(a){return a=a.replace(/(\[((?:\[[^\]]*\]|[^\[\]])*)\][ ]?(?:\n[ ]*)?\[(.*?)\])()()()()/g,m),a=a.replace(/(\[((?:\[[^\]]*\]|[^\[\]])*)\]\([ \t]*()<?(.*?)>?[ \t]*((['"])(.*?)\6[ \t]*)?\))/g,m),a=a.replace(/(\[([^\[\]]+)\])()()()()()/g,m),a},m=function(c,d,e,f,g,h,i,j){j==undefined&&(j="");var k=d,l=e,m=f.toLowerCase(),n=g,o=j;if(n==""){m==""&&(m=l.toLowerCase().replace(/ ?\n/g," ")),n="#"+m;if(a[m]!=undefined)n=a[m],b[m]!=undefined&&(o=b[m]);else if(k.search(/\(\s*\)$/m)>-1)n="";else return k}n=G(n,"*_");var p='<a href="'+n+'"';return o!=""&&(o=o.replace(/"/g,"&quot;"),o=G(o,"*_"),p+=' title="'+o+'"'),p+=">"+l+"</a>",p},n=function(a){return a=a.replace(/(!\[(.*?)\][ ]?(?:\n[ ]*)?\[(.*?)\])()()()()/g,o),a=a.replace(/(!\[(.*?)\]\s?\([ \t]*()<?(\S+?)>?[ \t]*((['"])(.*?)\6[ \t]*)?\))/g,o),a},o=function(c,d,e,f,g,h,i,j){var k=d,l=e,m=f.toLowerCase(),n=g,o=j;o||(o="");if(n==""){m==""&&(m=l.toLowerCase().replace(/ ?\n/g," ")),n="#"+m;if(a[m]!=undefined)n=a[m],b[m]!=undefined&&(o=b[m]);else return k}l=l.replace(/"/g,"&quot;"),n=G(n,"*_");var p='<img src="'+n+'" alt="'+l+'"';return o=o.replace(/"/g,"&quot;"),o=G(o,"*_"),p+=' title="'+o+'"',p+=" />",p},p=function(a){return a=a.replace(/^(.+)[ \t]*\n=+[ \t]*\n+/gm,function(a,b){return t("<h1>"+j(b)+"</h1>")}),a=a.replace(/^(.+)[ \t]*\n-+[ \t]*\n+/gm,function(a,b){return t("<h2>"+j(b)+"</h2>")}),a=a.replace(/^(\#{1,6})[ \t]*(.+?)[ \t]*\#*\n+/gm,function(a,b,c){var d=b.length;return t("<h"+d+">"+j(c)+"</h"+d+">")}),a},q,r=function(a){a+="~0";var b=/^(([ ]{0,3}([*+-]|\d+[.])[ \t]+)[^\r]+?(~0|\n{2,}(?=\S)(?![ \t]*(?:[*+-]|\d+[.])[ \t]+)))/gm;return d?a=a.replace(b,function(a,b,c){var d=b,e=c.search(/[*+-]/g)>-1?"ul":"ol";d=d.replace(/\n{2,}/g,"\n\n\n");var f=q(d);return f=f.replace(/\s+$/,""),f="<"+e+">"+f+"</"+e+">\n",f}):(b=/(\n\n|^\n?)(([ ]{0,3}([*+-]|\d+[.])[ \t]+)[^\r]+?(~0|\n{2,}(?=\S)(?![ \t]*(?:[*+-]|\d+[.])[ \t]+)))/g,a=a.replace(b,function(a,b,c,d){var e=b,f=c,g=d.search(/[*+-]/g)>-1?"ul":"ol",f=f.replace(/\n{2,}/g,"\n\n\n"),h=q(f);return h=e+"<"+g+">\n"+h+"</"+g+">\n",h})),a=a.replace(/~0/,""),a};q=function(a){return d++,a=a.replace(/\n{2,}$/,"\n"),a+="~0",a=a.replace(/(\n)?(^[ \t]*)([*+-]|\d+[.])[ \t]+([^\r]+?(\n{1,2}))(?=\n*(~0|\2([*+-]|\d+[.])[ \t]+))/gm,function(a,b,c,d,e){var f=e,g=b,h=c;return g||f.search(/\n{2,}/)>-1?f=i(E(f)):(f=r(E(f)),f=f.replace(/\n$/,""),f=j(f)),"<li>"+f+"</li>\n"}),a=a.replace(/~0/g,""),d--,a};var s=function(a){return a+="~0",a=a.replace(/(?:\n\n|^)((?:(?:[ ]{4}|\t).*\n+)+)(\n*[ ]{0,3}[^ \t\n]|(?=~0))/g,function(a,b,c){var d=b,e=c;return d=v(E(d)),d=F(d),d=d.replace(/^\n+/g,""),d=d.replace(/\n+$/g,""),d="<pre><code>"+d+"\n</code></pre>",t(d)+e}),a=a.replace(/~0/,""),a},t=function(a){return a=a.replace(/(^\n+|\n+$)/g,""),"\n\n~K"+(c.push(a)-1)+"K\n\n"},u=function(a){return a=a.replace(/(^|[^\\])(`+)([^\r]*?[^`])\2(?!`)/gm,function(a,b,c,d,e){var f=d;return f=f.replace(/^([ \t]*)/g,""),f=f.replace(/[ \t]*$/g,""),f=v(f),b+"<code>"+f+"</code>"}),a},v=function(a){return a=a.replace(/&/g,"&amp;"),a=a.replace(/</g,"&lt;"),a=a.replace(/>/g,"&gt;"),a=G(a,"*_{}[]\\",!1),a},w=function(a){return a=a.replace(/(\*\*|__)(?=\S)([^\r]*?\S[*_]*)\1/g,"<strong>$2</strong>"),a=a.replace(/(\w)_(\w)/g,"$1~E95E$2"),a=a.replace(/(\*|_)(?=\S)([^\r]*?\S)\1/g,"<em>$2</em>"),a},x=function(a){return a=a.replace(/((^[ \t]*>[ \t]?.+\n(.+\n)*\n*)+)/gm,function(a,b){var c=b;return c=c.replace(/^[ \t]*>[ \t]?/gm,"~0"),c=c.replace(/~0/g,""),c=c.replace(/^[ \t]+$/gm,""),c=i(c),c=c.replace(/(^|\n)/g,"$1  "),c=c.replace(/(\s*<pre>[^\r]+?<\/pre>)/gm,function(a,b){var c=b;return c=c.replace(/^  /mg,"~0"),c=c.replace(/~0/g,""),c}),t("<blockquote>\n"+c+"\n</blockquote>")}),a},y=function(a){a=a.replace(/^\n+/g,""),a=a.replace(/\n+$/g,"");var b=a.split(/\n{2,}/g),d=[],e=b.length;for(var f=0;f<e;f++){var g=b[f];g.search(/~K(\d+)K/g)>=0?d.push(g):g.search(/\S/)>=0&&(g=j(g),g=g.replace(/\n/g,"<br />"),g=g.replace(/^([ \t]*)/g,"<p>"),g+="</p>",d.push(g))}e=d.length;for(var f=0;f<e;f++)while(d[f].search(/~K(\d+)K/)>=0){var h=c[RegExp.$1];h=h.replace(/\$/g,"$$$$"),d[f]=d[f].replace(/~K\d+K/,h)}return d.join("\n\n")},z=function(a){return a=a.replace(/&(?!#?[xX]?(?:[0-9a-fA-F]+|\w+);)/g,"&amp;"),a=a.replace(/<(?![a-z\/?\$!])/gi,"&lt;"),a},A=function(a){return a=a.replace(/\\(\\)/g,H),a=a.replace(/\\([`*_{}\[\]()>#+-.!])/g,H),a},B=function(a){return a=a.replace(/<((https?|ftp|dict):[^'">\s]+)>/gi,'<a href="$1">$1</a>'),a=a.replace(/<(?:mailto:)?([-.\w]+\@[-a-z0-9]+(\.[-a-z0-9]+)*\.[a-z]+)>/gi,function(a,b){return C(D(b))}),a},C=function(a){function b(a){var b="0123456789ABCDEF",c=a.charCodeAt(0);return b.charAt(c>>4)+b.charAt(c&15)}var c=[function(a){return"&#"+a.charCodeAt(0)+";"},function(a){return"&#x"+b(a)+";"},function(a){return a}];return a="mailto:"+a,a=a.replace(/./g,function(a){if(a=="@")a=c[Math.floor(Math.random()*2)](a);else if(a!=":"){var b=Math.random();a=b>.9?c[2](a):b>.45?c[1](a):c[0](a)}return a}),a='<a href="'+a+'">'+a+"</a>",a=a.replace(/">.+:/g,'">'),a},D=function(a){return a=a.replace(/~E(\d+)E/g,function(a,b){var c=parseInt(b);return String.fromCharCode(c)}),a},E=function(a){return a=a.replace(/^(\t|[ ]{1,4})/gm,"~0"),a=a.replace(/~0/g,""),a},F=function(a){return a=a.replace(/\t(?=\t)/g,"    "),a=a.replace(/\t/g,"~A~B"),a=a.replace(/~B(.+?)~A/g,function(a,b,c){var d=b,e=4-d.length%4;for(var f=0;f<e;f++)d+=" ";return d}),a=a.replace(/~A/g,"    "),a=a.replace(/~B/g,""),a},G=function(a,b,c){var d="(["+b.replace(/([\[\]\\])/g,"\\$1")+"])";c&&(d="\\\\"+d);var e=new RegExp(d,"g");return a=a.replace(e,H),a},H=function(a,b){var c=b.charCodeAt(0);return"~E"+c+"E"}},function(){this.Mercury||(this.Mercury={}),jQuery.extend(this.Mercury,{version:"0.2.0",supported:document.getElementById&&document.designMode&&!jQuery.browser.konqueror&&!jQuery.browser.msie,Regions:{},modalHandlers:{},lightviewHandlers:{},dialogHandlers:{},preloadedViews:{},bind:function(a,b){return jQuery(document).bind("mercury:"+a,b)},trigger:function(a,b){return Mercury.log(a,b),jQuery(document).trigger("mercury:"+a,b)},log:function(){if(Mercury.debug&&console){if(arguments[0]==="hide:toolbar"||arguments[0]==="show:toolbar")return;try{return console.debug(arguments)}catch(a){}}}})}.call(this),function(){String.prototype.titleize=function(){return this[0].toUpperCase()+this.slice(1)},String.prototype.toHex=function(){return this[0]==="#"?this:this.replace(/rgba?\((\d+)[\s|\,]?\s(\d+)[\s|\,]?\s(\d+)\)/gi,function(a,b,c,d){return"#"+parseInt(b).toHex()+parseInt(c).toHex()+parseInt(d).toHex()})},String.prototype.singleDiff=function(a){var b,c,d,e,f;c="";for(d=0,f=a.length;d<f;d++){b=a[d];if(b==="each")break;if(b!==this[d]){e=new RegExp(this.substr(d).regExpEscape().replace(/^\s+|^(&nbsp;)+/g,"")+"$","m"),c=a.substr(d).replace(e,"");break}}return c},String.prototype.regExpEscape=function(){var a,b;return b=["/",".","*","+","?","|","(",")","[","]","{","}","\\"],a=new RegExp("(\\"+b.join("|\\")+")","g"),this.replace(a,"\\$1")},String.prototype.sanitizeHTML=function(){var a,b;return b=jQuery("<div>").html(this.toString()),b.find("style").remove(),a=b.text(),a=a.replace(/\n+/g,"<br/>").replace(/.*<!--.*-->/g,"").replace(/^(<br\/>)+|(<br\/>\s*)+$/g,""),a},Number.prototype.toHex=function(){var a;return a=this.toString(16).toUpperCase(),a[1]?a:"0"+a},Number.prototype.toBytes=function(){var a,b;a=parseInt(this),b=0;while(1023<a)a/=1024,b+=1;return b?""+a.toFixed(2)+[""," kb"," Mb"," Gb"," Tb"," Pb"," Eb"][b]:""+a+" bytes"}}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.PageEditor=function(){function b(a,b){var c;this.saveUrl=a!=null?a:null,this.options=b!=null?b:{};if(!Mercury.supported)throw"Mercury.PageEditor is unsupported in this client. Supported browsers are chrome 10+, firefix 4+, and safari 5+.";if(window.mercuryInstance)throw"Mercury.PageEditor can only be instantiated once.";this.options.visible!==!1&&(this.options.visible=!0),this.visible=this.options.visible,window.mercuryInstance=this,this.regions=[],this.initializeInterface();if(c=jQuery('meta[name="csrf-token"]').attr("content"))Mercury.csrfToken=c}return b.prototype.initializeInterface=function(){var b,c;return this.focusableElement=jQuery("<input>",{type:"text",style:"position:absolute;opacity:0"}).appendTo((b=this.options.appendTo)!=null?b:"body"),this.iframe=jQuery("<iframe>",{"class":"mercury-iframe",seamless:"true",frameborder:"0",src:"about:blank",style:"position:absolute;top:0;width:100%;visibility:hidden"}),this.iframe.appendTo((c=jQuery(this.options.appendTo).get(0))!=null?c:"body"),this.iframe.load(a(function(){return this.initializeFrame()},this)),this.iframe.get(0).contentWindow.document.location.href=this.iframeSrc(),this.toolbar=new Mercury.Toolbar(this.options),this.statusbar=new Mercury.Statusbar(this.options)},b.prototype.initializeFrame=function(){var a;try{if(this.iframe.data("loaded"))return;return this.iframe.data("loaded",!0),this.document=jQuery(this.iframe.get(0).contentWindow.document),jQuery('<style mercury-styles="true">').html(Mercury.config.injectedStyles).appendTo(this.document.find("head")),a=this.iframe.get(0).contentWindow,jQuery.globalEval=function(b){if(b&&/\S/.test(b))return(a.execScript||function(b){return a.eval.call(a,b)})(b)},a.Mercury=Mercury,this.bindEvents(),this.initializeRegions(),this.finalizeInterface(),Mercury.trigger("ready"),this.iframe.css({visibility:"visible"})}catch(b){return alert("Mercury.PageEditor failed to load: "+b+"\n\nPlease try refreshing.")}},b.prototype.initializeRegions=function(){var a,b,c,d,e,f,g,h;f=jQuery(".mercury-region",this.document);for(b=0,d=f.length;b<d;b++)a=f[b],this.buildRegion(jQuery(a));if(!this.options.visible)return;g=this.regions,h=[];for(c=0,e=g.length;c<e;c++){a=g[c];if(a.focus){a.focus();break}}return h},b.prototype.buildRegion=function(a){var b;try{return b=a.data("type").titleize(),this.regions.push(new Mercury.Regions[b](a,this.iframe.get(0).contentWindow))}catch(c){return Mercury.debug&&alert(c),alert('Region type is malformed, no data-type provided, or "'+b+'" is unknown.')}},b.prototype.finalizeInterface=function(){this.snippetToolbar=new Mercury.SnippetToolbar(this.document),this.hijackLinksAndForms(),this.resize();if(!this.options.visible)return Mercury.trigger("mode",{mode:"preview"})},b.prototype.bindEvents=function(){return Mercury.bind("initialize:frame",a(function(){return setTimeout(this.initializeFrame,1e3)},this)),Mercury.bind("focus:frame",a(function(){return this.iframe.focus()},this)),Mercury.bind("focus:window",a(function(){return setTimeout(a(function(){return this.focusableElement.focus()},this),10)},this)),Mercury.bind("toggle:interface",a(function(){return this.toggleInterface()},this)),Mercury.bind("action",a(function(a,b){if(b.action==="save")return this.save()},this)),this.document.mousedown(function(a){Mercury.trigger("hide:dialogs");if(Mercury.region&&jQuery(a.target).closest(".mercury-region").get(0)!==Mercury.region.element.get(0))return Mercury.trigger("unfocus:regions")}),jQuery(window).resize(a(function(){return this.resize()},this)),window.onbeforeunload=this.beforeUnload},b.prototype.toggleInterface=function(){return this.visible?(this.visible=!1,this.toolbar.hide(),this.statusbar.hide()):(this.visible=!0,this.toolbar.show(),this.statusbar.show()),Mercury.trigger("mode",{mode:"preview"}),this.resize()},b.prototype.resize=function(){var a,b,c;return c=jQuery(window).width(),a=this.statusbar.top(),b=this.toolbar.height(),Mercury.displayRect={top:b,left:0,width:c,height:a-b,fullHeight:a},this.iframe.css({top:b,left:0,height:a-b}),Mercury.trigger("resize")},b.prototype.iframeSrc=function(a){return a==null&&(a=null),(a!=null?a:window.location.href).replace(/([http|https]:\/\/.[^\/]*)\/editor\/?(.*)/i,"$1/$2")},b.prototype.hijackLinksAndForms=function(){var a,b,c,d,e,f,g,h,i,j;h=jQuery("a, form",this.document),j=[];for(d=0,f=h.length;d<f;d++){b=h[d],c=!1,i=Mercury.config.nonHijackableClasses||[];for(e=0,g=i.length;e<g;e++){a=i[e];if(jQuery(b).hasClass(a)){c=!0;continue}}j.push(!c&&(b.target===""||b.target==="_self")&&!jQuery(b).closest(".mercury-region").length?jQuery(b).attr("target","_top"):void 0)}return j},b.prototype.beforeUnload=function(){return Mercury.changes&&!Mercury.silent?"You have unsaved changes.  Are you sure you want to leave without saving them first?":null},b.prototype.save=function(){var b,c,d,e;return c=(d=(e=this.saveUrl)!=null?e:Mercury.saveURL)!=null?d:this.iframeSrc(),b=this.serialize(),Mercury.log("saving",b),this.options.saveStyle!=="form"&&(b=jQuery.toJSON(b)),jQuery.ajax(c,{type:"POST",data:{content:b},success:a(function(){return Mercury.changes=!1},this),error:a(function(){return alert("Mercury was unable to save to the url: "+c)},this)})},b.prototype.serialize=function(){var a,b,c,d,e;b={},e=this.regions;for(c=0,d=e.length;c<d;c++)a=e[c],b[a.name]=a.serialize();return b},b}()}.call(this),function(){this.Mercury.HistoryBuffer=function(){function a(a){this.maxLength=a!=null?a:200,this.index=0,this.stack=[],this.markerRegExp=/<em class="mercury-marker"><\/em>/g}return a.prototype.push=function(a){if(jQuery.type(a)==="string"){if(this.stack[this.index]&&this.stack[this.index].replace(this.markerRegExp,"")===a.replace(this.markerRegExp,""))return}else if(jQuery.type(a)==="object"&&a.html&&this.stack[this.index]&&this.stack[this.index].html===a.html)return;return this.stack=this.stack.slice(0,this.index+1),this.stack.push(a),this.stack.length>this.maxLength&&this.stack.shift(),this.index=this.stack.length-1},a.prototype.undo=function(){return this.index<1?null:(this.index-=1,this.stack[this.index])},a.prototype.redo=function(){return this.index>=this.stack.length-1?null:(this.index+=1,this.stack[this.index])},a}()}.call(this),function(){this.Mercury.tableEditor=function(a,b,c){return Mercury.tableEditor.load(a,b,c),Mercury.tableEditor},jQuery.extend(Mercury.tableEditor,{load:function(a,b,c){return this.table=a,this.cell=b,this.cellContent=c!=null?c:"",this.row=this.cell.parent("tr"),this.columnCount=this.getColumnCount(),this.rowCount=this.getRowCount()},addColumn:function(a){var b,c,d,e,f,g,h,i,j,k,l;a==null&&(a="after"),i=this.cellSignatureFor(this.cell),k=this.table.find("tr"),l=[];for(b=0,j=k.length;b<j;b++)g=k[b],h=1,d=a==="after"?{right:i.right}:{left:i.left},l.push((e=this.findCellByOptionsFor(g,d))?(f=jQuery("<"+e.cell.get(0).tagName+">").html(this.cellContent),this.setRowspanFor(f,e.height),a==="before"?e.cell.before(f):e.cell.after(f),b+=e.height-1):(c=this.findCellByIntersectionFor(g,i))?this.setColspanFor(c.cell,c.width+1):void 0);return l},removeColumn:function(){var a,b,c,d,e,f,g,h,i,j,k,l,m,n,o;h=this.cellSignatureFor(this.cell);if(h.width>1)return;f=[],a=[],n=this.table.find("tr");for(c=0,k=n.length;c<k;c++)g=n[c],(e=this.findCellByOptionsFor(g,{left:h.left,width:h.width}))?(f.push(e.cell),c+=e.height-1):(d=this.findCellByIntersectionFor(g,h))&&a.push(d.cell);for(i=0,l=f.length;i<l;i++)b=f[i],jQuery(b).remove();o=[];for(j=0,m=a.length;j<m;j++)b=a[j],o.push(this.setColspanFor(b,this.colspanFor(b)-1
));return o},addRow:function(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r;a==null&&(a="after"),f=jQuery("<tr>"),(i=this.rowspanFor(this.cell))>1&&a==="after"&&(this.row=jQuery(this.row.nextAll("tr")[i-2])),c=0,p=this.row.find("th, td");for(j=0,m=p.length;j<m;j++){b=p[j],d=this.colspanFor(b),e=jQuery("<"+b.tagName+">").html(this.cellContent),this.setColspanFor(e,d),c+=d;if((i=this.rowspanFor(b))>1&&a==="after"){this.setRowspanFor(b,i+1);continue}f.append(e)}if(c<this.columnCount){h=0,q=this.row.prevAll("tr");for(k=0,n=q.length;k<n;k++){g=q[k],h+=1,r=jQuery(g).find("td[rowspan], th[rowspan]");for(l=0,o=r.length;l<o;l++)b=r[l],i=this.rowspanFor(b),i-1>=h&&a==="before"?this.setRowspanFor(b,i+1):i-1>=h&&a==="after"&&(i-1===h?(e=jQuery("<"+b.tagName+">").html(this.cellContent),this.setColspanFor(e,this.colspanFor(b)),f.append(e)):this.setRowspanFor(b,i+1))}}return a==="before"?this.row.before(f):this.row.after(f)},removeRow:function(){var a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w;i=!0,f=0,e=0,s=this.row.find("td, th");for(k=0,o=s.length;k<o;k++){b=s[k],h=this.rowspanFor(b),f&&h!==f&&(i=!1);if(h<e||!e)e=h;f=h}if(!i&&this.rowspanFor(this.cell)>e)return;if(e>1)for(c=0,t=e-2;0<=t?c<=t:c>=t;0<=t?c++:c--)jQuery(this.row.nextAll("tr")[c]).remove();u=this.row.find("td[rowspan], th[rowspan]");for(l=0,p=u.length;l<p;l++){b=u[l],j=this.cellSignatureFor(b);if(j.height===e)continue;if(d=this.findCellByOptionsFor(this.row.nextAll("tr")[e-1],{left:j.left,forceAdjacent:!0}))this.setRowspanFor(b,this.rowspanFor(b)-this.rowspanFor(this.cell)),d.direction==="before"?d.cell.before(jQuery(b).clone()):d.cell.after(jQuery(b).clone())}if(this.columnsFor(this.row.find("td, th"))<this.columnCount){g=0,v=this.row.prevAll("tr");for(m=0,q=v.length;m<q;m++){a=v[m],g+=1,w=jQuery(a).find("td[rowspan], th[rowspan]");for(n=0,r=w.length;n<r;n++)b=w[n],h=this.rowspanFor(b),h>g&&this.setRowspanFor(b,h-this.rowspanFor(this.cell))}}return this.row.remove()},increaseColspan:function(){var a;a=this.cell.next("td, th");if(!a.length)return;if(this.rowspanFor(a)!==this.rowspanFor(this.cell))return;if(this.cellIndexFor(a)>this.cellIndexFor(this.cell)+this.colspanFor(this.cell))return;return this.setColspanFor(this.cell,this.colspanFor(this.cell)+this.colspanFor(a)),a.remove()},decreaseColspan:function(){var a;if(this.colspanFor(this.cell)===1)return;return this.setColspanFor(this.cell,this.colspanFor(this.cell)-1),a=jQuery("<"+this.cell.get(0).tagName+">").html(this.cellContent),this.setRowspanFor(a,this.rowspanFor(this.cell)),this.cell.after(a)},increaseRowspan:function(){var a,b,c;c=this.cellSignatureFor(this.cell),b=this.row.nextAll("tr")[c.height-1];if(b&&(a=this.findCellByOptionsFor(b,{left:c.left,width:c.width})))return this.setRowspanFor(this.cell,c.height+a.height),a.cell.remove()},decreaseRowspan:function(){var a,b,c,d;d=this.cellSignatureFor(this.cell);if(d.height===1)return;c=this.row.nextAll("tr")[d.height-2];if(a=this.findCellByOptionsFor(c,{left:d.left,forceAdjacent:!0}))return b=jQuery("<"+this.cell.get(0).tagName+">").html(this.cellContent),this.setColspanFor(b,this.colspanFor(this.cell)),this.setRowspanFor(this.cell,d.height-1),a.direction==="before"?a.cell.before(b):a.cell.after(b)},getColumnCount:function(){return this.columnsFor(this.table.find("thead tr:first-child, tbody tr:first-child, tfoot tr:first-child").first().find("td, th"))},getRowCount:function(){return this.table.find("tr").length},cellIndexFor:function(a){var b,c,d,e,f,g,h,i,j,k,l,m;a=jQuery(a),f=a.parent("tr"),d=this.columnsFor(f.find("td, th")),e=this.columnsFor(a.prevAll("td, th"));if(d<this.columnCount){g=0,l=f.prevAll("tr");for(h=0,j=l.length;h<j;h++){c=l[h],g+=1,m=jQuery(c).find("td[rowspan], th[rowspan]");for(i=0,k=m.length;i<k;i++)b=m[i],this.rowspanFor(b)>g&&this.cellIndexFor(b)<=e&&(e+=this.colspanFor(b))}}return e},cellSignatureFor:function(a){var b;return b={cell:jQuery(a)},b.left=this.cellIndexFor(a),b.width=this.colspanFor(a),b.height=this.rowspanFor(a),b.right=b.left+b.width,b},findCellByOptionsFor:function(a,b){var c,d,e,f,g,h;h=jQuery(a).find("td, th");for(f=0,g=h.length;f<g;f++){c=h[f],e=this.cellSignatureFor(c);if(typeof b.right!="undefined"&&e.right===b.right)return e;if(typeof b.left!="undefined")if(b.width){if(e.left===b.left&&e.width===b.width)return e}else if(!b.forceAdjacent){if(e.left===b.left)return e}else if(b.forceAdjacent&&e.left>b.left)return d=jQuery(c).prev("td, th"),d.length?(e=this.cellSignatureFor(d),e.direction="after"):e.direction="before",e}return b.forceAdjacent?(e.direction="after",e):null},findCellByIntersectionFor:function(a,b){var c,d,e,f,g;g=jQuery(a).find("td, th");for(e=0,f=g.length;e<f;e++){c=g[e],d=this.cellSignatureFor(c);if(d.right-b.left>=0&&d.right>b.left)return d}return null},columnsFor:function(a){var b,c,d,e;c=0;for(d=0,e=a.length;d<e;d++)b=a[d],c+=this.colspanFor(b);return c},colspanFor:function(a){return parseInt(jQuery(a).attr("colspan"))||1},rowspanFor:function(a){return parseInt(jQuery(a).attr("rowspan"))||1},setColspanFor:function(a,b){return jQuery(a).attr("colspan",b>1?b:null)},setRowspanFor:function(a,b){return jQuery(a).attr("rowspan",b>1?b:null)}})}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.Dialog=function(){function b(a,b,c){this.url=a,this.name=b,this.options=c!=null?c:{},this.button=this.options["for"],this.build(),this.bindEvents(),this.preload()}return b.prototype.build=function(){var a;return this.element=jQuery("<div>",{"class":"mercury-dialog mercury-"+this.name+"-dialog loading",style:"display:none"}),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body")},b.prototype.bindEvents=function(){return this.element.mousedown(function(a){return a.stopPropagation()})},b.prototype.preload=function(){if(this.options.preload)return this.load()},b.prototype.toggle=function(){return this.visible?this.hide():this.show()},b.prototype.resize=function(){return this.show()},b.prototype.show=function(){return Mercury.trigger("hide:dialogs",this),this.visible=!0,this.loaded?(this.element.css({width:"auto",height:"auto"}),this.position(this.visible)):this.position(),this.appear()},b.prototype.position=function(a){},b.prototype.appear=function(){return this.element.css({display:"block",opacity:0}),this.element.animate({opacity:.95},200,"easeInOutSine",a(function(){if(!this.loaded)return this.load(a(function(){return this.resize()},this))},this))},b.prototype.hide=function(){return this.element.hide(),this.visible=!1},b.prototype.load=function(b){if(!this.url)return;if(!Mercury.preloadedViews[this.url])return jQuery.ajax(this.url,{success:a(function(a){this.loadContent(a),Mercury.dialogHandlers[this.name]&&Mercury.dialogHandlers[this.name].call(this);if(b)return b()},this),error:a(function(){return this.hide(),this.button&&this.button.removeClass("pressed"),alert("Mercury was unable to load "+this.url+" for the "+this.name+" dialog.")},this)});this.loadContent(Mercury.preloadedViews[this.url]),Mercury.dialogHandlers[this.name]&&Mercury.dialogHandlers[this.name].call(this);if(b)return b()},b.prototype.loadContent=function(a){return this.loaded=!0,this.element.removeClass("loading"),this.element.html(a)},b}()}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b},c=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.Palette=function(){function a(b,c,d){this.url=b,this.name=c,this.options=d!=null?d:{},a.__super__.constructor.apply(this,arguments)}return b(a,Mercury.Dialog),a.prototype.build=function(){var a;return this.element=jQuery("<div>",{"class":"mercury-palette mercury-"+this.name+"-palette loading",style:"display:none"}),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body")},a.prototype.bindEvents=function(){return Mercury.bind("hide:dialogs",c(function(a,b){if(b!==this)return this.hide()},this)),a.__super__.bindEvents.apply(this,arguments)},a.prototype.position=function(a){var b,c;return this.element.css({top:0,left:0,display:"block",visibility:"hidden"}),b=this.button.offset(),c=this.element.width(),b.left+c>jQuery(window).width()&&(b.left=b.left-c+this.button.width()),this.element.css({top:b.top+this.button.height(),left:b.left,display:a?"block":"none",visibility:"visible"})},a}()}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b},c=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.Select=function(){function a(b,c,d){this.url=b,this.name=c,this.options=d!=null?d:{},a.__super__.constructor.apply(this,arguments)}return b(a,Mercury.Dialog),a.prototype.build=function(){var a;return this.element=jQuery("<div>",{"class":"mercury-select mercury-"+this.name+"-select loading",style:"display:none"}),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body")},a.prototype.bindEvents=function(){return Mercury.bind("hide:dialogs",c(function(a,b){if(b!==this)return this.hide()},this)),this.element.mousedown(c(function(a){return a.preventDefault()},this)),a.__super__.bindEvents.apply(this,arguments)},a.prototype.position=function(a){var b,c,d,e,f,g,h;return this.element.css({top:0,left:0,display:"block",visibility:"hidden"}),g=this.button.offset(),d=this.element.width(),c=this.element.height(),b=jQuery(document).height(),h=g.top+this.button.height()/2-c/2,h<g.top-100&&(h=g.top-100),h<20&&(h=20),e=this.loaded?"auto":c,h+c>=b-20&&(e=b-h-20),f=g.left,f+d>jQuery(window).width()&&(f=f-d+this.button.width()),this.element.css({top:h,left:f,height:e,display:a?"block":"none",visibility:"visible"})},a}()}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b},c=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.Panel=function(){function a(b,c,d){this.url=b,this.name=c,this.options=d!=null?d:{},a.__super__.constructor.apply(this,arguments)}return b(a,Mercury.Dialog),a.prototype.build=function(){var a;return this.element=jQuery("<div>",{"class":"mercury-panel loading",style:"display:none;"}),this.titleElement=jQuery("<h1>"+this.options.title+"</h1>").appendTo(this.element),this.paneElement=jQuery("<div>",{"class":"mercury-panel-pane"}).appendTo(this.element),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body")},a.prototype.bindEvents=function(){return Mercury.bind("resize",c(function(){return this.position(this.visible)},this)),Mercury.bind("hide:panels",c(function(a,b){if(b!==this)return this.button.removeClass("pressed"),this.hide()},this)),this.element.mousedown(function(a){return a.stopPropagation()}),a.__super__.bindEvents.apply(this,arguments)},a.prototype.show=function(){return Mercury.trigger("hide:panels",this),a.__super__.show.apply(this,arguments)},a.prototype.resize=function(){var a,b,d;this.paneElement.css({display:"none"}),d=this.element.width(),this.paneElement.css({visibility:"hidden",width:"auto",display:"block"}),b=this.element.width(),this.paneElement.css({visibility:"visible",display:"none"}),a=this.element.offset(),this.element.animate({left:a.left-(b-d),width:b},200,"easeInOutSine",c(function(){return this.paneElement.css({display:"block",width:b}),this.makeDraggable()},this));if(!this.visible)return this.hide()},a.prototype.position=function(a){var b,c,d,e,f;this.element.css({display:"block",visibility:"hidden"}),e=this.element.offset(),b=this.element.width(),c=Mercury.displayRect.height-16,f=c-this.titleElement.outerHeight(),this.paneElement.css({height:f,overflowY:f<30?"hidden":"auto"}),this.moved||(d=Mercury.displayRect.width-b-20),d<=8&&(d=8);if(this.pinned||b+e.left>Mercury.displayRect.width-20)d=Mercury.displayRect.width-b-20;this.element.css({top:Mercury.displayRect.top+8,left:d,height:c,display:a?"block":"none",visibility:"visible"}),this.makeDraggable();if(!a)return this.element.hide()},a.prototype.loadContent=function(a){return this.loaded=!0,this.element.removeClass("loading"),this.paneElement.css({visibility:"hidden"}),this.paneElement.html(a)},a.prototype.makeDraggable=function(){var a;return a=this.element.width(),this.element.draggable({handle:"h1",axis:"x",opacity:.7,scroll:!1,addClasses:!1,iframeFix:!0,containment:[8,0,Mercury.displayRect.width-a-20,0],stop:c(function(){var b;return b=this.element.offset().left,this.moved=!0,this.pinned=b>Mercury.displayRect.width-a-30?!0:!1,!0},this)})},a}()}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.modal=function(a,b){return b==null&&(b={}),Mercury.modal.show(a,b),Mercury.modal},jQuery.extend(Mercury.modal,{minWidth:400,show:function(a,b){return this.url=a,this.options=b!=null?b:{},Mercury.trigger("focus:window"),this.initialize(),this.visible?this.update():this.appear()},initialize:function(){if(this.initialized)return;return this.build(),this.bindEvents(),this.initialized=!0},build:function(){var a,b;return this.element=jQuery("<div>",{"class":"mercury-modal loading"}),this.element.html('<h1 class="mercury-modal-title"><span></span><a>&times;</a></h1>'),this.element.append('<div class="mercury-modal-content-container"><div class="mercury-modal-content"></div></div>'),this.overlay=jQuery("<div>",{"class":"mercury-modal-overlay"}),this.titleElement=this.element.find(".mercury-modal-title"),this.contentContainerElement=this.element.find(".mercury-modal-content-container"),this.contentElement=this.element.find(".mercury-modal-content"),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body"),this.overlay.appendTo((b=jQuery(this.options.appendTo).get(0))!=null?b:"body"),this.titleElement.find("span").html(this.options.title)},bindEvents:function(){return Mercury.bind("refresh",a(function(){return this.resize(!0)},this)),Mercury.bind("resize",a(function(){return this.position()},this)),this.overlay.click(a(function(){return this.hide()},this)),this.titleElement.find("a").click(a(function(){return this.hide()},this)),jQuery(document).bind("keydown",a(function(a){if(a.keyCode===27&&this.visible)return this.hide()},this))},appear:function(){return this.showing=!0,this.position(),this.overlay.show(),this.overlay.animate({opacity:1},200,"easeInOutSine",a(function(){return this.element.css({top:-this.element.height()}),this.setTitle(),this.element.show(),this.element.animate({top:0},200,"easeInOutSine",a(function(){return this.visible=!0,this.showing=!1,this.load()},this))},this))},resize:function(b){var c,d,e,f;e=b?"visible":"hidden",d=this.titleElement.outerHeight(),f=this.contentElement.outerWidth(),this.contentPane&&this.contentPane.css({height:"auto"}),this.contentElement.css({height:"auto",visibility:e,display:"block"}),c=this.contentElement.outerHeight()+d,f<this.minWidth&&(f=this.minWidth);if(c>Mercury.displayRect.fullHeight-20||this.options.fullHeight)c=Mercury.displayRect.fullHeight-20;return this.element.stop().animate({left:(Mercury.displayRect.width-f)/2,width:f,height:c},200,"easeInOutSine",a(function(){var a;return this.contentElement.css({visibility:"visible",display:"block"}),this.contentPane.length?(this.contentElement.css({height:c-d,overflow:"visible"}),a=this.contentControl.length?this.contentControl.outerHeight():0,this.contentPane.css({height:c-d-a-40}),this.contentPane.find(".mercury-modal-pane").css({width:f-40})):this.contentElement.css({height:c-d,overflow:"auto"})},this))},position:function(){var a,b,c,d,e;d=Mercury.displayRect.width,this.contentPane&&this.contentPane.css({height:"auto"}),this.contentElement.css({height:"auto"}),this.element.css({width:"auto",height:"auto",display:"block",visibility:"hidden"}),e=this.element.width(),b=this.element.height(),e<this.minWidth&&(e=this.minWidth);if(b>Mercury.displayRect.fullHeight-20||this.options.fullHeight)b=Mercury.displayRect.fullHeight-20;return c=this.titleElement.outerHeight(),this.contentPane&&this.contentPane.length?(this.contentElement.css({height:b-c,overflow:"visible"}),a=this.contentControl.length?this.contentControl.outerHeight():0,this.contentPane.css({height:b-c-a-40}),this.contentPane.find(".mercury-modal-pane").css({width:e-40})):this.contentElement.css({height:b-c,overflow:"auto"}),this.element.css({left:(d-e)/2,width:e,height:b,display:this.visible?"block":"none",visibility:"visible"})},update:function(){return this.reset(),this.resize(),this.load()},load:function(){this.setTitle();if(!this.url)return;return this.element.addClass("loading"),Mercury.preloadedViews[this.url]?setTimeout(a(function(){return this.loadContent(Mercury.preloadedViews[this.url])},this),10):jQuery.ajax(this.url,{type:this.options.loadType||"get",data:this.options.loadData,success:a(function(a){return this.loadContent(a)},this),error:a(function(){return this.hide(),alert("Mercury was unable to load "+this.url+" for the modal.")},this)})},loadContent:function(a,b){return b==null&&(b=null),this.initialize(),this.options=b||this.options,this.setTitle(),this.loaded=!0,this.element.removeClass("loading"),this.contentElement.html(a),this.contentElement.css({display:"none",visibility:"hidden"}),this.contentPane=this.element.find(".mercury-modal-pane-container"),this.contentControl=this.element.find(".mercury-modal-controls"),this.options.afterLoad&&this.options.afterLoad.call(this),this.options.handler&&Mercury.modalHandlers[this.options.handler]&&Mercury.modalHandlers[this.options.handler].call(this),this.resize()},setTitle:function(){return this.titleElement.find("span").html(this.options.title)},reset:function(){return this.titleElement.find("span").html(""),this.contentElement.html("")},hide:function(){if(this.showing)return;return Mercury.trigger("focus:frame"),this.element.hide(),this.overlay.hide(),this.reset(),this.visible=!1}})}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.lightview=function(a,b){return b==null&&(b={}),Mercury.lightview.show(a,b),Mercury.lightview},jQuery.extend(Mercury.lightview,{minWidth:400,show:function(a,b){return this.url=a,this.options=b!=null?b:{},Mercury.trigger("focus:window"),this.initialize(),this.visible?this.update():this.appear()},initialize:function(){if(this.initialized)return;return this.build(),this.bindEvents(),this.initialized=!0},build:function(){var a,b;return this.element=jQuery("<div>",{"class":"mercury-lightview loading"}),this.element.html('<h1 class="mercury-lightview-title"><span></span></h1>'),this.element.append('<div class="mercury-lightview-content"></div>'),this.overlay=jQuery("<div>",{"class":"mercury-lightview-overlay"}),this.titleElement=this.element.find(".mercury-lightview-title"),this.contentElement=this.element.find(".mercury-lightview-content"),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body"),this.overlay.appendTo((b=jQuery(this.options.appendTo).get(0))!=null?b:"body"),this.titleElement.find("span").html(this.options.title)},bindEvents:function(){return Mercury.bind("refresh",a(function(){return this.resize(!0)},this)),Mercury.bind("resize",a(function(){if(this.visible)return this.position()},this)),this.overlay.click(a(function(){return this.hide()},this)),jQuery(document).bind("keydown",a(function(a){if(a.keyCode===27&&this.visible)return this.hide()},this))},appear:function(){return this.position(),this.overlay.show().css({opacity:0}),this.overlay.animate({opacity:1},200,"easeInOutSine",a(function(){return this.setTitle(),this.element.show().css({opacity:0}),this.element.animate({opacity:1},200,"easeInOutSine",a(function(){return this.visible=!0,this.load()},this))},this))},resize:function(b){var c,d,e,f;e=Mercury.displayRect.width,d=Mercury.displayRect.fullHeight,this.element.css({overflow:"hidden"}),this.contentElement.css({visibility:"hidden",display:"none",width:"auto",height:"auto"}),f=this.contentElement.outerWidth()+40+2;if(f>e-40||this.options.fullSize)f=e-40;c=this.contentElement.outerHeight()+this.titleElement.outerHeight()+30;if(c>d-20||this.options.fullSize)c=d-20;return f<300&&(f=300),c<150&&(c=150),this.element.stop().animate({top:(d-c)/2+10,left:(Mercury.displayRect.width-f)/2,width:f,height:c},200,"easeInOutSine",a(function(){return this.contentElement.css({visibility:"visible",display:"block",opacity:0}),this.contentElement.stop().animate({opacity:1},200,"easeInOutSine"),this.element.css({overflow:"auto"})},this))},position:function(){var a,b,c,d;c=Mercury.displayRect.width,b=Mercury.displayRect.fullHeight,this.contentElement.css({position:"absolute",width:"auto",height:"auto"}),d=this.contentElement.width()+40+2;if(d>c-40||this.options.fullSize)d=c-40;a=this.contentElement.height()+this.titleElement.outerHeight()+30;if(a>b-20||this.options.fullSize)a=b-20;this.contentElement.css({position:"relative"}),d<300&&(d=300),a<150&&(a=150),this.element.css({top:(b-a)/2+10,left:(c-d)/2,width:d,height:a,overflow:"auto"});if(this.visible)return this.contentElement.css({width:d-40,height:a-30-this.titleElement.outerHeight()})},update:function(){return this.reset(),this.resize(),this.load()},load:function(){this.setTitle();if(!this.url)return;return this.element.addClass("loading"),Mercury.preloadedViews[this.url]?setTimeout(a(function(){return this.loadContent(Mercury.preloadedViews[this.url])},this),10):jQuery.ajax(this.url,{type:this.options.loadType||"get",data:this.options.loadData,success:a(function(a){return this.loadContent(a)},this),error:a(function(){return this.hide(),alert("Mercury was unable to load "+this.url+" for the lightview.")},this)})},loadContent:function(a,b){return b==null&&(b=null),this.initialize(),this.options=b||this.options,this.setTitle(),this.loaded=!0,this.element.removeClass("loading"),this.contentElement.html(a),this.contentElement.css({display:"none",visibility:"hidden"}),this.options.afterLoad&&this.options.afterLoad.call(this),this.options.handler&&Mercury.lightviewHandlers[this.options.handler]&&Mercury.lightviewHandlers[this.options.handler].call(this),this.resize()},setTitle:function(){return this.titleElement.find("span").html(this.options.title)},reset:function(){return this.titleElement.find("span").html(""),this.contentElement.html("")},hide:function(){return Mercury.trigger("focus:frame"),this.element.hide(),this.overlay.hide(),this.reset(),this.visible=!1}})}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.Statusbar=function(){function b(a){this.options=a!=null?a:{},this.visible=this.options.visible,this.build(),this.bindEvents()}return b.prototype.build=function(){var a;return this.element=jQuery("<div>",{"class":"mercury-statusbar"}),this.aboutElement=jQuery("<a>",{"class":"mercury-statusbar-about"}).appendTo(this.element).html("Mercury Editor v"+Mercury.version),this.pathElement=jQuery("<div>",{"class":"mercury-statusbar-path"}).appendTo(this.element),this.visible||this.element.css({visibility:"hidden"}),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body")},b.prototype.bindEvents=function(){return Mercury.bind("region:update",a(function(a,b){if(b.region&&jQuery.type(b.region.path)==="function")return this.setPath(b.region.path())},this)),this.aboutElement.click(a(function(){return Mercury.lightview("/mercury/lightviews/about.html",{title:"About Mercury Editor v"+Mercury.version})},this))},b.prototype.height=function(){return this.element.outerHeight()},b.prototype.top=function(){var a,b;return b=this.element.offset().top,a=parseInt(this.element.css("bottom"))<0?b-this.element.outerHeight():b,this.visible?a:b+this.element.outerHeight()},b.prototype.setPath=function(a){var b,c,d,e;c=[];for(d=0,e=a.length;d<e;d++)b=a[d],c.push("<a>"+b.tagName.toLowerCase()+"</a>");return this.pathElement.html("<span><strong>Path: </strong>"+c.reverse().join(" &raquo; ")+"</span>")},b.prototype.show=function(){return this.visible=!0,this.element.css({opacity:0,visibility:"visible"}),this.element.animate({opacity:1},200,"easeInOutSine")},b.prototype.hide=function(){return this.visible=!1,this.element.css({visibility:"hidden"})},b}()}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.Toolbar=function(){function c(a){this.options=a!=null?a:{},this.visible=this.options.visible,this.build(),this.bindEvents()}return c.prototype.build=function(){var b,c,d,e,f,g,h,i,j,k;this.element=jQuery("<div>",{"class":"mercury-toolbar-container",style:"width:10000px"}),this.visible||this.element.css({display:"none"}),this.element.appendTo((j=jQuery(this.options.appendTo).get(0))!=null?j:"body"),k=Mercury.config.toolbars;for(i in k){if(!a.call(k,i))continue;d=k[i];if(d._custom)continue;h=jQuery("<div>",{"class":"mercury-toolbar mercury-"+i+"-toolbar"}).appendTo(this.element),d._regions&&h.attr("data-regions",d._regions),e=jQuery("<div>",{"class":"mercury-toolbar-button-container"}).appendTo(h);for(c in d){if(!a.call(d,c))continue;g=d[c];if(c==="_regions")continue;b=this.buildButton(c,g),b&&b.appendTo(e)}e.css("white-space")==="nowrap"&&(f=new Mercury.Toolbar.Expander(i,{appendTo:h,"for":e}),f.appendTo(this.element)),i!=="primary"&&h.addClass("disabled")}return this.element.css({width:"100%"})},c.prototype.buildButton=function(b,c){var d,e,f,g,h,i,j;if(b[0]==="_")return!1;switch(jQuery.type(c)){case"array":return j=c[0],i=c[1],g=c[2],new Mercury.Toolbar.Button(b,j,i,g,{appendDialogsTo:this.element});case"object":f=new Mercury.Toolbar.ButtonGroup(b,c);for(d in c){if(!a.call(c,d))continue;h=c[d],e=this.buildButton(d,h),e&&e.appendTo(f)}return f;case"string":return jQuery("<hr>",{"class":"mercury-"+(c==="-"?"line-separator":"separator")});default:throw"Unknown button structure -- please provide an array, object, or string for "+b+"."}},c.prototype.bindEvents=function(){return Mercury.bind("region:focused",b(function(a,b){var c,d,e,f,g,h;g=this.element.find(".mercury-toolbar"),h=[];for(e=0,f=g.length;e<f;e++)d=g[e],d=jQuery(d),h.push((c=d.data("regions"))?c.split(",").indexOf(b.region.type)>-1?d.removeClass("disabled"):void 0:void 0);return h},this)),Mercury.bind("region:blurred",b(function(a,b){var c,d,e,f,g,h;g=this.element.find(".mercury-toolbar"),h=[];for(e=0,f=g.length;e<f;e++)d=g[e],d=jQuery(d),h.push((c=d.data("regions"))?c.split(",").indexOf(b.region.type)>-1?d.addClass("disabled"):void 0:void 0);return h},this)),this.element.click(function(){return Mercury.trigger("hide:dialogs")}),this.element.mousedown(function(a){return a.preventDefault()})},c.prototype.height=function(){return this.visible?this.element.outerHeight():0},c.prototype.show=function(){return this.visible=!0,this.element.css({top:-this.element.outerHeight(),display:"block"}),this.element.animate({top:0},200,"easeInOutSine")},c.prototype.hide=function(){return this.visible=!1,this.element.hide()},c}()}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.Toolbar.Button=function(){function c(a,b,c,d,e){return this.name=a,this.title=b,this.summary=c!=null?c:null,this.types=d!=null?d:{},this.options=e!=null?e:{},this.build(),this.bindEvents(),this.element}return c.prototype.build=function(){var b,c,d,e,f,g,h;this.element=jQuery("<div>",{title:(f=this.summary)!=null?f:this.title,"class":"mercury-button mercury-"+this.name+"-button"}).html("<em>"+this.title+"</em>"),this.element.data("expander",'<div class="mercury-expander-button" data-button="'+this.name+'"><em></em><span>'+this.title+"</span></div>"),this.handled=[],b={title:this.summary||this.title,preload:this.types.preload,appendTo:this.options.appendDialogsTo||"body","for":this.element},g=this.types,h=[];for(d in g){if(!a.call(g,d))continue;c=g[d],h.push(function(){switch(d){case"preload":return!0;case"regions":return this.element.addClass("disabled"),this.handled[d]=jQuery.isFunction(c)?c.call(this,this.name):c;case"toggle":return this.handled[d]=!0;case"mode":return this.handled[d]=c===!0?this.name:c;case"context":return this.handled[d]=jQuery.isFunction(c)?c:Mercury.Toolbar.Button.contexts[this.name];case"palette":return this.element.addClass("mercury-button-palette"),e=jQuery.isFunction(c)?c.call(this,this.name):c,this.handled[d]=new Mercury.Palette(e,this.name,b);case"select":return this.element.addClass("mercury-button-select").find("em").html(this.title),e=jQuery.isFunction(c)?c.call(this,this.name):c,this.handled[d]=new Mercury.Select(e,this.name,b);case"panel":return this.element.addClass("mercury-button-panel"),e=jQuery.isFunction(c)?c.call(this,this.name):c,this.handled.toggle=!0,this.handled[d]=new Mercury.Panel(e,this.name,b);case"modal":return this.handled[d]=jQuery.isFunction(c)?c.apply(this,this.name):c;default:throw"Unknown button type "+d+" used for the "+this.name+" button."}}.call(this))}return h},c.prototype.bindEvents=function(){return Mercury.bind("button",b(function(a,b){if(b.action===this.name)return this.element.click()},this)),Mercury.bind("region:update",b(function(a,b){var c;return this.handled.context&&b.region&&jQuery.type(b.region.currentElement)==="function"?(c=b.region.currentElement(),c.length&&this.handled.context.call(this,c,b.region.element)?this.element.addClass("active"):this.element.removeClass("active")):this.element.removeClass("active")},this)),Mercury.bind("region:focused",b(function(a,b){if(this.handled.regions&&b.region&&b.region.type)return this.handled.regions.indexOf(b.region.type)>-1?this.element.removeClass("disabled"):this.element.addClass("disabled")},this)),Mercury.bind("region:blurred",b(function(a,b){if(this.handled.regions)return this.element.addClass("disabled")},this)),this.element.mousedown(b(function(a){return this.element.addClass("active")},this)),this.element.mouseup(b(function(a){return this.element.removeClass("active")},this)),this.element.click(b(function(b){var c,d,e,f;if(this.element.closest(".disabled").length)return;c=!1,f=this.handled;for(e in f){if(!a.call(f,e))continue;d=f[e];switch(e){case"toggle":this.togglePressed();break;case"mode":c=!0,Mercury.trigger("mode",{mode:d});break;case"modal":c=!0,Mercury.modal(this.handled.modal,{title:this.summary||this.title,handler:this.name});break;case"palette":case"select":case"panel":b.stopPropagation(),c=!0,this.handled[e].toggle()}}return c||Mercury.trigger("action",{action:this.name}),Mercury.trigger("focus:frame")},this))},c.prototype.togglePressed=function(){return this.element.toggleClass("pressed")},c}(),this.Mercury.Toolbar.Button.contexts={backColor:function(a){return this.element.css("background-color",a.css("background-color"))},foreColor:function(a){return this.element.css("background-color",a.css("color"))},bold:function(a){var b;return b=a.css("font-weight"),b==="bold"||b>400},italic:function(a){return a.css("font-style")==="italic"},overline:function(a){return a.css("text-decoration")==="overline"},strikethrough:function(a,b){return a.css("text-decoration")==="line-through"||!!a.closest("strike",b).length},underline:function(a,b){return a.css("text-decoration")==="underline"||!!a.closest("u",b).length},subscript:function(a,b){return!!a.closest("sub",b).length},superscript:function(a,b){return!!a.closest("sup",b).length},justifyLeft:function(a){return a.css("text-align").indexOf("left")>-1},justifyCenter:function(a){return a.css("text-align").indexOf("center")>-1},justifyRight:function(a){return a.css("text-align").indexOf("right")>-1},justifyFull:function(a){return a.css("text-align").indexOf("justify")>-1},insertOrderedList:function(a,b){return!!a.closest("ol",b.element).length},insertUnorderedList:function(a,b){return!!a.closest("ul",b.element).length}}}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.Toolbar.ButtonGroup=function(){function b(a,b){return this.name=a,this.options=b!=null?b:{},this.build(),this.bindEvents(),this.regions=this.options._regions,this.element}return b.prototype.build=function(){this.element=jQuery("<div>",{"class":"mercury-button-group mercury-"+this.name+"-group"});if(this.options._context||this.options._regions)return this.element.addClass("disabled")},b.prototype.bindEvents=function(){return Mercury.bind("region:update",a(function(a,b){var c,d;c=Mercury.Toolbar.ButtonGroup.contexts[this.name];if(c&&b.region&&jQuery.type(b.region.currentElement)==="function")return d=b.region.currentElement(),d.length&&c.call(this,d,b.region.element)?this.element.removeClass("disabled"):this.element.addClass
("disabled")},this)),Mercury.bind("region:focused",a(function(a,b){if(this.regions&&b.region&&b.region.type){if(!(this.regions.indexOf(b.region.type)>-1))return this.element.addClass("disabled");if(!this.options._context)return this.element.removeClass("disabled")}},this)),Mercury.bind("region:blurred",a(function(a,b){if(this.options.regions)return this.element.addClass("disabled")},this))},b}(),this.Mercury.Toolbar.ButtonGroup.contexts={table:function(a,b){return!!a.closest("table",b).length}}}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b},c=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.Toolbar.Expander=function(){function a(b,c){return this.name=b,this.options=c,this.container=this.options["for"],this.containerWidth=this.container.outerWidth(),a.__super__.constructor.call(this,null,this.name,this.options),this.element}return b(a,Mercury.Palette),a.prototype.build=function(){var a;return this.container.css({whiteSpace:"normal"}),this.trigger=jQuery("<div>",{"class":"mercury-toolbar-expander"}).appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body"),this.element=jQuery("<div>",{"class":"mercury-palette mercury-expander mercury-"+this.name+"-expander",style:"display:none"}),this.windowResize()},a.prototype.bindEvents=function(){return Mercury.bind("hide:dialogs",c(function(a,b){if(b!==this)return this.hide()},this)),Mercury.bind("resize",c(function(){return this.windowResize()},this)),a.__super__.bindEvents.apply(this,arguments),this.trigger.click(c(function(a){var b,c,d,e,f;a.stopPropagation(),c=[],f=this.container.find(".mercury-button");for(d=0,e=f.length;d<e;d++)b=f[d],b=jQuery(b),b.position().top>5&&c.push(b.data("expander"));return this.loadContent(c.join("")),this.toggle()},this)),this.element.click(c(function(a){var b,c;return c=jQuery(a.target).closest("[data-button]").data("button"),b=this.container.find(".mercury-"+c+"-button"),b.click()},this))},a.prototype.windowResize=function(){return this.containerWidth>jQuery(window).width()?this.trigger.show():this.trigger.hide(),this.hide()},a.prototype.position=function(a){var b,c;return this.element.css({top:0,left:0,display:"block",visibility:"hidden"}),b=this.trigger.offset(),c=this.element.width(),b.left+c>jQuery(window).width()&&(b.left=b.left-c+this.trigger.width()),this.element.css({top:b.top+this.trigger.height(),left:b.left,display:a?"block":"none",visibility:"visible"})},a}()}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.tooltip=function(a,b,c){return c==null&&(c={}),Mercury.tooltip.show(a,b,c),Mercury.tooltip},jQuery.extend(Mercury.tooltip,{show:function(a,b,c){return this.forElement=a,this.content=b,this.options=c!=null?c:{},this.document=jQuery(this.forElement.get(0).ownerDocument),this.initialize(),this.visible?this.update():this.appear()},initialize:function(){if(this.initialized)return;return this.build(),this.bindEvents(),this.initialized=!0},build:function(){var a;return this.element=jQuery("<div>",{"class":"mercury-tooltip"}),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body")},bindEvents:function(){var b,c,d,e;Mercury.bind("resize",a(function(){if(this.visible)return this.position()},this)),this.document.scroll(a(function(){if(this.visible)return this.position()},this)),e=this.forElement.parentsUntil(jQuery("body",this.document));for(c=0,d=e.length;c<d;c++)b=e[c],b.scrollHeight>b.clientHeight&&jQuery(b).scroll(a(function(){if(this.visible)return this.position()},this));return this.element.mousedown(function(a){return a.preventDefault(),a.stopPropagation()})},appear:function(){return this.update(),this.element.show(),this.element.animate({opacity:1},200,"easeInOutSine",a(function(){return this.visible=!0},this))},update:function(){return this.element.html(this.content),this.position()},position:function(){var a,b,c,d;return b=this.forElement.offset(),d=this.element.width(),c=b.top+(Mercury.displayRect.top-jQuery(this.document).scrollTop())+this.forElement.outerHeight(),a=b.left-jQuery(this.document).scrollLeft(),a+d+25>Mercury.displayRect.width&&(a=a-(a+d+25)-Mercury.displayRect.width),a=a<=0?0:a,this.element.css({top:c,left:a})},hide:function(){if(!this.initialized)return;return this.element.hide(),this.visible=!1}})}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.Snippet=function(){function c(a,b,c){this.name=a,this.identity=b,c==null&&(c={}),this.version=0,this.data="",this.history=new Mercury.HistoryBuffer,this.setOptions(c)}return c.all=[],c.displayOptionsFor=function(a){return Mercury.modal(Mercury.config.snippets.optionsUrl.replace(":name",a),{title:"Snippet Options",handler:"insertSnippet",snippetName:a}),Mercury.snippet=null},c.create=function(a,b){var c,d;return c="snippet_"+this.all.length,d=new Mercury.Snippet(a,c,b),this.all.push(d),d},c.find=function(a){var b,c,d,e;e=this.all;for(c=0,d=e.length;c<d;c++){b=e[c];if(b.identity===a)return b}return null},c.load=function(b){var c,d,e,f;f=[];for(d in b){if(!a.call(b,d))continue;c=b[d],e=new Mercury.Snippet(c.name,d,c.options),f.push(this.all.push(e))}return f},c.prototype.getHTML=function(a,b){var c;return b==null&&(b=null),c=jQuery('<div class="mercury-snippet" contenteditable="false">',a),c.attr({"data-snippet":this.identity}),c.attr({"data-version":this.version}),c.html("["+this.identity+"]"),this.loadPreview(c,b),c},c.prototype.getText=function(a){return"[--"+this.identity+"--]"},c.prototype.loadPreview=function(a,c){return c==null&&(c=null),jQuery.ajax(Mercury.config.snippets.previewUrl.replace(":name",this.name),{type:Mercury.config.snippets.method,data:this.options,success:b(function(b){this.data=b,a.html(b);if(c)return c()},this),error:b(function(){return alert("Error loading the preview for the "+this.name+" snippet.")},this)})},c.prototype.displayOptions=function(){return Mercury.snippet=this,Mercury.modal(Mercury.config.snippets.optionsUrl.replace(":name",this.name),{title:"Snippet Options",handler:"insertSnippet",loadType:Mercury.config.snippets.method,loadData:this.options})},c.prototype.setOptions=function(a){return this.options=a,delete this.options.authenticity_token,delete this.options.utf8,this.version+=1,this.history.push(this.options)},c.prototype.setVersion=function(a){return a==null&&(a=null),a=parseInt(a),a&&this.history.stack[a-1]?(this.version=a-1,this.options=this.history.stack[this.version],!0):!1},c.prototype.serialize=function(){return{name:this.name,options:this.options}},c}()}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b},c=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.SnippetToolbar=function(){function d(a,b){this.document=a,this.options=b!=null?b:{},d.__super__.constructor.call(this,this.options)}return b(d,Mercury.Toolbar),d.prototype.build=function(){var b,c,d,e,f,g;this.element=jQuery("<div>",{"class":"mercury-toolbar mercury-snippet-toolbar",style:"display:none"}),this.element.appendTo((e=jQuery(this.options.appendTo).get(0))!=null?e:"body"),f=Mercury.config.toolbars.snippetable,g=[];for(c in f){if(!a.call(f,c))continue;d=f[c],b=this.buildButton(c,d),g.push(b?b.appendTo(this.element):void 0)}return g},d.prototype.bindEvents=function(){return Mercury.bind("show:toolbar",c(function(a,b){if(!b.snippet)return;return b.snippet.mouseout(c(function(){return this.hide()},this)),this.show(b.snippet)},this)),Mercury.bind("hide:toolbar",c(function(a,b){if(!b.type||b.type!=="snippet")return;return this.hide(b.immediately)},this)),jQuery(this.document).scroll(c(function(){if(this.visible)return this.position()},this)),this.element.mousemove(c(function(){return clearTimeout(this.hideTimeout)},this)),this.element.mouseout(c(function(){return this.hide()},this))},d.prototype.show=function(a){return this.snippet=a,Mercury.tooltip.hide(),this.position(),this.appear()},d.prototype.position=function(){var a,b,c;return b=this.snippet.offset(),c=b.top+Mercury.displayRect.top-jQuery(this.document).scrollTop()-this.height()+10,a=b.left-jQuery(this.document).scrollLeft(),this.element.css({top:c,left:a})},d.prototype.appear=function(){clearTimeout(this.hideTimeout);if(this.visible)return;return this.visible=!0,this.element.css({display:"block",opacity:0}),this.element.stop().animate({opacity:1},200,"easeInOutSine")},d.prototype.hide=function(a){return a==null&&(a=!1),clearTimeout(this.hideTimeout),a?(this.element.hide(),this.visible=!1):this.hideTimeout=setTimeout(c(function(){return this.element.stop().animate({opacity:0},300,"easeInOutSine",c(function(){return this.element.hide()},this)),this.visible=!1},this),500)},d}()}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.Region=function(){function c(a,b,c){this.element=a,this.window=b,this.options=c!=null?c:{},this.type||(this.type="region"),Mercury.log("building "+this.type,this.element,this.options),this.document=this.window.document,this.name=this.element.attr("id"),this.history=new Mercury.HistoryBuffer,this.build(),this.bindEvents(),this.pushHistory()}var b;return b="region",c.prototype.build=function(){},c.prototype.focus=function(){},c.prototype.bindEvents=function(){return Mercury.bind("mode",a(function(a,b){if(b.mode==="preview")return this.togglePreview()},this)),Mercury.bind("focus:frame",a(function(){if(this.previewing)return;if(Mercury.region!==this)return;return this.focus()},this)),Mercury.bind("action",a(function(a,b){if(this.previewing)return;if(Mercury.region!==this)return;if(b.action)return this.execCommand(b.action,b)},this)),this.element.mousemove(a(function(a){var b;if(this.previewing)return;if(Mercury.region!==this)return;b=jQuery(a.target).closest(".mercury-snippet");if(b.length)return this.snippet=b,Mercury.trigger("show:toolbar",{type:"snippet",snippet:this.snippet})},this)),this.element.mouseout(a(function(a){if(this.previewing)return;return Mercury.trigger("hide:toolbar",{type:"snippet",immediately:!1})},this))},c.prototype.content=function(a,b){var c,d,e,f,g;a==null&&(a=null),b==null&&(b=!1);if(a!==null)return this.element.html(a);c=jQuery("<div>").appendTo(this.document.createDocumentFragment()),c.html(this.element.html().replace(/^\s+|\s+$/g,""));if(b){g=c.find(".mercury-snippet");for(d=0,f=g.length;d<f;d++)e=g[d],e=jQuery(e),e.attr({contenteditable:null,"data-version":null}),e.html("["+e.data("snippet")+"]")}return c.html()},c.prototype.togglePreview=function(){if(!this.previewing)return this.previewing=!0,this.element.addClass("mercury-region-preview").removeClass("mercury-region"),Mercury.trigger("region:blurred",{region:this});this.previewing=!1,this.element.addClass("mercury-region").removeClass("mercury-region-preview");if(Mercury.region===this)return this.focus()},c.prototype.execCommand=function(a,b){return b==null&&(b={}),this.focus(),a!=="redo"&&this.pushHistory(),Mercury.log("execCommand",a,b.value),Mercury.changes=!0},c.prototype.pushHistory=function(){return this.history.push(this.content())},c.prototype.snippets=function(){var a,b,c,d,e,f;c={},f=this.element.find("[data-snippet]");for(d=0,e=f.length;d<e;d++)a=f[d],b=Mercury.Snippet.find(jQuery(a).data("snippet")),b.setVersion(jQuery(a).data("version")),c[b.identity]=b.serialize();return c},c.prototype.serialize=function(){return{type:this.type,value:this.content(null,!0),snippets:this.snippets()}},c}()}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}},b=Object.prototype.hasOwnProperty;this.Mercury.uploader=function(a,b){return Mercury.config.uploading.enabled&&Mercury.uploader.show(a,b),Mercury.uploader},jQuery.extend(Mercury.uploader,{show:function(a,b){this.options=b!=null?b:{},this.file=new Mercury.uploader.File(a);if(this.file.errors){alert("Error: "+this.file.errors);return}if(!this.supported())return;return Mercury.trigger("focus:window"),this.initialize(),this.appear()},initialize:function(){if(this.initialized)return;return this.build(),this.bindEvents(),this.initialized=!0},supported:function(){var a,b;return b=new XMLHttpRequest,a=window.FileReader,window.Uint8Array&&window.ArrayBuffer&&!XMLHttpRequest.prototype.sendAsBinary&&(XMLHttpRequest.prototype.sendAsBinary=function(a){var b,c,d,e;d=new Uint8Array(a.length);for(c=0,e=a.length;c<e;c++)b=a[c],d[c]=a.charCodeAt(c)&255;return this.send(d.buffer)}),!!(b.upload&&b.sendAsBinary&&a)},build:function(){var a,b;return this.element=jQuery("<div>",{"class":"mercury-uploader",style:"display:none"}),this.element.append('<div class="mercury-uploader-preview"><b><img/></b></div>'),this.element.append('<div class="mercury-uploader-details"></div>'),this.element.append('<div class="mercury-uploader-progress"><span>Processing...</span><div class="mercury-uploader-indicator"><div><b>0%</b></div></div></div>'),this.overlay=jQuery("<div>",{"class":"mercury-uploader-overlay",style:"display:none"}),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body"),this.overlay.appendTo((b=jQuery(this.options.appendTo).get(0))!=null?b:"body")},bindEvents:function(){return Mercury.bind("resize",a(function(){return this.position()},this))},appear:function(){return this.fillDisplay(),this.position(),this.overlay.show(),this.overlay.animate({opacity:1},200,"easeInOutSine",a(function(){return this.element.show(),this.element.animate({opacity:1},200,"easeInOutSine",a(function(){return this.visible=!0,this.loadImage()},this))},this))},position:function(){var a,b;return b=this.element.outerWidth(),a=this.element.outerHeight(),this.element.css({top:(Mercury.displayRect.height-a)/2,left:(Mercury.displayRect.width-b)/2})},fillDisplay:function(){var a;return a=["Name: "+this.file.name,"Size: "+this.file.readableSize,"Type: "+this.file.type],this.element.find(".mercury-uploader-details").html(a.join("<br/>"))},loadImage:function(){return this.file.readAsDataURL(a(function(a){return this.element.find(".mercury-uploader-preview b").html(jQuery("<img>",{src:a})),this.upload()},this))},upload:function(){var b;return b=new XMLHttpRequest,jQuery.each(["onloadstart","onprogress","onload","onabort","onerror"],a(function(c,d){return b.upload[d]=a(function(a){return this.uploaderEvents[d].call(this,a)},this)},this)),b.onload=a(function(a){var b;console.debug(a);if(a.currentTarget.status>=400)return this.updateStatus("Error: Unable to upload the file"),alert(""+a.currentTarget.status+": Unable to process response"),this.hide();try{return b=Mercury.config.uploading.handler?Mercury.config.uploading.handler(a.target.responseText):jQuery.parseJSON(a.target.responseText),Mercury.trigger("action",{action:"insertImage",value:{src:b.image.url}})}catch(c){return this.updateStatus("Error: Unable to upload the file"),alert("Unable to process response: "+c),this.hide()}},this),b.open("post",Mercury.config.uploading.url,!0),b.setRequestHeader("Accept","application/json, text/javascript, text/html, application/xml, text/xml, */*"),b.setRequestHeader("X-Requested-With","XMLHttpRequest"),b.setRequestHeader("X-CSRF-Token",Mercury.csrfToken),this.file.readAsBinaryString(a(function(a){var c;return c=new Mercury.uploader.MultiPartPost(Mercury.config.uploading.inputName,this.file,a),this.file.updateSize(c.delta),b.setRequestHeader("Content-Type","multipart/form-data; boundary="+c.boundary),b.sendAsBinary(c.body)},this))},updateStatus:function(a,b){var c;this.element.find(".mercury-uploader-progress span").html(a);if(b)return c=Math.floor(b*100/this.file.size)+"%",this.element.find(".mercury-uploader-indicator div").css({width:c}),this.element.find(".mercury-uploader-indicator b").html(c).show()},hide:function(b){return b==null&&(b=0),setTimeout(a(function(){return this.element.animate({opacity:0},200,"easeInOutSine",a(function(){return this.overlay.animate({opacity:0},200,"easeInOutSine",a(function(){return this.overlay.hide(),this.element.hide(),this.reset(),this.visible=!1,Mercury.trigger("focus:frame")},this))},this))},this),b*1e3)},reset:function(){return this.element.find(".mercury-uploader-preview b").html(""),this.element.find(".mercury-uploader-indicator div").css({width:0}),this.element.find(".mercury-uploader-indicator b").html("0%").hide(),this.updateStatus("Processing...")},uploaderEvents:{onloadstart:function(){return this.updateStatus("Uploading...")},onprogress:function(a){return this.updateStatus("Uploading...",a.loaded)},onabort:function(){return this.updateStatus("Aborted"),this.hide(1)},onload:function(){return this.updateStatus("Successfully uploaded",this.file.size),this.hide(1)},onerror:function(){return this.updateStatus("Error: Unable to upload the file"),this.hide(3)}}}),Mercury.uploader.File=function(){function b(a){var b;this.file=a,this.size=this.file.size,this.fullSize=this.file.size,this.readableSize=this.file.size.toBytes(),this.name=this.file.fileName,this.type=this.file.type,b=[],this.size>=Mercury.config.uploading.maxFileSize&&b.push("Too large"),Mercury.config.uploading.allowedMimeTypes.indexOf(this.type)>-1||b.push("Unsupported format"),b.length&&(this.errors=b.join(" / "))}return b.prototype.readAsDataURL=function(b){var c;return b==null&&(b=null),c=new FileReader,c.readAsDataURL(this.file),c.onload=a(function(){if(b)return b(c.result)},this)},b.prototype.readAsBinaryString=function(b){var c;return b==null&&(b=null),c=new FileReader,c.readAsBinaryString(this.file),c.onload=a(function(){if(b)return b(c.result)},this)},b.prototype.updateSize=function(a){return this.fullSize=this.size+a},b}(),Mercury.uploader.MultiPartPost=function(){function a(a,b,c,d){this.inputName=a,this.file=b,this.contents=c,this.formInputs=d!=null?d:{},this.boundary="Boundaryx20072377098235644401115438165x",this.body="",this.buildBody(),this.delta=this.body.length-this.file.size}return a.prototype.buildBody=function(){var a,c,d,e;a="--"+this.boundary,e=this.formInputs;for(c in e){if(!b.call(e,c))continue;d=e[c],this.body+=""+a+'\r\nContent-Disposition: form-data; name="'+c+'"\r\n\r\n'+unescape(encodeURIComponent(d))+"\r\n"}return this.body+=""+a+'\r\nContent-Disposition: form-data; name="'+this.inputName+'"; filename="'+this.file.name+'"\r\nContent-Type: '+this.file.type+"\r\nContent-Transfer-Encoding: binary\r\n\r\n"+this.contents+"\r\n"+a+"--"},a}()}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b},c=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.Regions.Editable=function(){function d(a,b,c){this.element=a,this.window=b,this.options=c!=null?c:{},this.type="editable",d.__super__.constructor.apply(this,arguments)}var a;return b(d,Mercury.Region),a="editable",d.prototype.build=function(){var a,b,c,d;jQuery.browser.mozilla&&this.content()===""&&this.content("&nbsp;"),this.element.data({originalOverflow:this.element.css("overflow")}),this.element.css({overflow:"auto"}),this.specialContainer=jQuery.browser.mozilla&&this.element.get(0).tagName!=="DIV",this.element.get(0).contentEditable=!0,d=this.element.find(".mercury-snippet");for(b=0,c=d.length;b<c;b++)a=d[b],a.contentEditable=!1,jQuery(a).attr("data-version","1");if(!this.document.mercuryEditing)return this.document.execCommand("styleWithCSS",!1,!1),this.document.execCommand("insertBROnReturn",!1,!0),this.document.execCommand("enableInlineTableEditing",!1,!1),this.document.execCommand("enableObjectResizing",!1,!1),this.document.mercuryEditing=!0},d.prototype.bindEvents=function(){return d.__super__.bindEvents.apply(this,arguments),Mercury.bind("region:update",c(function(){var a,b,d;if(this.previewing)return;if(Mercury.region!==this)return;setTimeout(c(function(){return this.selection().forceSelection(this.element.get(0))},this),1),b=this.currentElement();if(b.length)return d=b.closest("table",this.element),d.length&&Mercury.tableEditor(d,b.closest("tr, td"),"&nbsp;"),a=b.closest("a",this.element),a.length&&a.attr("href")?Mercury.tooltip(a,'<a href="'+a.attr("href")+'" target="_blank">'+a.attr("href")+"</a>",{position:"below"}):Mercury.tooltip.hide()},this)),this.element.bind("dragenter",c(function(a){if(this.previewing)return;return Mercury.snippet||a.preventDefault(),a.originalEvent.dataTransfer.dropEffect="copy"},this)),this.element.bind("dragover",c(function(a){if(this.previewing)return;Mercury.snippet||a.preventDefault(),a.originalEvent.dataTransfer.dropEffect="copy";if(jQuery.browser.webkit)return clearTimeout(this.dropTimeout),this.dropTimeout=setTimeout(c(function(){return this.element.trigger("possible:drop")},this),10)},this)),this.element.bind("drop",c(function(a){if(this.previewing)return;clearTimeout(this.dropTimeout),this.dropTimeout=setTimeout(c(function(){return this.element.trigger("possible:drop")},this),1);if(!a.originalEvent.dataTransfer.files.length)return;return a.preventDefault(),this.focus(),Mercury.uploader(a.originalEvent.dataTransfer.files[0])},this)),this.element.bind("possible:drop",c(function(a){var b;if(this.previewing)return;if(b=this.element.find("img[data-snippet]").get(0))return this.focus(),Mercury.Snippet.displayOptionsFor(jQuery(b).data("snippet")),this.document.execCommand("undo",!1,null)},this)),this.element.bind("paste",c(function(){var a;if(this.previewing)return;if(Mercury.region!==this)return;Mercury.changes=!0;if(this.specialContainer){event.preventDefault();return}return a=this.content(),clearTimeout(this.handlePasteTimeout),this.handlePasteTimeout=setTimeout(c(function(){return this.handlePaste(a)},this),100)},this)),this.element.focus(c(function(){if(this.previewing)return;return Mercury.region=this,setTimeout(c(function(){return this.selection().forceSelection(this.element.get(0))},this),1),Mercury.trigger("region:focused",{region:this})},this)),this.element.blur(c(function(){if(this.previewing)return;return Mercury.trigger("region:blurred",{region:this}),Mercury.tooltip.hide()},this)),this.element.click(c(function(a){if(this.previewing)return jQuery(a.target).closest("a").attr("target","_top")},this)),this.element.dblclick(c(function(a){var b;if(this.previewing)return;b=jQuery(a.target).closest("img",this.element);if(b.length)return this.selection().selectNode(b.get(0),!0),Mercury.trigger("button",{action:"insertMedia"})},this)),this.element.mouseup(c(function(){if(this.previewing)return;return this.pushHistory(),Mercury.trigger("region:update",{region:this})},this)),this.element.keydown(c(function(a){var b,c;if(this.previewing)return;Mercury.changes=!0;switch(a.keyCode){case 90:if(!a.metaKey)return;a.preventDefault(),a.shiftKey?this.execCommand("redo"):this.execCommand("undo");return;case 13:jQuery.browser.webkit&&this.selection().commonAncestor().closest("li, ul",this.element).length===0?(a.preventDefault(),this.document.execCommand("insertLineBreak",!1,null)):this.specialContainer&&(a.preventDefault(),this.document.execCommand("insertHTML",!1,"<br/>"));break;case 9:a.preventDefault(),b=this.selection().commonAncestor(),c=!1,b.closest("li",this.element).length&&(c=!0,a.shiftKey?this.execCommand("outdent"):this.execCommand("indent")),c||this.execCommand("insertHTML",{value:"&nbsp; "})}if(a.metaKey)switch(a.keyCode){case 66:this.execCommand("bold"),a.preventDefault();break;case 73:this.execCommand("italic"),a.preventDefault();break;case 85:this.execCommand("underline"),a.preventDefault()}return this.pushHistory(a.keyCode)},this)),this.element.keyup(c(function(){if(this.previewing)return;return Mercury.trigger("region:update",{region:this})},this))},d.prototype.focus=function(){var a;return Mercury.region!==this&&(this.element.focus(),a=this.selection().selection.collapseToStart()),Mercury.trigger("region:focused",{region:this}),Mercury.trigger("region:update",{region:this})},d.prototype.content=function(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o;a==null&&(a=null),b==null&&(b=!0),c==null&&(c=!1);if(a!==null){d=jQuery("<div>").appendTo(this.document.createDocumentFragment()),d.html(a),n=d.find("[data-snippet]");for(k=0,l=n.length;k<l;k++){f=n[k],f.contentEditable=!1,f=jQuery(f);if(i=Mercury.Snippet.find(f.data("snippet")))if(!f.data("version"))try{j=parseInt(f.html().match(/\/(\d+)\]/)[1]),j&&(i.setVersion(j),f.attr({"data-version":j}),f.html(i.data))}catch(p){}}return this.element.html(d.html()),this.selection().selectMarker(this.element)}this.element.find("meta").remove(),c&&(h=this.selection(),h.placeMarker()),d=jQuery("<div>").appendTo(this.document.createDocumentFragment()),d.html(this.element.html().replace(/^\s+|\s+$/g,""));if(b){o=d.find("[data-snippet]");for(g=0,m=o.length;g<m;g++){f=o[g],f=jQuery(f);if(i=Mercury.Snippet.find(f.data("snippet")))i.data=f.html();f.html("["+f.data("snippet")+"/"+f.data("version")+"]"),f.attr({contenteditable:null,"data-version":null})}}return e=d.html(),c&&h.removeMarker(),e},d.prototype.togglePreview=function(){return this.previewing?(this.element.get(0).contentEditable=!0,this.element.css({overflow:"auto"})):(this.content(this.content()),this.element.get(0).contentEditable=!1,this.element.css({overflow:this.element.data("originalOverflow")}),this.element.blur()),d.__super__.togglePreview.apply(this,arguments)},d.prototype.execCommand=function(a,b){var c,e;b==null&&(b={}),d.__super__.execCommand.apply(this,arguments);if(c=Mercury.config.behaviors[a]||Mercury.Regions.Editable.actions[a])return c.call(this,this.selection(),b);a==="indent"&&(e=this.element.get(0).previousSibling),a==="insertHTML"&&b.value&&b.value.get&&(b.value=jQuery("<div>").html(b.value).html());try{return this.document.execCommand(a,!1,b.value)}catch(f){if(a==="indent"&&this.element.prev()!==e)return this.element.prev().remove()}},d.prototype.pushHistory=function(a){var b,d,e;return b=[13,46,8],e=2.5,a&&(d=b.indexOf(a)),clearTimeout(this.historyTimeout),d>=0&&d!==this.lastKnownKeyCode?this.history.push(this.content(null,!1,!0)):a?this.historyTimeout=setTimeout(c(function(){return this.history.push(this.content(null,!1,!0))},this),e*1e3):this.history.push(this.content(null,!1,!0)),this.lastKnownKeyCode=d},d.prototype.selection=function(){return new Mercury.Regions.Editable.Selection(this.window.getSelection(),this.document)},d.prototype.path=function(){var a;return a=this.selection().commonAncestor(),a?a.get(0)===this.element.get(0)?[]:a.parentsUntil(this.element):[]},d.prototype.currentElement=function(){var a,b;return a=[],b=this.selection(),b.range&&(a=b.commonAncestor(),a.get(0).nodeType===3&&(a=a.parent())),a},d.prototype.handlePaste=function(a){var b,c,d,e;a=a.replace(/^\<br\>/,""),this.element.find(".mercury-region").remove(),d=this.content();if(d.indexOf("<!--StartFragment-->")>-1||d.indexOf('="mso-')>-1||d.indexOf("<o:")>-1||d.indexOf('="Mso')>-1){b=a.singleDiff(this.content()).sanitizeHTML();try{return this.document.execCommand("undo",!1,null),this.execCommand("insertHTML",{value:b})}catch(f){return this.content(a),Mercury.modal("/mercury/modals/sanitizer",{title:"HTML Sanitizer (Starring Clippy)",afterLoad:function(){return this.element.find("textarea").val(b.replace(/<br\/>/g,"\n"))}})}}else if(Mercury.config.cleanStylesOnPaste)return e=a.singleDiff(this.content()),c=jQuery("<div>").appendTo(this.document.createDocumentFragment()).html(e),c.find("[style]").attr({style:null}),this.document.execCommand("undo",!1,null),this.execCommand("insertHTML",{value:c.html()})},d.actions={insertRowBefore:function(){return Mercury.tableEditor.addRow("before")},insertRowAfter:function(){return Mercury.tableEditor.addRow("after")},insertColumnBefore:function(){return Mercury.tableEditor.addColumn("before")},insertColumnAfter:function(){return Mercury.tableEditor.addColumn("after")},deleteColumn:function(){return Mercury.tableEditor.removeColumn()},deleteRow:function(){return Mercury.tableEditor.removeRow()},increaseColspan:function(){return Mercury.tableEditor.increaseColspan()},decreaseColspan:function(){return Mercury.tableEditor.decreaseColspan()},increaseRowspan:function(){return Mercury.tableEditor.increaseRowspan()},decreaseRowspan:function(){return Mercury.tableEditor.decreaseRowspan()},undo:function(){return this.content(this.history.undo())},redo:function(){return this.content(this.history.redo())},removeFormatting:function(a){return a.insertTextNode(a.textContent())},backColor:function(a,b){return a.wrap('<span style="background-color:'+b.value.toHex()+'">',!0)},overline:function(a){return a.wrap('<span style="text-decoration:overline">',!0)},style:function(a,b){return a.wrap('<span class="'+b.value+'">',!0)},replaceHTML:function(a,b){return this.content(b.value)},insertImage:function(a,b){return this.execCommand("insertHTML",{value:jQuery("<img/>",b.value)})},insertLink:function(a,b){var c;return c=jQuery("<"+b.value.tagName+">",this.document).attr(b.value.attrs).html(b.value.content),a.insertNode(c)},replaceLink:function(a,b){var c,d;return c=jQuery("<"+b.value.tagName+">",this.document).attr(b.value.attrs).html(b.value.content),a.selectNode(b.node),d=jQuery("<div>").html(a.content()).find("a").html(),a.replace(jQuery(c,a.context).html(d))},insertSnippet:function(a,b){var c,d;return d=b.value,(c=this.element.find("[data-snippet="+d.identity+"]")).length&&a.selectNode(c.get(0)),a.insertNode(d.getHTML(this.document))},editSnippet:function(){var a;if(!this.snippet)return;return a=Mercury.Snippet.find(this.snippet.data("snippet")),a.displayOptions()},removeSnippet:function(){return this.snippet&&this.snippet.remove(),Mercury.trigger("hide:toolbar",{type:"snippet",immediately:!0})}},d}(),Mercury.Regions.Editable.Selection=function(){function a(a,b){this.selection=a,this.context=b;if(this.selection.rangeCount>=1)this.range=this.selection.getRangeAt(0),this.fragment=this.range.cloneContents(),this.clone=this.range.cloneRange(),this.collapsed=this.selection.isCollapsed;else return}return a.prototype.commonAncestor=function(a){var b;return a==null&&(a=!1),this.range?(b=this.range.commonAncestorContainer,b.nodeType===3&&a&&(b=b.parentNode),jQuery(b)):null},a.prototype.wrap=function(a,b){return b==null&&(b=!1),a=jQuery(a,this.context).html(this.fragment),b&&this.replace(a),a},a.prototype.textContent=function(){return this.range.cloneContents().textContent},a.prototype.content=function(){return this.range.cloneContents()},a.prototype.is=function(a){var b;return b=this.content(),b.childNodes.length===1&&jQuery(b.firstChild).is(a)?jQuery(b.firstChild):!1},a.prototype.forceSelection=function(a){var b,c;if(!jQuery.browser.webkit)return;c=this.context.createRange(),this.range?this.commonAncestor(!0).closest(".mercury-snippet").length&&(b=this.context.createTextNode("\0"),a.appendChild(b)):a.lastChild&&a.lastChild.nodeType===3&&a.lastChild.textContent.replace(/^[\s+|\n+]|[\s+|\n+]$/,"")===""?(b=a.lastChild,a.lastChild.textContent="\0"):(b=this.context.createTextNode(" "),a.appendChild(b));if(b)return c.setStartBefore(b),c.setEndBefore(b),this.selection.addRange(c)},a.prototype.selectMarker=function(a){var b,c;b=a.find("em.mercury-marker");if(!b.length)return;return c=this.context.createRange(),c.setStartBefore(b.get(0)),b.length>=2&&c.setEndBefore(b.get(1)),b.remove(),this.selection.removeAllRanges(),this.selection.addRange(c)},a.prototype.placeMarker=function(){var a,b;if(!this.range)return;return this.startMarker=jQuery('<em class="mercury-marker"/>',this.context).get(0),this.endMarker=jQuery('<em class="mercury-marker"/>',this.context).get(0),a=this.range.cloneRange(),a.collapse(!1),a.insertNode(this.endMarker),this.range.collapsed||(b=this.range.cloneRange(),b.collapse(!0),b.insertNode(this.startMarker)),this.selection.removeAllRanges(),this.selection.addRange(this.range)},a.prototype.removeMarker=function(){return jQuery(this.startMarker).remove(),jQuery(this.endMarker).remove()},a.prototype.insertTextNode=function(a){var b;return b=this.context.createTextNode(a),this.range.extractContents(),this.range.insertNode(b),this.range.selectNodeContents(b),this.selection.addRange(this.range)},a.prototype.insertNode=function(a){return a.get&&(a=a.get(0)),jQuery.type(a)==="string"&&(a=jQuery(a,this.context).get(0)),this.range.deleteContents(),this.range.insertNode(a),this.range.selectNodeContents(a),this.selection.addRange(this.range)},a.prototype.selectNode=function(a,b){return b==null&&(b=!1),this.range.selectNode(a),b&&this.selection.removeAllRanges(),this.selection.addRange(this.range)},a.prototype.replace=function(a){return a.get&&(a=a.get(0)),jQuery.type(a)==="string"&&
(a=jQuery(a,this.context).get(0)),this.range.deleteContents(),this.range.insertNode(a),this.range.selectNodeContents(a),this.selection.addRange(this.range)},a}()}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b},c=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.Regions.Markupable=function(){function d(a,b,c){this.element=a,this.window=b,this.options=c!=null?c:{},this.type="markupable",d.__super__.constructor.apply(this,arguments),this.converter=new Showdown.converter}var a;return b(d,Mercury.Region),a="markupable",d.prototype.build=function(){var a,b,c;return c="100%",a=this.element.height(),b=this.element.html().replace(/^\s+|\s+$/g,"").replace("&gt;",">"),this.textarea=jQuery("<textarea>",this.document).val(b),this.textarea.attr("class",this.element.attr("class")).addClass("mercury-textarea"),this.textarea.css({border:0,background:"transparent",display:"block",width:c,height:a,fontFamily:'"Courier New", Courier, monospace',fontSize:"14px"}),this.element.empty().append(this.textarea),this.element.removeClass("mercury-region"),this.previewElement=jQuery("<div>",this.document),this.element.append(this.previewElement),this.element=this.textarea,this.resize()},d.prototype.focus=function(){return this.element.focus()},d.prototype.bindEvents=function(){return Mercury.bind("mode",c(function(a,b){if(b.mode==="preview")return this.togglePreview()},this)),Mercury.bind("focus:frame",c(function(){if(this.previewing)return;if(Mercury.region!==this)return;return this.focus()},this)),Mercury.bind("action",c(function(a,b){if(this.previewing)return;if(Mercury.region!==this)return;if(b.action)return this.execCommand(b.action,b)},this)),Mercury.bind("unfocus:regions",c(function(a){if(this.previewing)return;if(Mercury.region!==this)return;return this.element.blur(),this.element.removeClass("focus"),Mercury.trigger("region:blurred",{region:this})},this)),this.element.bind("dragenter",c(function(a){if(this.previewing)return;return a.preventDefault(),a.originalEvent.dataTransfer.dropEffect="copy"},this)),this.element.bind("dragover",c(function(a){if(this.previewing)return;return a.preventDefault(),a.originalEvent.dataTransfer.dropEffect="copy"},this)),this.element.bind("drop",c(function(a){if(this.previewing)return;Mercury.snippet&&(a.preventDefault(),this.focus(),Mercury.Snippet.displayOptionsFor(Mercury.snippet));if(a.originalEvent.dataTransfer.files.length)return a.preventDefault(),this.focus(),Mercury.uploader(a.originalEvent.dataTransfer.files[0])},this)),this.element.focus(c(function(){if(this.previewing)return;return Mercury.region=this,this.element.addClass("focus"),Mercury.trigger("region:focused",{region:this})},this)),this.element.keydown(c(function(a){var b,c,d,e,f,g;if(this.previewing)return;Mercury.changes=!0,this.resize();switch(a.keyCode){case 90:if(!a.metaKey)return;a.preventDefault(),a.shiftKey?this.execCommand("redo"):this.execCommand("undo");return;case 13:e=this.selection(),g=this.element.val(),f=g.lastIndexOf("\n",e.start),b=g.indexOf("\n",e.end),b<f&&(b=g.length),g[f]==="\n"&&(f=g.lastIndexOf("\n",e.start-1)),g[f+1]==="-"&&(e.replace("\n- ",!1,!0),a.preventDefault()),/\d/.test(g[f+1])&&(c=g.substring(f,b),/(\d+)\./.test(c)&&(d=parseInt(RegExp.$1),e.replace("\n"+(d+=1)+". ",!1,!0),a.preventDefault()));break;case 9:a.preventDefault(),this.execCommand("insertHTML",{value:"  "})}if(a.metaKey)switch(a.keyCode){case 66:this.execCommand("bold"),a.preventDefault();break;case 73:this.execCommand("italic"),a.preventDefault();break;case 85:this.execCommand("underline"),a.preventDefault()}return this.pushHistory(a.keyCode)},this)),this.element.keyup(c(function(){if(this.previewing)return;return Mercury.trigger("region:update",{region:this})},this)),this.element.mouseup(c(function(){if(this.previewing)return;return this.focus(),Mercury.trigger("region:focused",{region:this})},this)),this.previewElement.click(c(function(a){if(this.previewing)return $(a.target).closest("a").attr("target","_top")},this))},d.prototype.content=function(a,b){return a==null&&(a=null),b==null&&(b=!0),a!==null?jQuery.type(a)==="string"?this.element.val(a):(this.element.val(a.html),this.selection().select(a.selection.start,a.selection.end)):this.element.val()},d.prototype.contentAndSelection=function(){return{html:this.content(null,!1),selection:this.selection().serialize()}},d.prototype.togglePreview=function(){var a;return this.previewing?(this.previewElement.hide(),this.element.show()):(a=this.converter.makeHtml(this.element.val()),this.previewElement.html(a),this.previewElement.show(),this.element.hide()),d.__super__.togglePreview.apply(this,arguments)},d.prototype.execCommand=function(a,b){var c;return b==null&&(b={}),d.__super__.execCommand.apply(this,arguments),(c=Mercury.Regions.Markupable.actions[a])&&c.call(this,this.selection(),b),this.resize()},d.prototype.pushHistory=function(a){var b,d,e;return b=[13,46,8],e=2.5,a&&(d=b.indexOf(a)),clearTimeout(this.historyTimeout),d>=0&&d!==this.lastKnownKeyCode?this.history.push(this.contentAndSelection()):a?this.historyTimeout=setTimeout(c(function(){return this.history.push(this.contentAndSelection())},this),e*1e3):this.history.push(this.contentAndSelection()),this.lastKnownKeyCode=d},d.prototype.selection=function(){return new Mercury.Regions.Markupable.Selection(this.element)},d.prototype.resize=function(){},d.prototype.snippets=function(){},d.actions={undo:function(){return this.content(this.history.undo())},redo:function(){return this.content(this.history.redo())},insertHTML:function(a,b){var c;return b.value.get&&(c=b.value.get(0))&&(b.value=jQuery("<div>").html(c).html()),a.replace(b.value,!1,!0)},insertImage:function(a,b){return a.replace("![add alt text]("+encodeURI(b.value.src)+")",!0)},insertLink:function(a,b){return a.replace("["+b.value.content+"]("+b.value.attrs.href+" 'optional title')",!0)},insertUnorderedList:function(a){return a.addList("unordered")},insertOrderedList:function(a){return a.addList("ordered")},style:function(a,b){return a.wrap('<span class="'+b.value+'">',"</span>")},formatblock:function(a,b){var c,d,e;e={h1:["# "," #"],h2:["## "," ##"],h3:["### "," ###"],h4:["#### "," ####"],h5:["##### "," #####"],h6:["###### "," ######"],pre:["    ",""],blockquote:["> ",""],p:["\n","\n"]};for(d in e)c=e[d],a.unWrapLine(""+c[0],""+c[1]);if(b.value==="blockquote"){Mercury.Regions.Markupable.actions.indent.call(this,a,b);return}return a.wrapLine(""+e[b.value][0],""+e[b.value][1])},bold:function(a){return a.wrap("**","**")},italic:function(a){return a.wrap("_","_")},subscript:function(a){return a.wrap("<sub>","</sub>")},superscript:function(a){return a.wrap("<sup>","</sup>")},indent:function(a){return a.wrapLine("> ","",!1,!0)},outdent:function(a){return a.unWrapLine("> ","",!1,!0)},horizontalRule:function(a){return a.replace("\n- - -\n")},insertSnippet:function(a,b){var c;return c=b.value,a.replace(c.getText())}},d}(),Mercury.Regions.Markupable.Selection=function(){function a(a){this.element=a,this.el=this.element.get(0),this.getDetails()}return a.prototype.serialize=function(){return{start:this.start,end:this.end}},a.prototype.getDetails=function(){return this.length=this.el.selectionEnd-this.el.selectionStart,this.start=this.el.selectionStart,this.end=this.el.selectionEnd,this.text=this.element.val().substr(this.start,this.length)},a.prototype.replace=function(a,b,c){var d,e,f;return b==null&&(b=!1),c==null&&(c=!1),this.getDetails(),f=this.element.val(),e=this.element.val(),this.element.val(f.substr(0,this.start)+a+f.substr(this.end,f.length)),d=this.element.val()!==e,b&&this.select(this.start,this.start+a.length),c&&this.select(this.start+a.length,this.start+a.length),d},a.prototype.select=function(a,b){return this.start=a,this.end=b,this.element.focus(),this.el.selectionStart=this.start,this.el.selectionEnd=this.end,this.getDetails()},a.prototype.wrap=function(a,b){this.getDetails(),this.deselectNewLines(),this.replace(a+this.text+b,this.text!=="");if(this.text==="")return this.select(this.start+a.length,this.start+a.length)},a.prototype.wrapLine=function(a,b,c,d){var e,f,g,h;c==null&&(c=!0),d==null&&(d=!1),this.getDetails(),f=this.serialize(),h=this.element.val(),g=h.lastIndexOf("\n",this.start),e=h.indexOf("\n",this.end),e<g&&(e=h.length),h[g]==="\n"&&(g=h.lastIndexOf("\n",this.start-1)),this.select(g+1,e),this.replace(a+this.text+b,c);if(d)return this.select(f.start+a.length,f.end+a.length)},a.prototype.unWrapLine=function(a,b,c,d){var e,f,g,h,i,j,k;c==null&&(c=!0),d==null&&(d=!1),this.getDetails(),i=this.serialize(),k=this.element.val(),j=k.lastIndexOf("\n",this.start),f=k.indexOf("\n",this.end),f<j&&(f=k.length),k[j]==="\n"&&(j=k.lastIndexOf("\n",this.start-1)),this.select(j+1,f),window.something=this.text,g=new RegExp("^"+a.regExpEscape()),h=new RegExp(""+b.regExpEscape()+"$"),e=this.replace(this.text.replace(g,"").replace(h,""),c);if(d&&e)return this.select(i.start-a.length,i.end-a.length)},a.prototype.addList=function(a){var b,c,d,e,f,g;return g=this.element.val(),f=g.lastIndexOf("\n",this.start),b=g.indexOf("\n",this.end),b<f&&(b=g.length),g[f]==="\n"&&(f=g.lastIndexOf("\n",this.start-1)),this.select(f+1,b),e=this.text.split("\n"),a==="unordered"?this.replace("- "+e.join("\n- "),!0):this.replace(function(){var a,b;b=[];for(c=0,a=e.length;c<a;c++)d=e[c],b.push(""+(c+1)+". "+d);return b}().join("\n"),!0)},a.prototype.deselectNewLines=function(){var a,b;return b=this.text,a=b.replace(/\n+$/g,"").length,this.select(this.start,this.start+a)},a.prototype.placeMarker=function(){return this.wrap("[mercury-marker]","[mercury-marker]")},a.prototype.removeMarker=function(){var a,b,c;c=this.element.val(),b=c.indexOf("[mercury-marker]");if(b>-1)return a=c.indexOf("[mercury-marker]",b+1)-"[mercury-marker]".length,this.element.val(this.element.val().replace(/\[mercury-marker\]/g,"")),this.select(b,a);return},a.prototype.textContent=function(){return this.text},a}()}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b},c=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.Regions.Snippetable=function(){function d(a,b,c){this.element=a,this.window=b,this.options=c!=null?c:{},this.type="snippetable",d.__super__.constructor.apply(this,arguments),this.makeSortable()}var a;return b(d,Mercury.Region),a="snippetable",d.prototype.build=function(){if(this.element.css("minHeight")==="0px")return this.element.css({minHeight:20})},d.prototype.bindEvents=function(){return d.__super__.bindEvents.apply(this,arguments),Mercury.bind("unfocus:regions",c(function(a){if(this.previewing)return;if(Mercury.region===this)return this.element.removeClass("focus"),this.element.sortable("destroy"),Mercury.trigger("region:blurred",{region:this})},this)),Mercury.bind("focus:window",c(function(a){if(this.previewing)return;if(Mercury.region===this)return this.element.removeClass("focus"),this.element.sortable("destroy"),Mercury.trigger("region:blurred",{region:this})},this)),jQuery(this.document).keydown(c(function(a){if(this.previewing)return;if(Mercury.region!==this)return;Mercury.changes=!0;switch(a.keyCode){case 90:if(!a.metaKey)return;a.preventDefault(),a.shiftKey?this.execCommand("redo"):this.execCommand("undo")}},this)),this.element.mouseup(c(function(){if(this.previewing)return;return this.focus(),Mercury.trigger("region:focused",{region:this})},this)),this.element.bind("dragover",c(function(a){if(this.previewing)return;return a.preventDefault(),a.originalEvent.dataTransfer.dropEffect="copy"},this)),this.element.bind("drop",c(function(a){if(this.previewing)return;if(!Mercury.snippet)return;return this.focus(),a.preventDefault(),Mercury.Snippet.displayOptionsFor(Mercury.snippet)},this))},d.prototype.focus=function(){return Mercury.region=this,this.makeSortable(),this.element.addClass("focus")},d.prototype.togglePreview=function(){return this.previewing?this.makeSortable():(this.element.sortable("destroy"),this.element.removeClass("focus")),d.__super__.togglePreview.apply(this,arguments)},d.prototype.execCommand=function(a,b){var c;b==null&&(b={}),d.__super__.execCommand.apply(this,arguments);if(c=Mercury.Regions.Snippetable.actions[a])return c.call(this,b)},d.prototype.makeSortable=function(){return this.element.sortable("destroy").sortable({document:this.document,scroll:!1,containment:"parent",items:".mercury-snippet",opacity:.4,revert:100,tolerance:"pointer",beforeStop:c(function(){return Mercury.trigger("hide:toolbar",{type:"snippet",immediately:!0}),!0},this),stop:c(function(){return setTimeout(c(function(){return this.pushHistory()},this),100),!0},this)})},d.actions={undo:function(){return this.content(this.history.undo())},redo:function(){return this.content(this.history.redo())},insertSnippet:function(a){var b,d;return d=a.value,(b=this.element.find("[data-snippet="+d.identity+"]")).length?b.replaceWith(d.getHTML(this.document,c(function(){return this.pushHistory()},this))):this.element.append(d.getHTML(this.document,c(function(){return this.pushHistory()},this)))},editSnippet:function(){var a;if(!this.snippet)return;return a=Mercury.Snippet.find(this.snippet.data("snippet")),a.displayOptions()},removeSnippet:function(){return this.snippet&&this.snippet.remove(),Mercury.trigger("hide:toolbar",{type:"snippet",immediately:!0})}},d}()}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.dialogHandlers.backColor=function(){return this.element.find(".picker, .last-picked").click(a(function(a){var b;return b=jQuery(a.target).css("background-color"),this.element.find(".last-picked").css({background:b}),this.button.css({backgroundColor:b}),Mercury.trigger("action",{action:"backColor",value:b})},this))}}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.dialogHandlers.foreColor=function(){return this.element.find(".picker, .last-picked").click(a(function(a){var b;return b=jQuery(a.target).css("background-color"),this.element.find(".last-picked").css({background:b}),this.button.css({backgroundColor:b}),Mercury.trigger("action",{action:"foreColor",value:b})},this))}}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.dialogHandlers.formatblock=function(){return this.element.find("[data-tag]").click(a(function(a){var b;return b=jQuery(a.target).data("tag"),Mercury.trigger("action",{action:"formatblock",value:b})},this))}}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.dialogHandlers.snippetPanel=function(){return this.element.find("input.filter").keyup(a(function(){var a,b,c,d,e,f;b=this.element.find("input.filter").val(),e=this.element.find("li[data-filter]"),f=[];for(c=0,d=e.length;c<d;c++)a=e[c],f.push(LiquidMetal.score(jQuery(a).data("filter"),b)===0?jQuery(a).hide():jQuery(a).show());return f},this)),this.element.find("img[data-snippet]").bind("dragstart",function(a){return Mercury.snippet=jQuery(this).data("snippet")})}}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.dialogHandlers.style=function(){return this.element.find("[data-class]").click(a(function(a){var b;return b=jQuery(a.target).data("class"),Mercury.trigger("action",{action:"style",value:b})},this))}}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.modalHandlers.htmlEditor=function(){return this.element.find("textarea").val(Mercury.region.content(null,!0,!1)),this.element.find("form").submit(a(function(a){var b;return a.preventDefault(),b=this.element.find("textarea").val().replace(/\n/g,""),Mercury.trigger("action",{action:"replaceHTML",value:b}),this.hide()},this))}}.call(this),function(){this.Mercury.modalHandlers.insertCharacter=function(){return this.element.find(".character").click(function(){return Mercury.trigger("action",{action:"insertHTML",value:"&"+jQuery(this).attr("data-entity")+";"}),Mercury.modal.hide()})}}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.modalHandlers.insertLink=function(){var b,c,d,e,f,g,h,i,j,k;this.element.find("label input").click(function(a){return jQuery(this).closest("label").next(".selectable").focus()}),this.element.find(".selectable").focus(function(){return jQuery(this).prev("label").find("input[type=radio]").prop("checked",!0)}),this.element.find("#link_target").change(a(function(){return this.element.find(".link-target-options").hide(),this.element.find("#"+this.element.find("#link_target").val()+"_options").show(),this.resize(!0)},this)),b=this.element.find("#link_existing_bookmark"),k=jQuery("a[name]",window.mercuryInstance.document);for(i=0,j=k.length;i<j;i++)f=k[i],b.append(jQuery("<option>",{value:jQuery(f).attr("name")}).text(jQuery(f).text()));return Mercury.region&&Mercury.region.selection&&(h=Mercury.region.selection(),h&&h.commonAncestor&&(c=h.commonAncestor(!0).closest("a")),c&&c.length&&(d=c,this.element.find("#link_text_container").hide(),c.attr("href")&&c.attr("href").indexOf("#")===0?(b.val(c.attr("href").replace(/[^#]*#/,"")),b.prev("label").find("input[type=radio]").prop("checked",!0)):this.element.find("#link_external_url").val(c.attr("href")),c.attr("name")&&(g=this.element.find("#link_new_bookmark"),g.val(c.attr("name")),g.prev("label").find("input[type=radio]").prop("checked",!0)),c.attr("target")&&this.element.find("#link_target").val(c.attr("target")),c.attr("href")&&c.attr("href").indexOf("javascript:void")===0&&(e=c.attr("href"),this.element.find("#link_external_url").val(e.match(/window.open\('([^']+)',/)[1]),this.element.find("#link_target").val("popup"),this.element.find("#link_popup_width").val(e.match(/width=(\d+),/)[1]),this.element.find("#link_popup_height").val(e.match(/height=(\d+),/)[1]),this.element.find("#popup_options").show())),h.textContent&&this.element.find("#link_text").val(h.textContent())),this.element.find("form").submit(a(function(a){var b,c,e,f,g,h;a.preventDefault(),e=this.element.find("#link_text").val(),f=this.element.find("#link_target").val(),g=this.element.find("input[name=link_type]:checked").val();switch(g){case"existing_bookmark":c={href:"#"+this.element.find("#link_existing_bookmark").val()};break;case"new_bookmark":c={name:""+this.element.find("#link_new_bookmark").val()};break;default:c={href:this.element.find("#link_"+g).val()}}switch(f){case"popup":b={width:parseInt(this.element.find("#link_popup_width").val())||500,height:parseInt(this.element.find("#link_popup_height").val())||500,menubar:"no",toolbar:"no"},c.href="javascript:void(window.open('"+c.href+"', 'popup_window', '"+jQuery.param(b).replace(/&/g,",")+"'))";break;default:f&&(c.target=f)}return h={tagName:"a",attrs:c,content:e},d?Mercury.trigger("action",{action:"replaceLink",value:h,node:d.get(0)}):Mercury.trigger("action",{action:"insertLink",value:h}),this.hide()},this))}}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.modalHandlers.insertMedia=function(){var b,c,d,e;return this.element.find("label input").click(function(a){return jQuery(this).closest("label").next(".selectable").focus()}),this.element.find(".selectable").focus(a(function(a){var b;return b=jQuery(a.target),b.prev("label").find("input[type=radio]").prop("checked",!0),this.element.find(".media-options").hide(),this.element.find("#"+b.attr("id").replace("media_","")).show(),this.resize(!0)},this)),Mercury.region&&Mercury.region.selection&&(d=Mercury.region.selection(),d.is&&(c=d.is("img"))&&(this.element.find("#media_image_url").val(c.attr("src")),this.element.find("#media_image_alignment").val(c.attr("align"))),d.is&&(b=d.is("iframe"))&&(e=b.attr("src"),e.indexOf("http://www.youtube.com")>-1?(this.element.find("#media_youtube_url").val("http://youtu.be/"+e.match(/\/embed\/(\w+)/)[1]),this.element.find("#media_youtube_width").val(b.width()),this.element.find("#media_youtube_height").val(b.height()),this.element.find("#media_youtube_url").focus()):e.indexOf("http://player.vimeo.com")>-1&&(this.element.find("#media_vimeo_url").val("http://vimeo.com/"+e.match(/\/video\/(\w+)/)[1]),this.element.find("#media_vimeo_width").val(b.width()),this.element.find("#media_vimeo_height").val(b.height()),this.element.find("#media_vimeo_url").focus()))),this.element.find("form").submit(a(function(a){var b,c,d,e,f,g;a.preventDefault(),e=this.element.find("input[name=media_type]:checked").val();switch(e){case"image_url":c={src:this.element.find("#media_image_url").val()};if(b=this.element.find("#media_image_alignment").val())c.align=b;Mercury.trigger("action",{action:"insertImage",value:c});break;case"youtube_url":f=this.element.find("#media_youtube_url").val();if(!/^http:\/\/youtu.be\//.test(f)){alert("Error: The provided youtube share url was invalid.");return}d=f.replace("http://youtu.be/",""),g=jQuery("<iframe>",{width:this.element.find("#media_youtube_width").val()||560,height:this.element.find("#media_youtube_height").val()||349,src:"http://www.youtube.com/embed/"+d+"?wmode=transparent",frameborder:0,allowfullscreen:"true"}),Mercury.trigger("action",{action:"insertHTML",value:g});break;case"vimeo_url":f=this.element.find("#media_vimeo_url").val();if(!/^http:\/\/vimeo.com\//.test(f)){alert("Error: The provided vimeo url was invalid.");return}d=f.replace("http://vimeo.com/",""),g=jQuery("<iframe>",{width:this.element.find("#media_vimeo_width").val()||400,height:this.element.find("#media_vimeo_height").val()||225,src:"http://player.vimeo.com/video/"+d+"?title=1&byline=1&portrait=0&color=ffffff",frameborder:0}),Mercury.trigger("action",{action:"insertHTML",value:g})}return this.hide()},this))}}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.modalHandlers.insertSnippet=function(){return this.element.find("form").submit(a(function(a){var b,c;return a.preventDefault(),b=this.element.find("form").serializeObject(),Mercury.snippet?(c=Mercury.snippet,c.setOptions(b),Mercury.snippet=null):c=Mercury.Snippet.create(this.options.snippetName,b),Mercury.trigger("action",{action:"insertSnippet",value:c}),this.hide()},this))}}.call(this),function(){var a=function(a,b){return function(){return a.apply(b,arguments)}};this.Mercury.modalHandlers.insertTable=function(){var b,c;return c=this.element.find("#table_display table"),c.click(a(function(a){var b;return b=jQuery(a.target),c=b.closest("table"),c.find(".selected").removeClass("selected"),b.addClass("selected"),Mercury.tableEditor(c,b,"&nbsp;")},this)),b=c.find("td, th").first(),b.addClass("selected"),Mercury.tableEditor(c,b,"&nbsp;"),this.element.find("input.action").click(a(function(a){var b;b=jQuery(a.target).attr("name");switch(b){case"insertRowBefore":return Mercury.tableEditor.addRow("before");case"insertRowAfter":return Mercury.tableEditor.addRow("after");case"deleteRow":return Mercury.tableEditor.removeRow();case"insertColumnBefore":return Mercury.tableEditor.addColumn("before");case"insertColumnAfter":return Mercury.tableEditor.addColumn("after");case"deleteColumn":return Mercury.tableEditor.removeColumn();case"increaseColspan":return Mercury.tableEditor.increaseColspan();case"decreaseColspan":return Mercury.tableEditor.decreaseColspan();case"increaseRowspan":return Mercury.tableEditor.increaseRowspan();case"decreaseRowspan":return Mercury.tableEditor.decreaseRowspan()}},this)),this.element.find("#table_alignment").change(a(function(){return c.attr({align:this.element.find("#table_alignment").val()})},this)),this.element.find("#table_border").keyup(a(function(){return c.attr({border:parseInt(this.element.find("#table_border").val())})},this)),this.element.find("#table_spacing").keyup(a(function(){return c.attr({cellspacing:parseInt(this.element.find("#table_spacing").val())})},this)),this.element.find("form").submit(a(function(a){var b,d;return a.preventDefault(),c.find(".selected").removeClass("selected"),c.find("td, th").html("&nbsp;"),b=jQuery("<div>").html(c).html(),d=b.replace(/^\s+|\n/gm,"").replace(/(<\/.*?>|<table.*?>|<tbody>|<tr>)/g,"$1\n"),Mercury.trigger("action",{action:"insertHTML",value:d}),this.hide()},this))}}.call(this)